@@ -108,7 +108,7 @@ struct _CompEditorPrivate {
 	icaltimezone *zone;
 	gboolean use_24_hour_format;
 
-	gint week_start_day;
+	GDateWeekday week_start_day;
 
 	gint work_day_end_hour;
 	gint work_day_end_minute;
@@ -178,15 +178,9 @@ static const gchar *ui =
 "  <toolbar name='main-toolbar'>"
 "    <toolitem action='save-and-close'/>\n"
 "    <toolitem action='save'/>\n"
-"#if !EXPRESS\n"
 "    <toolitem action='print'/>\n"
-"#endif\n"
 "    <separator/>"
 "    <placeholder name='content'/>\n"
-"#if EXPRESS\n"
-"    <separator expand='true'/>\n"
-"    <toolitem action='close'/>\n"
-"#endif\n"
 "  </toolbar>"
 "</ui>";
 
@@ -1047,6 +1041,7 @@ save_and_close_editor (CompEditor *editor,
 			ECalClientSourceType source_type;
 			icalcomponent *icalcomp = NULL;
 			const gchar *uid = NULL;
+			gchar *msg;
 			gchar *rid = NULL;
 			GError *error = NULL;
 
@@ -1065,35 +1060,42 @@ save_and_close_editor (CompEditor *editor,
 				if (error != NULL) {
 					switch (source_type) {
 						case (E_CAL_CLIENT_SOURCE_TYPE_TASKS):
-							g_warning ("Unable to retrieve saved component from the task list, returned error was: %s", error->message);
+							msg = g_strdup_printf (
+								  _("Unable to retrieve saved component from the task list, returned error was: %s"),
+								  error->message);
 							break;
 						case (E_CAL_CLIENT_SOURCE_TYPE_MEMOS):
-							g_warning ("Unable to retrieve saved component from the memo list, returned error was: %s", error->message);
+							msg = g_strdup_printf (
+								  _("Unable to retrieve saved component from the memo list, returned error was: %s"),
+								  error->message);
 							break;
 						case (E_CAL_CLIENT_SOURCE_TYPE_EVENTS):
 						default:
-							g_warning ("Unable to retrieve saved component from the calendar, returned error was: %s", error->message);
+							msg = g_strdup_printf (
+								  _("Unable to retrieve saved component from the calendar, returned error was: %s"),
+								  error->message);
 							break;
 					}
 					g_clear_error (&error);
 				} else {
 					switch (source_type) {
 						case (E_CAL_CLIENT_SOURCE_TYPE_TASKS):
-							g_warning ("Unable to retrieve saved component from the task list");
+							msg = g_strdup (
+								  _("Unable to retrieve saved component from the task list"));
 						break;
 						case (E_CAL_CLIENT_SOURCE_TYPE_MEMOS):
-							g_warning ("Unable to retrieve saved component from the memo list");
+							msg = g_strdup (
+								  _("Unable to retrieve saved component from the memo list"));
 							break;
 						case (E_CAL_CLIENT_SOURCE_TYPE_EVENTS):
 						default:
-							g_warning ("Unable to retrieve saved component from the calendar");
+							msg = g_strdup (
+								  _("Unable to retrieve saved component from the calendar"));
 							break;
 					}
 				}
-				e_notice (
-					GTK_WINDOW (editor),
-					GTK_MESSAGE_ERROR,
-					_("Unable to synchronize with the server"));
+				e_notice (GTK_WINDOW (editor), GTK_MESSAGE_ERROR, "%s", msg);
+				g_free (msg);
 			} else {
 				comp = e_cal_component_new ();
 				if (e_cal_component_set_icalcomponent (comp, icalcomp)) {
@@ -1108,20 +1110,21 @@ save_and_close_editor (CompEditor *editor,
 				} else {
 					switch (source_type) {
 						case (E_CAL_CLIENT_SOURCE_TYPE_TASKS):
-							g_warning ("Unable to update the editor with the retrieved component from the task list");
+							msg = g_strdup (
+								  _("Unable to update the editor with the retrieved component from the task list"));
 						break;
 						case (E_CAL_CLIENT_SOURCE_TYPE_MEMOS):
-							g_warning ("Unable to update the editor with the retrieved component from the memo list");
+							msg = g_strdup (
+								  _("Unable to update the editor with the retrieved component from the memo list"));
 							break;
 						case (E_CAL_CLIENT_SOURCE_TYPE_EVENTS):
 						default:
-							g_warning ("Unable to update the editor with the retrieved component from the calendar");
+							msg = g_strdup (
+								  _("Unable to update the editor with the retrieved component from the calendar"));
 							break;
 					}
-					e_notice (
-						GTK_WINDOW (editor),
-						GTK_MESSAGE_ERROR,
-						_("Unable to synchronize with the server"));
+					e_notice (GTK_WINDOW (editor), GTK_MESSAGE_ERROR, "%s", msg);
+					g_free (msg);
 					icalcomponent_free (icalcomp);
 				}
 				g_object_unref (comp);
@@ -1512,7 +1515,7 @@ comp_editor_set_property (GObject *object,
 		case PROP_WEEK_START_DAY:
 			comp_editor_set_week_start_day (
 				COMP_EDITOR (object),
-				g_value_get_int (value));
+				g_value_get_enum (value));
 			return;
 
 		case PROP_WORK_DAY_END_HOUR:
@@ -1599,7 +1602,7 @@ comp_editor_get_property (GObject *object,
 			return;
 
 		case PROP_WEEK_START_DAY:
-			g_value_set_int (
+			g_value_set_enum (
 				value, comp_editor_get_week_start_day (
 				COMP_EDITOR (object)));
 			return;
@@ -1993,13 +1996,12 @@ comp_editor_class_init (CompEditorClass *class)
 	g_object_class_install_property (
 		object_class,
 		PROP_WEEK_START_DAY,
-		g_param_spec_int (
+		g_param_spec_enum (
 			"week-start-day",
 			"Week Start Day",
 			NULL,
-			0,  /* Monday */
-			6,  /* Sunday  */
-			0,
+			E_TYPE_DATE_WEEKDAY,
+			G_DATE_MONDAY,
 			G_PARAM_READWRITE |
 			G_PARAM_STATIC_STRINGS));
 
@@ -2088,7 +2090,6 @@ comp_editor_init (CompEditor *editor)
 	GtkWindow *window;
 	EShell *shell;
 	gboolean express_mode;
-	gboolean meego_mode;
 	gint n_targets;
 	GError *error = NULL;
 
@@ -2096,7 +2097,6 @@ comp_editor_init (CompEditor *editor)
 	 *       that depends on it to a constructed() method. */
 	shell = e_shell_get_default ();
 	express_mode = e_shell_get_express_mode (shell);
-	meego_mode = e_shell_get_meego_mode (shell);
 
 	editor->priv = priv = COMP_EDITOR_GET_PRIVATE (editor);
 
@@ -2123,9 +2123,7 @@ comp_editor_init (CompEditor *editor)
 	priv->is_group_item = FALSE;
 	priv->saved = FALSE;
 
-	priv->ui_manager = e_ui_manager_new ();
-	e_ui_manager_set_express_mode (
-		E_UI_MANAGER (priv->ui_manager), express_mode);
+	priv->ui_manager = gtk_ui_manager_new ();
 
 	gtk_window_add_accel_group (
 		GTK_WINDOW (editor),
@@ -2235,7 +2233,7 @@ comp_editor_init (CompEditor *editor)
 	action = comp_editor_get_action (editor, "save");
 	gtk_action_set_sensitive (action, FALSE);
 
-	e_ui_manager_add_ui_from_string (E_UI_MANAGER (priv->ui_manager), ui, &error);
+	gtk_ui_manager_add_ui_from_string (priv->ui_manager, ui, -1, &error);
 	if (error != NULL) {
 		g_warning ("%s: %s", G_STRFUNC, error->message);
 		g_error_free (error);
@@ -2251,11 +2249,9 @@ comp_editor_init (CompEditor *editor)
 
 	container = widget;
 
-	if (!express_mode) {
-		widget = comp_editor_get_managed_widget (editor, "/main-menu");
-		gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
-		gtk_widget_set_visible (widget, !meego_mode);
-	}
+	widget = comp_editor_get_managed_widget (editor, "/main-menu");
+	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
+	gtk_widget_set_visible (widget, TRUE);
 
 	widget = comp_editor_get_managed_widget (editor, "/main-toolbar");
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
@@ -2282,26 +2278,9 @@ comp_editor_init (CompEditor *editor)
 	container = e_attachment_paned_get_content_area (
 		E_ATTACHMENT_PANED (priv->attachment_view));
 
-	if (meego_mode) {
-		widget = gtk_scrolled_window_new (NULL, NULL);
-		gtk_scrolled_window_set_policy (
-			GTK_SCROLLED_WINDOW (widget),
-			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-		gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
-		gtk_widget_set_size_request (widget, 300, -1);
-		gtk_widget_show (widget);
-
-		container = widget;
-	}
-
 	widget = gtk_notebook_new ();
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (widget), express_mode);
-	if (!meego_mode)
-		gtk_box_pack_start (
-			GTK_BOX (container), widget, TRUE, TRUE, 0);
-	else
-		gtk_scrolled_window_add_with_viewport (
-			GTK_SCROLLED_WINDOW (container), widget);
+	gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
 	priv->notebook = GTK_NOTEBOOK (widget);
 	gtk_widget_show (widget);
 
@@ -2346,7 +2325,6 @@ comp_editor_init (CompEditor *editor)
 
 	gtk_application_add_window (
 		GTK_APPLICATION (shell), GTK_WINDOW (editor));
-	e_shell_adapt_window_size (shell, GTK_WINDOW (editor));
 }
 
 static gboolean
@@ -2641,7 +2619,7 @@ comp_editor_set_use_24_hour_format (CompEditor *editor,
 	g_object_notify (G_OBJECT (editor), "use-24-hour-format");
 }
 
-gint
+GDateWeekday
 comp_editor_get_week_start_day (CompEditor *editor)
 {
 	g_return_val_if_fail (IS_COMP_EDITOR (editor), 0);
@@ -2651,10 +2629,10 @@ comp_editor_get_week_start_day (CompEditor *editor)
 
 void
 comp_editor_set_week_start_day (CompEditor *editor,
-                                gint week_start_day)
+                                GDateWeekday week_start_day)
 {
 	g_return_if_fail (IS_COMP_EDITOR (editor));
-	g_return_if_fail (week_start_day >= 0 && week_start_day < 7);
+	g_return_if_fail (g_date_valid_weekday (week_start_day));
 
 	if (week_start_day == editor->priv->week_start_day)
 		return;
@@ -3239,8 +3217,8 @@ attachment_loaded_cb (EAttachment *attachment,
 	 * So this is a lazy migration from the old form to the new.
 	 */
 
-	file_info = e_attachment_ref_file_info (attachment);
-	if (file_info == NULL) {
+	file_info = e_attachment_get_file_info (attachment);
+	if (!file_info) {
 		/* failed to load an attachment file */
 		e_attachment_load_handle_error (attachment, result, parent);
 		return;
@@ -3256,8 +3234,6 @@ attachment_loaded_cb (EAttachment *attachment,
 		g_free (new_name);
 	}
 
-	g_object_unref (file_info);
-
 	e_attachment_load_handle_error (attachment, result, parent);
 }
 
@@ -3730,13 +3706,12 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		CamelStream *stream;
 		GByteArray *byte_array;
 		guchar *buffer = NULL;
-		const gchar *description;
-		const gchar *disposition;
+		const gchar *desc, *disp;
 		gint column_id;
 
 		column_id = E_ATTACHMENT_STORE_COLUMN_ATTACHMENT;
 		gtk_tree_model_get (model, &iter, column_id, &attachment, -1);
-		mime_part = e_attachment_ref_mime_part (attachment);
+		mime_part = e_attachment_get_mime_part (attachment);
 		g_object_unref (attachment);
 
 		valid = gtk_tree_model_iter_next (model, &iter);
@@ -3760,23 +3735,21 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		cal_mime_attach->length = byte_array->len;
 		cal_mime_attach->filename =
 			g_strdup (camel_mime_part_get_filename (mime_part));
-		description = camel_mime_part_get_description (mime_part);
-		if (description == NULL || *description == '\0')
-			description = _("attachment");
-		cal_mime_attach->description = g_strdup (description);
+		desc = camel_mime_part_get_description (mime_part);
+		if (!desc || *desc == '\0')
+			desc = _("attachment");
+		cal_mime_attach->description = g_strdup (desc);
 		cal_mime_attach->content_type = g_strdup (
 			camel_data_wrapper_get_mime_type (wrapper));
 		cal_mime_attach->content_id = g_strdup (
 			camel_mime_part_get_content_id (mime_part));
 
-		disposition = camel_mime_part_get_disposition (mime_part);
-		cal_mime_attach->disposition =
-			(disposition != NULL) &&
-			(g_ascii_strcasecmp (disposition, "inline") == 0);
+		disp = camel_mime_part_get_disposition (mime_part);
+		if (disp && !g_ascii_strcasecmp (disp, "inline"))
+			cal_mime_attach->disposition = TRUE;
 
 		attach_list = g_slist_append (attach_list, cal_mime_attach);
 
-		g_object_unref (mime_part);
 		g_object_unref (stream);
 
 	}
