@@ -1539,21 +1539,6 @@ get_widgets (TaskPage *tpage)
 	gtk_entry_set_completion (GTK_ENTRY (priv->categories), completion);
 	g_object_unref (completion);
 
-	if (priv->summary) {
-		EShell *shell;
-		EShellSettings *shell_settings;
-		CompEditor *editor;
-
-		editor = comp_editor_page_get_editor (page);
-		shell = comp_editor_get_shell (editor);
-		shell_settings = e_shell_get_shell_settings (shell);
-
-		g_object_bind_property (
-			shell_settings, "composer-inline-spelling",
-			priv->summary, "checking-enabled",
-			G_BINDING_SYNC_CREATE);
-	}
-
 	return (priv->summary
 		&& priv->summary_label
 		&& priv->due_date
