@@ -220,9 +220,16 @@ gboolean	e_cal_model_get_use_default_reminder
 void		e_cal_model_set_use_default_reminder
 						(ECalModel *model,
 						 gboolean use_def_reminder);
-gint		e_cal_model_get_week_start_day	(ECalModel *model);
+GDateWeekday	e_cal_model_get_week_start_day	(ECalModel *model);
 void		e_cal_model_set_week_start_day	(ECalModel *model,
-						 gint week_start_day);
+						 GDateWeekday week_start_day);
+gboolean	e_cal_model_get_work_day	(ECalModel *model,
+						 GDateWeekday weekday);
+void		e_cal_model_set_work_day	(ECalModel *model,
+						 GDateWeekday weekday,
+						 gboolean work_day);
+GDateWeekday	e_cal_model_get_work_day_first	(ECalModel *model);
+GDateWeekday	e_cal_model_get_work_day_last	(ECalModel *model);
 gint		e_cal_model_get_work_day_end_hour
 						(ECalModel *model);
 void		e_cal_model_set_work_day_end_hour
@@ -247,9 +254,9 @@ ECalClient *	e_cal_model_ref_default_client	(ECalModel *model);
 void		e_cal_model_set_default_client	(ECalModel *model,
 						 ECalClient *client);
 GList *		e_cal_model_list_clients	(ECalModel *model);
-gboolean	e_cal_model_add_client		(ECalModel *model,
+void		e_cal_model_add_client		(ECalModel *model,
 						 ECalClient *cal_client);
-gboolean	e_cal_model_remove_client	(ECalModel *model,
+void		e_cal_model_remove_client	(ECalModel *model,
 						 ECalClient *cal_client);
 void		e_cal_model_remove_all_clients	(ECalModel *model);
 void		e_cal_model_get_time_range	(ECalModel *model,
