@@ -430,16 +430,13 @@ itip_get_comp_attendee (ESourceRegistry *registry,
 	}
 
 	extension_name = E_SOURCE_EXTENSION_MAIL_IDENTITY;
-	list = e_source_registry_list_sources (registry, extension_name);
+	list = e_source_registry_list_enabled (registry, extension_name);
 
 	for (link = list; link != NULL; link = g_list_next (link)) {
 		ESourceExtension *extension;
 
 		source = E_SOURCE (link->data);
 
-		if (!e_source_registry_check_enabled (registry, source))
-			continue;
-
 		extension_name = E_SOURCE_EXTENSION_MAIL_IDENTITY;
 		extension = e_source_get_extension (source, extension_name);
 
@@ -723,8 +720,7 @@ comp_to_list (ESourceRegistry *registry,
 			 * invite will be sent to the resources as well. */
 			if (att->cutype != ICAL_CUTYPE_INDIVIDUAL &&
 			    att->cutype != ICAL_CUTYPE_GROUP &&
-			    att->cutype != ICAL_CUTYPE_RESOURCE &&
-			    att->cutype != ICAL_CUTYPE_UNKNOWN)
+			    att->cutype != ICAL_CUTYPE_RESOURCE)
 				continue;
 			else if (users_has_attendee (users, att->value))
 				continue;
@@ -771,39 +767,19 @@ comp_to_list (ESourceRegistry *registry,
 
 			array = g_ptr_array_new ();
 
-			sender = itip_get_comp_attendee (registry, comp, NULL);
-
 			e_cal_component_get_organizer (comp, &organizer);
-			if (organizer.value && (!sender || g_ascii_strcasecmp (
-			    itip_strip_mailto (organizer.value), sender) != 0)) {
-				destination = e_destination_new ();
-				e_destination_set_email (
-					destination,
-					itip_strip_mailto (organizer.value));
-				if (organizer.cn)
-					e_destination_set_name (destination, organizer.cn);
-				g_ptr_array_add (array, destination);
-			}
+			sender = itip_get_comp_attendee (registry, comp, NULL);
 
 			for (l = attendees; l != NULL; l = l->next) {
 				ECalComponentAttendee *att = l->data;
 
-				if (!att->value)
-					continue;
-				else if (att->cutype != ICAL_CUTYPE_INDIVIDUAL &&
-					 att->cutype != ICAL_CUTYPE_GROUP &&
-					 att->cutype != ICAL_CUTYPE_UNKNOWN)
+				if (att->cutype != ICAL_CUTYPE_INDIVIDUAL &&
+				    att->cutype != ICAL_CUTYPE_GROUP)
 					continue;
 				else if (only_attendees &&
 					!comp_editor_have_in_new_attendees_lst (
 					only_attendees, itip_strip_mailto (att->value)))
 					continue;
-				else if (organizer.value &&
-					 g_ascii_strcasecmp (att->value, organizer.value) == 0)
-					continue;
-				else if (sender && g_ascii_strcasecmp (
-					itip_strip_mailto (att->value), sender) == 0)
-					continue;
 
 				destination = e_destination_new ();
 				if (att->cn != NULL)
@@ -821,8 +797,6 @@ comp_to_list (ESourceRegistry *registry,
 
 			destination = e_destination_new ();
 			e_cal_component_get_organizer (comp, &organizer);
-			if (organizer.cn)
-				e_destination_set_name (destination, organizer.cn);
 			if (organizer.value)
 				e_destination_set_email (
 					destination, itip_strip_mailto (organizer.value));
@@ -859,8 +833,7 @@ comp_to_list (ESourceRegistry *registry,
 			ECalComponentAttendee *att = l->data;
 
 			if (att->cutype != ICAL_CUTYPE_INDIVIDUAL &&
-			    att->cutype != ICAL_CUTYPE_GROUP &&
-			    att->cutype != ICAL_CUTYPE_UNKNOWN)
+			    att->cutype != ICAL_CUTYPE_GROUP)
 				continue;
 
 			if (!g_ascii_strcasecmp (
@@ -1603,16 +1576,13 @@ find_enabled_identity (ESourceRegistry *registry,
 		return NULL;
 
 	extension_name = E_SOURCE_EXTENSION_MAIL_IDENTITY;
-	list = e_source_registry_list_sources (registry, extension_name);
+	list = e_source_registry_list_enabled (registry, extension_name);
 
 	for (link = list; link != NULL; link = g_list_next (link)) {
 		ESource *source = E_SOURCE (link->data);
 		ESourceMailIdentity *extension;
 		const gchar *address;
 
-		if (!e_source_registry_check_enabled (registry, source))
-			continue;
-
 		extension = e_source_get_extension (source, extension_name);
 		address = e_source_mail_identity_get_address (extension);
 
@@ -1683,7 +1653,7 @@ itip_send_comp (ESourceRegistry *registry,
                 gboolean only_new_attendees)
 {
 	EShell *shell;
-	EShellSettings *shell_settings;
+	GSettings *settings;
 	EMsgComposer *composer;
 	EComposerHeaderTable *table;
 	EDestination **destinations;
@@ -1700,10 +1670,13 @@ itip_send_comp (ESourceRegistry *registry,
 
 	/* FIXME Pass this in. */
 	shell = e_shell_get_default ();
-	shell_settings = e_shell_get_shell_settings (shell);
 
-	use_24_hour_format = e_shell_settings_get_boolean (
-		shell_settings, "cal-use-24-hour-format");
+	settings = g_settings_new ("org.gnome.evolution.calendar");
+
+	use_24_hour_format =
+		g_settings_get_boolean (settings, "use-24hour-format");
+
+	g_object_unref (settings);
 
 	default_zone = e_cal_client_get_default_timezone (cal_client);
 
@@ -2169,7 +2142,6 @@ itip_publish_comp (ECalClient *cal_client,
 	SoupMessage *msg;
 	SoupURI *real_uri;
 	gchar *ical_string = NULL;
-	EProxy *proxy;
 
 	toplevel = e_cal_util_new_top_level ();
 	icalcomponent_set_method (toplevel, ICAL_METHOD_PUBLISH);
@@ -2186,19 +2158,6 @@ itip_publish_comp (ECalClient *cal_client,
 	session = soup_session_async_new ();
 	g_object_set (session, SOUP_SESSION_TIMEOUT, 90, NULL);
 
-	proxy = e_proxy_new ();
-	e_proxy_setup_proxy (proxy);
-
-	if (e_proxy_require_proxy_for_uri (proxy, uri)) {
-		SoupURI *proxy_uri;
-
-		proxy_uri = e_proxy_peek_uri_for (proxy, uri);
-
-		g_object_set (session, SOUP_SESSION_PROXY_URI, proxy_uri, NULL);
-	}
-
-	g_clear_object (&proxy);
-
 	real_uri = soup_uri_new (uri);
 	if (!real_uri || !real_uri->host) {
 		g_warning (G_STRLOC ": Invalid URL: %s", uri);
@@ -2283,57 +2242,3 @@ is_icalcomp_valid (icalcomponent *icalcomp)
 
 	return TRUE;
 }
-
-gboolean
-itip_component_has_recipients (ECalComponent *comp)
-{
-	GSList *attendees = NULL;
-	ECalComponentAttendee *attendee;
-	ECalComponentOrganizer organizer;
-	gboolean res = FALSE;
-
-	g_return_val_if_fail (comp != NULL, FALSE);
-
-	e_cal_component_get_organizer (comp, &organizer);
-	e_cal_component_get_attendee_list (comp, &attendees);
-
-	if (!attendees) {
-		if (organizer.value && e_cal_component_get_vtype (comp) == E_CAL_COMPONENT_JOURNAL) {
-			/* memos store recipients in an extra property */
-			icalcomponent *icalcomp;
-			icalproperty *icalprop;
-
-			icalcomp = e_cal_component_get_icalcomponent (comp);
-
-			for (icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
-			     icalprop != NULL;
-			     icalprop = icalcomponent_get_next_property (icalcomp, ICAL_X_PROPERTY)) {
-				const gchar *x_name;
-
-				x_name = icalproperty_get_x_name (icalprop);
-
-				if (g_str_equal (x_name, "X-EVOLUTION-RECIPIENTS")) {
-					const gchar *str_recipients = icalproperty_get_x (icalprop);
-
-					res = str_recipients && g_ascii_strcasecmp (organizer.value, str_recipients) != 0;
-					break;
-				}
-			}
-		}
-
-		return res;
-	}
-
-	if (g_slist_length (attendees) > 1 || !e_cal_component_has_organizer (comp)) {
-		e_cal_component_free_attendee_list (attendees);
-		return TRUE;
-	}
-
-	attendee = attendees->data;
-
-	res = organizer.value && attendee && attendee->value && g_ascii_strcasecmp (organizer.value, attendee->value) != 0;
-
-	e_cal_component_free_attendee_list (attendees);
-
-	return res;
-}
