@@ -140,7 +140,6 @@ e_composer_private_constructed (EMsgComposer *composer)
 	EMsgComposerPrivate *priv = composer->priv;
 	EFocusTracker *focus_tracker;
 	EShell *shell;
-	EShellSettings *shell_settings;
 	EWebViewGtkHTML *web_view;
 	ESourceRegistry *registry;
 	GtkhtmlEditor *editor;
@@ -150,8 +149,8 @@ e_composer_private_constructed (EMsgComposer *composer)
 	GtkWidget *widget;
 	GtkWidget *send_widget;
 	GtkWindow *window;
+	GSettings *settings;
 	const gchar *path;
-	gboolean small_screen_mode;
 	gchar *filename, *gallery_path;
 	gint ii;
 	GError *error = NULL;
@@ -159,32 +158,11 @@ e_composer_private_constructed (EMsgComposer *composer)
 	editor = GTKHTML_EDITOR (composer);
 	ui_manager = gtkhtml_editor_get_ui_manager (editor);
 
+	settings = g_settings_new ("org.gnome.evolution.mail");
+
 	shell = e_msg_composer_get_shell (composer);
 	registry = e_shell_get_registry (shell);
-	shell_settings = e_shell_get_shell_settings (shell);
 	web_view = e_msg_composer_get_web_view (composer);
-	small_screen_mode = e_shell_get_small_screen_mode (shell);
-
-	if (small_screen_mode) {
-#if 0
-		/* In the lite composer, for small screens, we are not
-		 * ready yet to hide the menubar.  It still has useful
-		 * items like the ones to show/hide the various header
-		 * fields, plus the security options.
-		 *
-		 * When we move those options out of the menu and into
-		 * the composer's toplevel, we can probably get rid of
-		 * the menu.
-		 */
-		widget = gtkhtml_editor_get_managed_widget (editor, "/main-menu");
-		gtk_widget_hide (widget);
-#endif
-		widget = gtkhtml_editor_get_managed_widget (editor, "/main-toolbar");
-		gtk_toolbar_set_style (
-			GTK_TOOLBAR (widget), GTK_TOOLBAR_BOTH_HORIZ);
-		gtk_widget_hide (widget);
-
-	}
 
 	/* Each composer window gets its own window group. */
 	window = GTK_WINDOW (composer);
@@ -270,10 +248,7 @@ e_composer_private_constructed (EMsgComposer *composer)
 	widget = e_composer_header_table_new (shell, registry);
 	gtk_container_set_border_width (GTK_CONTAINER (widget), 6);
 	gtk_box_pack_start (GTK_BOX (container), widget, FALSE, FALSE, 0);
-	if (small_screen_mode)
-		gtk_box_reorder_child (GTK_BOX (container), widget, 1);
-	else
-		gtk_box_reorder_child (GTK_BOX (container), widget, 2);
+	gtk_box_reorder_child (GTK_BOX (container), widget, 2);
 	priv->header_table = g_object_ref (widget);
 	gtk_widget_show (widget);
 
@@ -283,12 +258,6 @@ e_composer_private_constructed (EMsgComposer *composer)
 
 	/* Construct the attachment paned. */
 
-	if (small_screen_mode) {
-		/* Short attachment bar for Anjal. */
-		e_attachment_paned_set_default_height (75);
-		e_attachment_icon_view_set_default_icon_size (GTK_ICON_SIZE_BUTTON);
-	}
-
 	widget = e_attachment_paned_new ();
 	gtk_box_pack_start (GTK_BOX (container), widget, TRUE, TRUE, 0);
 	priv->attachment_paned = g_object_ref (widget);
@@ -299,61 +268,6 @@ e_composer_private_constructed (EMsgComposer *composer)
 		widget, "editable",
 		G_BINDING_SYNC_CREATE);
 
-	if (small_screen_mode) {
-		GtkWidget *tmp, *tmp1, *tmp_box, *container;
-		GtkWidget *combo;
-
-		combo = e_attachment_paned_get_view_combo (
-			E_ATTACHMENT_PANED (widget));
-		gtk_widget_hide (combo);
-		container = e_attachment_paned_get_controls_container (
-			E_ATTACHMENT_PANED (widget));
-
-		tmp_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-
-		tmp = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		tmp1 = gtk_image_new_from_icon_name (
-			"mail-send", GTK_ICON_SIZE_BUTTON);
-		gtk_box_pack_start ((GtkBox *) tmp, tmp1, FALSE, FALSE, 0);
-		tmp1 = gtk_label_new_with_mnemonic (_("S_end"));
-		gtk_box_pack_start ((GtkBox *) tmp, tmp1, FALSE, FALSE, 6);
-		gtk_widget_show_all (tmp);
-		gtk_widget_reparent (send_widget, tmp_box);
-		gtk_box_set_child_packing (
-			GTK_BOX (tmp_box), send_widget,
-			FALSE, FALSE, 6, GTK_PACK_END);
-		gtk_tool_item_set_is_important (GTK_TOOL_ITEM (send_widget), TRUE);
-		send_widget = gtk_bin_get_child ((GtkBin *) send_widget);
-		gtk_container_remove (
-			GTK_CONTAINER (send_widget),
-			gtk_bin_get_child (GTK_BIN (send_widget)));
-		gtk_container_add ((GtkContainer *) send_widget, tmp);
-		gtk_button_set_relief ((GtkButton *) send_widget, GTK_RELIEF_NORMAL);
-		path = "/main-toolbar/pre-main-toolbar/save-draft";
-		send_widget = gtk_ui_manager_get_widget (ui_manager, path);
-		tmp = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		tmp1 = gtk_image_new_from_stock (
-			GTK_STOCK_SAVE, GTK_ICON_SIZE_BUTTON);
-		gtk_box_pack_start ((GtkBox *) tmp, tmp1, FALSE, FALSE, 0);
-		tmp1 = gtk_label_new_with_mnemonic (_("Save draft"));
-		gtk_box_pack_start ((GtkBox *) tmp, tmp1, FALSE, FALSE, 3);
-		gtk_widget_show_all (tmp);
-		gtk_widget_reparent (send_widget, tmp_box);
-		gtk_box_set_child_packing (
-			GTK_BOX (tmp_box), send_widget,
-			FALSE, FALSE, 6, GTK_PACK_END);
-		gtk_tool_item_set_is_important (GTK_TOOL_ITEM (send_widget), TRUE);
-		send_widget = gtk_bin_get_child ((GtkBin *) send_widget);
-		gtk_container_remove (
-			GTK_CONTAINER (send_widget),
-			gtk_bin_get_child (GTK_BIN (send_widget)));
-		gtk_container_add ((GtkContainer *) send_widget, tmp);
-		gtk_button_set_relief ((GtkButton *) send_widget, GTK_RELIEF_NORMAL);
-
-		gtk_widget_show (tmp_box);
-		gtk_box_pack_end (GTK_BOX (container), tmp_box, FALSE, FALSE, 3);
-	}
-
 	container = e_attachment_paned_get_content_area (
 		E_ATTACHMENT_PANED (priv->attachment_paned));
 
@@ -385,8 +299,9 @@ e_composer_private_constructed (EMsgComposer *composer)
 
 	container = priv->gallery_scrolled_window;
 
-	gallery_path = e_shell_settings_get_string (
-		shell_settings, "composer-gallery-path");
+	/* FIXME This should be an EMsgComposer property. */
+	gallery_path = g_settings_get_string (
+		settings, "composer-gallery-path");
 	widget = e_picture_gallery_new (gallery_path);
 	gtk_container_add (GTK_CONTAINER (container), widget);
 	priv->gallery_icon_view = g_object_ref (widget);
@@ -457,6 +372,8 @@ e_composer_private_constructed (EMsgComposer *composer)
 	g_signal_connect (
 		web_view, "url-requested",
 		G_CALLBACK (msg_composer_url_requested_cb), composer);
+
+	g_object_unref (settings);
 }
 
 void
@@ -912,31 +829,31 @@ e_composer_selection_is_image_uris (EMsgComposer *composer,
 static gboolean
 add_signature_delimiter (EMsgComposer *composer)
 {
-	EShell *shell;
-	EShellSettings *shell_settings;
+	GSettings *settings;
+	gboolean signature_delim;
 
-	/* FIXME This preference should be an EMsgComposer property. */
+	/* FIXME This should be an EMsgComposer property. */
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	signature_delim = !g_settings_get_boolean (
+		settings, "composer-no-signature-delim");
+	g_object_unref (settings);
 
-	shell = e_msg_composer_get_shell (composer);
-	shell_settings = e_shell_get_shell_settings (shell);
-
-	return !e_shell_settings_get_boolean (
-		shell_settings, "composer-no-signature-delim");
+	return signature_delim;
 }
 
 static gboolean
 use_top_signature (EMsgComposer *composer)
 {
-	EShell *shell;
-	EShellSettings *shell_settings;
+	GSettings *settings;
+	gboolean top_signature;
 
-	/* FIXME This preference should be an EMsgComposer property. */
+	/* FIXME This should be an EMsgComposer property. */
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	top_signature = g_settings_get_boolean (
+		settings, "composer-top-signature");
+	g_object_unref (settings);
 
-	shell = e_msg_composer_get_shell (composer);
-	shell_settings = e_shell_get_shell_settings (shell);
-
-	return e_shell_settings_get_boolean (
-		shell_settings, "composer-top-signature");
+	return top_signature;
 }
 
 static void
