@@ -33,7 +33,6 @@
 #include "e-attachment-handler-sendto.h"
 #include "e-misc-utils.h"
 #include "e-selection.h"
-#include "e-ui-manager.h"
 
 enum {
 	UPDATE_ACTIONS,
@@ -175,7 +174,7 @@ action_open_with_cb (GtkAction *action,
 		E_ATTACHMENT_STORE_COLUMN_ATTACHMENT, &attachment, -1);
 	g_return_if_fail (E_IS_ATTACHMENT (attachment));
 
-	file_info = e_attachment_ref_file_info (attachment);
+	file_info = e_attachment_get_file_info (attachment);
 	g_return_if_fail (file_info != NULL);
 
 	content_type = g_file_info_get_content_type (file_info);
@@ -193,8 +192,6 @@ action_open_with_cb (GtkAction *action,
 		g_object_unref (app_info);
 	}
 
-	g_object_unref (file_info);
-
 	g_list_foreach (list, (GFunc) gtk_tree_path_free, NULL);
 	g_list_free (list);
 }
@@ -884,7 +881,7 @@ e_attachment_view_init (EAttachmentView *view)
 
 	priv = e_attachment_view_get_private (view);
 
-	ui_manager = e_ui_manager_new ();
+	ui_manager = gtk_ui_manager_new ();
 	priv->merge_id = gtk_ui_manager_new_merge_id (ui_manager);
 	priv->ui_manager = ui_manager;
 
@@ -1150,7 +1147,7 @@ e_attachment_view_open_path (EAttachmentView *view,
 	store = e_attachment_view_get_store (view);
 	model = GTK_TREE_MODEL (store);
 
-	g_return_if_fail (gtk_tree_model_get_iter (model, &iter, path));
+	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter, column_id, &attachment, -1);
 
 	parent = gtk_widget_get_toplevel (GTK_WIDGET (view));
@@ -1563,7 +1560,7 @@ e_attachment_view_drag_begin (EAttachmentView *view,
 		gint width, height;
 
 		attachment = E_ATTACHMENT (priv->selected->data);
-		icon = e_attachment_ref_icon (attachment);
+		icon = e_attachment_get_icon (attachment);
 		g_return_if_fail (icon != NULL);
 
 		icon_theme = gtk_icon_theme_get_default ();
@@ -1590,8 +1587,6 @@ e_attachment_view_drag_begin (EAttachmentView *view,
 
 			gtk_icon_info_free (icon_info);
 		}
-
-		g_object_unref (icon);
 	}
 }
 
