@@ -113,7 +113,7 @@ emfe_attachment_format (EMailFormatterExtension *extension,
 	gchar *str, *text, *html;
 	gchar *button_id;
 	EAttachmentStore *store;
-	EMailExtensionRegistry *registry;
+	EMailExtensionRegistry *reg;
 	GQueue *extensions;
 	EMailPartAttachment *empa;
 	CamelMimeFilterToHTMLFlags flags;
@@ -156,70 +156,76 @@ emfe_attachment_format (EMailFormatterExtension *extension,
 		}
 	}
 
-	registry = e_mail_formatter_get_extension_registry (formatter);
-
-	extensions = e_mail_extension_registry_get_for_mime_type (
-		registry, empa->snoop_mime_type);
-	if (extensions == NULL)
-		extensions = e_mail_extension_registry_get_fallback (
-			registry, empa->snoop_mime_type);
-
-	/* If the attachment is requested as RAW, then call the
-	 * handler directly and do not append any other code. */
+        /* If the attachment is requested as RAW, then call the handler directly
+         * and do not append any other code. */
 	if ((context->mode == E_MAIL_FORMATTER_MODE_RAW) ||
 	    (context->mode == E_MAIL_FORMATTER_MODE_PRINTING)) {
-		GList *head, *link;
-		gboolean success = FALSE;
+		EMailExtensionRegistry *reg;
+		GQueue *extensions;
+		GList *iter;
+		reg = e_mail_formatter_get_extension_registry (formatter);
 
-		if (extensions == NULL)
+		extensions = e_mail_extension_registry_get_for_mime_type (
+					reg, empa->snoop_mime_type);
+		if (!extensions) {
+			extensions = e_mail_extension_registry_get_fallback (
+					reg, empa->snoop_mime_type);
+		}
+
+		if (!extensions)
 			return FALSE;
 
 		if (context->mode == E_MAIL_FORMATTER_MODE_PRINTING) {
 			gchar *name;
 			EAttachment *attachment;
-			GFileInfo *file_info;
-			const gchar *display_name;
-			gchar *description;
+			GFileInfo *fi;
+			const gchar *description;
 
 			attachment = empa->attachment;
-			file_info = e_attachment_ref_file_info (attachment);
-			display_name = g_file_info_get_display_name (file_info);
+			fi = e_attachment_get_file_info (attachment);
 
-			description = e_attachment_dup_description (attachment);
-			if (description != NULL && *description != '\0') {
+			description = e_attachment_get_description (attachment);
+			if (description && *description) {
 				name = g_strdup_printf (
 					"<h2>Attachment: %s (%s)</h2>\n",
-					description, display_name);
+					description, g_file_info_get_display_name (fi));
 			} else {
 				name = g_strdup_printf (
 					"<h2>Attachment: %s</h2>\n",
-					display_name);
+					g_file_info_get_display_name (fi));
 			}
 
-			camel_stream_write_string (
-				stream, name, cancellable, NULL);
-
-			g_free (description);
+			camel_stream_write_string (stream, name, cancellable, NULL);
 			g_free (name);
-
-			g_object_unref (file_info);
 		}
 
-		head = g_queue_peek_head_link (extensions);
+		for (iter = g_queue_peek_head_link (extensions); iter; iter = iter->next) {
 
-		for (link = head; link != NULL; link = g_list_next (link)) {
-			success = e_mail_formatter_extension_format (
-				E_MAIL_FORMATTER_EXTENSION (link->data),
-				formatter, context, part, stream, cancellable);
-			if (success)
-				break;
+			EMailFormatterExtension *ext;
+			ext = iter->data;
+			if (!ext)
+				continue;
+
+			if (e_mail_formatter_extension_format (ext, formatter,
+				context, part, stream, cancellable)) {
+				return TRUE;
+			}
 		}
 
-		return success;
+		return FALSE;
 	}
 
 	/* E_MAIL_FORMATTER_MODE_NORMAL: */
 
+	reg = e_mail_formatter_get_extension_registry (formatter);
+	extensions = e_mail_extension_registry_get_for_mime_type (
+				reg, empa->snoop_mime_type);
+
+	if (!extensions) {
+		extensions = e_mail_extension_registry_get_fallback (
+				reg, empa->snoop_mime_type);
+	}
+
 	text = e_mail_part_describe (part->part, empa->snoop_mime_type);
 	flags = e_mail_formatter_get_text_format_flags (formatter);
 	html = camel_text_to_html (
@@ -249,11 +255,13 @@ emfe_attachment_format (EMailFormatterExtension *extension,
 	g_free (str);
 	g_free (html);
 
-	if (extensions != NULL) {
+	if (extensions) {
+		GList *iter;
 		CamelStream *content_stream;
-		gboolean success = FALSE;
+		gboolean ok;
 
 		content_stream = camel_stream_mem_new ();
+		ok = FALSE;
 		if (empa->attachment_view_part_id != NULL) {
 			EMailPart *attachment_view_part;
 
@@ -268,7 +276,7 @@ emfe_attachment_format (EMailFormatterExtension *extension,
 			}
 
 			if (attachment_view_part != NULL) {
-				success = e_mail_formatter_format_as (
+				ok = e_mail_formatter_format_as (
 					formatter, context,
 					attachment_view_part,
 					content_stream, NULL,
@@ -277,46 +285,44 @@ emfe_attachment_format (EMailFormatterExtension *extension,
 			}
 
 		} else {
-			GList *head, *link;
 
-			head = g_queue_peek_head_link (extensions);
+			for (iter = g_queue_peek_head_link (extensions); iter; iter = iter->next) {
 
-			for (link = head; link != NULL; link = g_list_next (link)) {
-				success = e_mail_formatter_extension_format (
-					E_MAIL_FORMATTER_EXTENSION (link->data),
-					formatter, context,
-					part, content_stream,
-					cancellable);
-				if (success)
+				EMailFormatterExtension *ext;
+
+				ext = iter->data;
+				if (!ext)
+					continue;
+
+				if (e_mail_formatter_extension_format (
+						ext, formatter, context,
+						part, content_stream,
+						cancellable)) {
+					ok = TRUE;
 					break;
+				}
 			}
 		}
 
-		if (success) {
-			gchar *wrapper_element_id;
-
-			wrapper_element_id = g_strconcat (
-				attachment_part_id, ".wrapper", NULL);
-
+		if (ok) {
 			str = g_strdup_printf (
 				"<tr><td colspan=\"2\">"
 				"<div class=\"attachment-wrapper\" id=\"%s\">",
-				wrapper_element_id);
+				attachment_part_id);
 
 			camel_stream_write_string (
 				stream, str, cancellable, NULL);
+			g_free (str);
 
 			g_seekable_seek (
 				G_SEEKABLE (content_stream), 0,
 				G_SEEK_SET, cancellable, NULL);
 			camel_stream_write_to_stream (
-				content_stream, stream, cancellable, NULL);
+					content_stream, stream,
+					cancellable, NULL);
 
 			camel_stream_write_string (
 				stream, "</div></td></tr>", cancellable, NULL);
-
-			g_free (wrapper_element_id);
-			g_free (str);
 		}
 
 		g_object_unref (content_stream);
