@@ -54,7 +54,6 @@ format_short_headers (EMailFormatter *formatter,
                       guint32 flags,
                       GCancellable *cancellable)
 {
-	GtkTextDirection direction;
 	const gchar *charset;
 	CamelContentType *ct;
 	gchar *hdr_charset;
@@ -63,12 +62,11 @@ format_short_headers (EMailFormatter *formatter,
 	struct _camel_header_address *addrs = NULL;
 	struct _camel_header_raw *header;
 	GString *from;
+	gboolean is_rtl;
 
 	if (g_cancellable_is_cancelled (cancellable))
 		return;
 
-	direction = gtk_widget_get_default_direction ();
-
 	ct = camel_mime_part_get_content_type ((CamelMimePart *) part);
 	charset = camel_content_type_param (ct, "charset");
 	charset = camel_iconv_charset_name (charset);
@@ -81,9 +79,9 @@ format_short_headers (EMailFormatter *formatter,
 
 	g_string_append_printf (
 		buffer,
-		"<table class=\"header\" "
+		"<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" "
 		"id=\"__evo-short-headers\" style=\"display: %s\">",
-		flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED ? "table" : "none");
+		flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED ? "block" : "none");
 
 	header = ((CamelMimePart *) part)->headers;
 	while (header) {
@@ -98,10 +96,8 @@ format_short_headers (EMailFormatter *formatter,
 				formatter, tmp, addrs, header->name, FALSE,
 				!(flags & E_MAIL_FORMATTER_HEADER_FLAG_NOELIPSIZE));
 
-			if (tmp->len > 0)
-				g_string_printf (
-					from, "%s: %s",
-					_("From"), tmp->str);
+			if (tmp->len)
+				g_string_printf (from, _("From: %s"), tmp->str);
 			g_string_free (tmp, TRUE);
 
 		} else if (!g_ascii_strcasecmp (header->name, "Subject")) {
@@ -118,20 +114,20 @@ format_short_headers (EMailFormatter *formatter,
 
 	g_free (hdr_charset);
 
-	g_string_append (buffer, "<tr class=\"header\">");
-	if (direction == GTK_TEXT_DIR_RTL)
-		g_string_append (buffer, "<td class=\"header rtl\">");
-	else
-		g_string_append (buffer, "<td class=\"header ltr\">");
-	g_string_append (buffer, "<strong>");
-	if (subject != NULL && *subject != '\0')
-		g_string_append (buffer, subject);
-	else
-		g_string_append (buffer, _("(no subject)"));
-	g_string_append (buffer, "</strong>");
-	if (from->len > 0)
-		g_string_append_printf (buffer, " (%s)", from->str);
-	g_string_append (buffer, "</td></tr>");
+	is_rtl = gtk_widget_get_default_direction () == GTK_TEXT_DIR_RTL;
+	if (is_rtl) {
+		g_string_append_printf (
+			buffer,
+			"<tr><td width=\"100%%\" align=\"right\">%s%s%s <strong>%s</strong></td></tr>",
+			from->len ? "(" : "", from->str, from->len ? ")" : "",
+			subject ? subject : _("(no subject)"));
+	} else {
+		g_string_append_printf (
+			buffer,
+			"<tr><td><strong>%s</strong> %s%s%s</td></tr>",
+			subject ? subject : _("(no subject)"),
+			from->len ? "(" : "", from->str, from->len ? ")" : "");
+	}
 
 	g_string_append (buffer, "</table>");
 
@@ -249,23 +245,10 @@ format_full_headers (EMailFormatter *formatter,
 	gboolean mail_from_delegate = FALSE;
 	gchar *hdr_charset;
 	gchar *evolution_imagesdir;
-	const gchar *direction;
 
 	if (g_cancellable_is_cancelled (cancellable))
 		return;
 
-	switch (gtk_widget_get_default_direction ()) {
-		case GTK_TEXT_DIR_RTL:
-			direction = "rtl";
-			break;
-		case GTK_TEXT_DIR_LTR:
-			direction = "ltr";
-			break;
-		default:
-			direction = "inherit";
-			break;
-	}
-
 	ct = camel_mime_part_get_content_type ((CamelMimePart *) part);
 	charset = camel_content_type_param (ct, "charset");
 	charset = camel_iconv_charset_name (charset);
@@ -277,15 +260,12 @@ format_full_headers (EMailFormatter *formatter,
 
 	g_string_append_printf (
 		buffer,
-		"<table cellspacing=\"0\" cellpadding=\"0\" "
-		"border=\"0\" width=\"100%%\" "
-		"id=\"__evo-full-headers\" "
-		"style=\"display: %s; direction: %s;\">",
-		flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED ? "none" : "table",
-		direction);
+		"<table cellspacing=\"0\" cellpadding=\"0\" border=\"0\" "
+		"id=\"__evo-full-headers\" style=\"display: %s\" width=\"100%%\">",
+		flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED ? "none" : "block");
 
 	header = ((CamelMimePart *) part)->headers;
-	while (header != NULL) {
+	while (header) {
 		if (!g_ascii_strcasecmp (header->name, "Sender")) {
 			struct _camel_header_address *addrs;
 			GString *html;
@@ -295,15 +275,14 @@ format_full_headers (EMailFormatter *formatter,
 
 			html = g_string_new ("");
 			name = e_mail_formatter_format_address (
-				formatter, html, addrs, header->name, FALSE,
-				~(flags & E_MAIL_FORMATTER_HEADER_FLAG_NOELIPSIZE));
+					formatter, html, addrs, header->name, FALSE,
+					~(flags & E_MAIL_FORMATTER_HEADER_FLAG_NOELIPSIZE));
 
 			header_sender = html->str;
 			camel_header_address_list_clear (&addrs);
 
 			g_string_free (html, FALSE);
 			g_free (name);
-
 		} else if (!g_ascii_strcasecmp (header->name, "From")) {
 			struct _camel_header_address *addrs;
 			GString *html;
@@ -313,15 +292,14 @@ format_full_headers (EMailFormatter *formatter,
 
 			html = g_string_new ("");
 			name = e_mail_formatter_format_address (
-				formatter, html, addrs, header->name, FALSE,
-				!(flags & E_MAIL_FORMATTER_HEADER_FLAG_NOELIPSIZE));
+					formatter, html, addrs, header->name, FALSE,
+					!(flags & E_MAIL_FORMATTER_HEADER_FLAG_NOELIPSIZE));
 
 			header_from = html->str;
 			camel_header_address_list_clear (&addrs);
 
 			g_string_free (html, FALSE);
 			g_free (name);
-
 		} else if (!g_ascii_strcasecmp (header->name, "X-Evolution-Mail-From-Delegate")) {
 			mail_from_delegate = TRUE;
 		}
@@ -364,14 +342,14 @@ format_full_headers (EMailFormatter *formatter,
 	g_string_append (
 		buffer,
 		"<tr valign=\"top\"><td width=\"100%\">"
-		"<table class=\"header\">\n");
+		"<table border=0 cellpadding=\"0\">\n");
 
 	g_free (evolution_imagesdir);
 
 	/* dump selected headers */
 	if (mode & E_MAIL_FORMATTER_MODE_ALL_HEADERS) {
 		header = ((CamelMimePart *) part)->headers;
-		while (header != NULL) {
+		while (header) {
 			e_mail_formatter_format_header (
 				formatter, buffer, part, header,
 				E_MAIL_FORMATTER_HEADER_FLAG_NOCOLUMNS, charset);
@@ -393,7 +371,7 @@ format_full_headers (EMailFormatter *formatter,
 			mailer = !g_ascii_strcasecmp (h->name, "X-Evolution-Mailer");
 			face = !g_ascii_strcasecmp (h->name, "Face");
 
-			while (header != NULL) {
+			while (header) {
 				if (e_mail_formatter_get_show_sender_photo (formatter) &&
 					!photo_name && !g_ascii_strcasecmp (header->name, "From"))
 					photo_name = header->value;
@@ -464,9 +442,8 @@ format_full_headers (EMailFormatter *formatter,
 		gchar *name;
 
 		name = g_uri_escape_string (photo_name, NULL, FALSE);
-		g_string_append (
-			buffer,
-			"<td align=\"right\" valign=\"top\">");
+		g_string_append (buffer, "<td align=\"right\" valign=\"top\">");
+
 		g_string_append_printf (
 			buffer,
 			"<img src=\"mail://contact-photo?mailaddr=\" "
@@ -486,9 +463,7 @@ format_full_headers (EMailFormatter *formatter,
 			(const gchar *) face_header_value,
 			face_header_len, "image/png");
 
-		g_string_append (
-			buffer,
-			"<td align=\"right\" valign=\"top\">");
+		g_string_append (buffer, "<td align=\"right\" valign=\"top\">");
 		write_contact_picture (part, 48, buffer);
 		g_string_append (buffer, "</td>");
 
@@ -501,19 +476,16 @@ format_full_headers (EMailFormatter *formatter,
 		CamelMimePart *iconpart = NULL;
 
 		icon_info = gtk_icon_theme_lookup_icon (
-			gtk_icon_theme_get_default (),
-			"evolution", 16, GTK_ICON_LOOKUP_NO_SVG);
+				gtk_icon_theme_get_default (),
+				"evolution", 16, GTK_ICON_LOOKUP_NO_SVG);
 		if (icon_info != NULL) {
 			iconpart = load_picture_from_file (
-				"image/png",
-				gtk_icon_info_get_filename (icon_info),
+				"image/png", gtk_icon_info_get_filename (icon_info),
 				cancellable);
 			gtk_icon_info_free (icon_info);
 		}
-		if (iconpart != NULL) {
-			g_string_append (
-				buffer,
-				"<td align=\"right\" valign=\"top\">");
+		if (iconpart) {
+			g_string_append (buffer, "<td align=\"right\" valign=\"top\">");
 			write_contact_picture (iconpart, 16, buffer);
 			g_string_append (buffer, "</td>");
 
@@ -533,12 +505,7 @@ emfe_headers_format (EMailFormatterExtension *extension,
                      GCancellable *cancellable)
 {
 	GString *buffer;
-	const GdkColor white = { 0, G_MAXUINT16, G_MAXUINT16, G_MAXUINT16 };
-	const GdkColor *body_color = &white;
-	const GdkColor *header_color;
-	const gchar *direction;
-	gboolean is_collapsable;
-	gboolean is_collapsed;
+	gint bg_color;
 
 	if (g_cancellable_is_cancelled (cancellable))
 		return FALSE;
@@ -546,73 +513,47 @@ emfe_headers_format (EMailFormatterExtension *extension,
 	if (!part->part)
 		return FALSE;
 
-	switch (gtk_widget_get_default_direction ()) {
-		case GTK_TEXT_DIR_RTL:
-			direction = "rtl";
-			break;
-		case GTK_TEXT_DIR_LTR:
-			direction = "ltr";
-			break;
-		default:
-			direction = "inherit";
-			break;
-	}
-
-	is_collapsable =
-		(context->flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSABLE);
-
-	is_collapsed =
-		(context->flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED);
-
 	buffer = g_string_new ("");
 
-	if (context->mode != E_MAIL_FORMATTER_MODE_PRINTING)
-		body_color = e_mail_formatter_get_color (
-			formatter, E_MAIL_FORMATTER_COLOR_BODY);
-
-	header_color = e_mail_formatter_get_color (
-		formatter, E_MAIL_FORMATTER_COLOR_HEADER);
+	if (context->mode == E_MAIL_FORMATTER_MODE_PRINTING) {
+		GdkRGBA white = { 1.0, 1.0, 1.0, 1.0};
+		bg_color = e_rgba_to_value (&white);
+	} else {
+		bg_color = e_rgba_to_value (
+				e_mail_formatter_get_color (
+					formatter, E_MAIL_FORMATTER_COLOR_BODY));
+	}
 
 	g_string_append_printf (
 		buffer,
 		"<div class=\"headers\" style=\"background: #%06x;\" id=\"%s\">"
-		"<table border=\"0\" width=\"100%%\" "
-		"style=\"color: #%06x; direction: %s\">"
-		"<tr>",
-		e_color_to_value ((GdkColor *) body_color),
+		"<table border=\"0\" width=\"100%%\" style=\"color: #%06x;\">\n"
+		"<tr><td valign=\"top\" width=\"16\">\n",
+		bg_color,
 		part->id,
-		e_color_to_value ((GdkColor *) header_color),
-		direction);
+		e_rgba_to_value (
+			e_mail_formatter_get_color (
+				formatter,
+				E_MAIL_FORMATTER_COLOR_HEADER)));
 
-	if (is_collapsable)
+	if (context->flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSABLE) {
 		g_string_append_printf (
 			buffer,
-			"<td valign=\"top\" width=\"16\">"
 			"<img src=\"evo-file://%s/%s\" class=\"navigable\" "
-			"     id=\"__evo-collapse-headers-img\" />"
-			"</td>",
+			"id=\"__evo-collapse-headers-img\" />"
+			"</td><td>",
 			EVOLUTION_IMAGESDIR,
-			is_collapsed ? "plus.png" : "minus.png");
+			(context->flags & E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED) ?
+				"plus.png" : "minus.png");
 
-	g_string_append (buffer, "<td>");
+		format_short_headers (formatter, buffer,
+			(CamelMedium *) part->part, context->flags, cancellable);
+	}
 
-	if (is_collapsable)
-		format_short_headers (
-			formatter, buffer,
-			CAMEL_MEDIUM (part->part),
-			context->flags,
-			cancellable);
+	format_full_headers (formatter, buffer,
+		(CamelMedium *) part->part, context->mode, context->flags, cancellable);
 
-	format_full_headers (
-		formatter, buffer,
-		CAMEL_MEDIUM (part->part),
-		context->mode,
-		context->flags,
-		cancellable);
-
-	g_string_append (buffer, "</td>");
-
-	g_string_append (buffer, "</tr></table></div>");
+	g_string_append (buffer, "</td></tr></table></div>");
 
 	camel_stream_write_string (stream, buffer->str, cancellable, NULL);
 
