@@ -58,42 +58,35 @@ write_attachments_list (EMailFormatter *formatter,
 	for (link = attachments; link != NULL; link = g_slist_next (link)) {
 		EMailPartAttachment *part = link->data;
 		EAttachment *attachment;
-		GFileInfo *file_info;
-		const gchar *display_name;
-		gchar *description;
-		gchar *name;
-		gchar *size;
+		GFileInfo *fi;
+		gchar *name, *size;
 
 		if (!part)
 			continue;
 
 		attachment = part->attachment;
-		file_info = e_attachment_ref_file_info (attachment);
-		if (file_info == NULL)
+		fi = e_attachment_get_file_info (attachment);
+		if (!fi)
 			continue;
 
-		display_name = g_file_info_get_display_name (file_info);
-		description = e_attachment_dup_description (attachment);
-
-		if (description != NULL && *description != '\0') {
+		if (e_attachment_get_description (attachment) &&
+                    *e_attachment_get_description (attachment)) {
 			name = g_strdup_printf (
 				"%s (%s)",
-				description, display_name);
+				e_attachment_get_description (attachment),
+				g_file_info_get_display_name (fi));
 		} else {
-			name = g_strdup (display_name);
+			name = g_strdup (g_file_info_get_display_name (fi));
 		}
 
-		size = g_format_size (g_file_info_get_size (file_info));
+		size = g_format_size (g_file_info_get_size (fi));
 
 		g_string_append_printf (
 			str, "<tr><td>%s</td><td>%s</td></tr>\n",
 			name, size);
 
-		g_free (description);
 		g_free (name);
 		g_free (size);
-
-		g_object_unref (file_info);
 	}
 
 	g_string_append (str, "</table>\n");
@@ -182,22 +175,21 @@ mail_formatter_print_run (EMailFormatter *formatter,
 }
 
 static void
-mail_formatter_set_style (EMailFormatter *formatter,
-                          GtkStyle *style,
-                          GtkStateType state)
+mail_formatter_update_style (EMailFormatter *formatter,
+			     GtkStateFlags state)
 {
 	EMailFormatterClass *formatter_class;
 
 	/* White background */
-	GdkColor body_color = { 0, G_MAXUINT16, G_MAXUINT16, G_MAXUINT16 };
+	GdkRGBA body_color = { 1.0, 1.0, 1.0, 1.0 };
 	/* Black text */
-	GdkColor text_color = { 0, 0, 0, 0 };
+	GdkRGBA text_color = { 0.0, 0.0, 0.0, 0.0 };
 
 	g_object_freeze_notify (G_OBJECT (formatter));
 
 	/* Set the other colors */
 	formatter_class = E_MAIL_FORMATTER_CLASS (e_mail_formatter_print_parent_class);
-	formatter_class->set_style (formatter, style, state);
+	formatter_class->update_style (formatter, state);
 
 	e_mail_formatter_set_color (
 		formatter, E_MAIL_FORMATTER_COLOR_FRAME, &body_color);
@@ -232,7 +224,7 @@ e_mail_formatter_print_class_init (EMailFormatterPrintClass *class)
 
 	formatter_class = E_MAIL_FORMATTER_CLASS (class);
 	formatter_class->run = mail_formatter_print_run;
-	formatter_class->set_style = mail_formatter_set_style;
+	formatter_class->update_style = mail_formatter_update_style;
 
 	object_class = G_OBJECT_CLASS (class);
 	object_class->finalize = e_mail_formatter_print_finalize;
