@@ -72,10 +72,10 @@ emfe_source_format (EMailFormatterExtension *extension,
 			buffer,
 			"<div class=\"part-container\" "
 			"style=\"border: 0; background: #%06x; color: #%06x;\" >",
-			e_color_to_value ((GdkColor *)
+			e_rgba_to_value (
 				e_mail_formatter_get_color (
 					formatter, E_MAIL_FORMATTER_COLOR_BODY)),
-			e_color_to_value ((GdkColor *)
+			e_rgba_to_value (
 				e_mail_formatter_get_color (
 					formatter, E_MAIL_FORMATTER_COLOR_TEXT)));
 	} else {
@@ -84,13 +84,13 @@ emfe_source_format (EMailFormatterExtension *extension,
 			"<div class=\"part-container\" "
 			"style=\"border-color: #%06x; background: #%06x; color: #%06x;\">"
 			"<div class=\"part-container-inner-margin pre\">\n",
-			e_color_to_value ((GdkColor *)
+			e_rgba_to_value (
 				e_mail_formatter_get_color (
 					formatter, E_MAIL_FORMATTER_COLOR_FRAME)),
-			e_color_to_value ((GdkColor *)
+			e_rgba_to_value (
 				e_mail_formatter_get_color (
 					formatter, E_MAIL_FORMATTER_COLOR_BODY)),
-			e_color_to_value ((GdkColor *)
+			e_rgba_to_value (
 				e_mail_formatter_get_color (
 					formatter, E_MAIL_FORMATTER_COLOR_TEXT)));
 	}
