@@ -27,6 +27,8 @@
 #include <gdk/gdk.h>
 #include <glib/gi18n.h>
 
+#include "libemail-engine/e-mail-enumtypes.h"
+
 #define d(x)
 
 /* internal formatter extensions */
@@ -165,7 +167,7 @@ e_mail_formatter_set_property (GObject *object,
 		case PROP_IMAGE_LOADING_POLICY:
 			e_mail_formatter_set_image_loading_policy (
 				E_MAIL_FORMATTER (object),
-				g_value_get_int (value));
+				g_value_get_enum (value));
 			return;
 
 		case PROP_MARK_CITATIONS:
@@ -263,7 +265,7 @@ e_mail_formatter_get_property (GObject *object,
 			return;
 
 		case PROP_IMAGE_LOADING_POLICY:
-			g_value_set_int (
+			g_value_set_enum (
 				value,
 				e_mail_formatter_get_image_loading_policy (
 				E_MAIL_FORMATTER (object)));
@@ -464,34 +466,42 @@ mail_formatter_run (EMailFormatter *formatter,
 }
 
 static void
-mail_formatter_set_style (EMailFormatter *formatter,
-                          GtkStyle *style,
-                          GtkStateType state)
+mail_formatter_update_style (EMailFormatter *formatter,
+			     GtkStateFlags state)
 {
-	GdkColor *color;
-	EMailFormatterColor type;
+	GtkStyleContext *style_context;
+	GtkWidgetPath *widget_path;
+	GdkRGBA rgba;
 
 	g_object_freeze_notify (G_OBJECT (formatter));
 
-	color = &style->bg[state];
-	type = E_MAIL_FORMATTER_COLOR_BODY;
-	e_mail_formatter_set_color (formatter, type, color);
+	/* derive colors from top-level window */
+	style_context = gtk_style_context_new ();
+	widget_path = gtk_widget_path_new ();
+	gtk_widget_path_append_type (widget_path, GTK_TYPE_WINDOW);
+	gtk_style_context_set_path (style_context, widget_path);
 
-	color = &style->base[GTK_STATE_NORMAL];
-	type = E_MAIL_FORMATTER_COLOR_CONTENT;
-	e_mail_formatter_set_color  (formatter, type, color);
+	gtk_style_context_get_background_color (style_context, state, &rgba);
+	e_mail_formatter_set_color (formatter, E_MAIL_FORMATTER_COLOR_BODY, &rgba);
 
-	color = &style->dark[state];
-	type = E_MAIL_FORMATTER_COLOR_FRAME;
-	e_mail_formatter_set_color  (formatter, type, color);
+	rgba.red *= 0.8;
+	rgba.green *= 0.8;
+	rgba.blue *= 0.8;
+	e_mail_formatter_set_color (formatter, E_MAIL_FORMATTER_COLOR_FRAME, &rgba);
 
-	color = &style->fg[state];
-	type = E_MAIL_FORMATTER_COLOR_HEADER;
-	e_mail_formatter_set_color  (formatter, type, color);
+	gtk_style_context_get_color (style_context, state, &rgba);
+	e_mail_formatter_set_color (formatter, E_MAIL_FORMATTER_COLOR_HEADER, &rgba);
 
-	color = &style->text[state];
-	type = E_MAIL_FORMATTER_COLOR_TEXT;
-	e_mail_formatter_set_color  (formatter, type, color);
+	gtk_style_context_add_class (style_context, GTK_STYLE_CLASS_ENTRY);
+
+	gtk_style_context_get_background_color (style_context, state | GTK_STATE_FLAG_FOCUSED, &rgba);
+	e_mail_formatter_set_color  (formatter, E_MAIL_FORMATTER_COLOR_CONTENT, &rgba);
+
+	gtk_style_context_get_color (style_context, state | GTK_STATE_FLAG_FOCUSED, &rgba);
+	e_mail_formatter_set_color (formatter, E_MAIL_FORMATTER_COLOR_TEXT, &rgba);
+
+	gtk_widget_path_free (widget_path);
+	g_object_unref (style_context);
 
 	g_object_thaw_notify (G_OBJECT (formatter));
 }
@@ -540,7 +550,7 @@ static void
 e_mail_formatter_class_init (EMailFormatterClass *class)
 {
 	GObjectClass *object_class;
-	GdkColor *color;
+	GdkRGBA *rgba;
 
 	e_mail_formatter_parent_class = g_type_class_peek_parent (class);
 	g_type_class_add_private (class, sizeof (EMailFormatterPrivate));
@@ -553,22 +563,22 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 
 	class->context_size = sizeof (EMailFormatterContext);
 	class->run = mail_formatter_run;
-	class->set_style = mail_formatter_set_style;
+	class->update_style = mail_formatter_update_style;
 
-	color = &class->colors[E_MAIL_FORMATTER_COLOR_BODY];
-	gdk_color_parse ("#eeeeee", color);
+	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_BODY];
+	gdk_rgba_parse (rgba, "#eeeeee");
 
-	color = &class->colors[E_MAIL_FORMATTER_COLOR_CONTENT];
-	gdk_color_parse ("#ffffff", color);
+	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_CONTENT];
+	gdk_rgba_parse (rgba, "#ffffff");
 
-	color = &class->colors[E_MAIL_FORMATTER_COLOR_FRAME];
-	gdk_color_parse ("#3f3f3f", color);
+	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_FRAME];
+	gdk_rgba_parse (rgba, "#3f3f3f");
 
-	color = &class->colors[E_MAIL_FORMATTER_COLOR_HEADER];
-	gdk_color_parse ("#eeeeee", color);
+	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_HEADER];
+	gdk_rgba_parse (rgba, "#eeeeee");
 
-	color = &class->colors[E_MAIL_FORMATTER_COLOR_TEXT];
-	gdk_color_parse ("#000000", color);
+	rgba = &class->colors[E_MAIL_FORMATTER_COLOR_TEXT];
+	gdk_rgba_parse (rgba, "#000000");
 
 	g_object_class_install_property (
 		object_class,
@@ -577,7 +587,7 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 			"body-color",
 			"Body Color",
 			NULL,
-			GDK_TYPE_COLOR,
+			GDK_TYPE_RGBA,
 			G_PARAM_READWRITE));
 
 	g_object_class_install_property (
@@ -587,7 +597,7 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 			"citation-color",
 			"Citation Color",
 			NULL,
-			GDK_TYPE_COLOR,
+			GDK_TYPE_RGBA,
 			G_PARAM_READWRITE));
 
 	g_object_class_install_property (
@@ -597,7 +607,7 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 			"content-color",
 			"Content Color",
 			NULL,
-			GDK_TYPE_COLOR,
+			GDK_TYPE_RGBA,
 			G_PARAM_READWRITE));
 
 	g_object_class_install_property (
@@ -607,7 +617,7 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 			"frame-color",
 			"Frame Color",
 			NULL,
-			GDK_TYPE_COLOR,
+			GDK_TYPE_RGBA,
 			G_PARAM_READWRITE));
 
 	g_object_class_install_property (
@@ -617,19 +627,17 @@ e_mail_formatter_class_init (EMailFormatterClass *class)
 			"header-color",
 			"Header Color",
 			NULL,
-			GDK_TYPE_COLOR,
+			GDK_TYPE_RGBA,
 			G_PARAM_READWRITE));
 
-	/* FIXME Make this a proper enum property. */
 	g_object_class_install_property (
 		object_class,
 		PROP_IMAGE_LOADING_POLICY,
-		g_param_spec_int (
+		g_param_spec_enum (
 			"image-loading-policy",
 			"Image Loading Policy",
 			NULL,
-			E_MAIL_IMAGE_LOADING_POLICY_NEVER,
-			E_MAIL_IMAGE_LOADING_POLICY_ALWAYS,
+			E_TYPE_MAIL_IMAGE_LOADING_POLICY,
 			E_MAIL_IMAGE_LOADING_POLICY_NEVER,
 			G_PARAM_READWRITE));
 
@@ -1067,13 +1075,13 @@ e_mail_formatter_get_html_header (EMailFormatter *formatter)
 		"  table th { color: #%06x; font-weight: bold; }\n"
 		"</style>\n"
 		"</head><body bgcolor=\"#%06x\" text=\"#%06x\">",
-		e_color_to_value ((GdkColor *)
+		e_rgba_to_value (
 			e_mail_formatter_get_color (
 				formatter, E_MAIL_FORMATTER_COLOR_HEADER)),
-		e_color_to_value ((GdkColor *)
+		e_rgba_to_value (
 			e_mail_formatter_get_color (
 				formatter, E_MAIL_FORMATTER_COLOR_BODY)),
-		e_color_to_value ((GdkColor *)
+		e_rgba_to_value (
 			e_mail_formatter_get_color (
 				formatter, E_MAIL_FORMATTER_COLOR_TEXT)));
 }
@@ -1097,9 +1105,9 @@ e_mail_formatter_get_text_format_flags (EMailFormatter *formatter)
 	return E_MAIL_FORMATTER_GET_CLASS (formatter)->text_html_flags;
 }
 
-const GdkColor *
+const GdkRGBA *
 e_mail_formatter_get_color (EMailFormatter *formatter,
-                            EMailFormatterColor type)
+                            EMailFormatterColorType type)
 {
 	g_return_val_if_fail (E_IS_MAIL_FORMATTER (formatter), NULL);
 	g_return_val_if_fail (type < E_MAIL_FORMATTER_NUM_COLOR_TYPES, NULL);
@@ -1109,10 +1117,10 @@ e_mail_formatter_get_color (EMailFormatter *formatter,
 
 void
 e_mail_formatter_set_color (EMailFormatter *formatter,
-                            EMailFormatterColor type,
-                            const GdkColor *color)
+                            EMailFormatterColorType type,
+                            const GdkRGBA *color)
 {
-	GdkColor *format_color;
+	GdkRGBA *format_color;
 	const gchar *property_name;
 
 	g_return_if_fail (E_IS_MAIL_FORMATTER (formatter));
@@ -1121,7 +1129,7 @@ e_mail_formatter_set_color (EMailFormatter *formatter,
 
 	format_color = &E_MAIL_FORMATTER_GET_CLASS (formatter)->colors[type];
 
-	if (gdk_color_equal (color, format_color))
+	if (gdk_rgba_equal (color, format_color))
 		return;
 
 	format_color->red   = color->red;
@@ -1155,19 +1163,17 @@ e_mail_formatter_set_color (EMailFormatter *formatter,
 }
 
 void
-e_mail_formatter_set_style (EMailFormatter *formatter,
-                            GtkStyle *style,
-                            GtkStateType state)
+e_mail_formatter_update_style (EMailFormatter *formatter,
+			       GtkStateFlags state)
 {
 	EMailFormatterClass *formatter_class;
 
 	g_return_if_fail (E_IS_MAIL_FORMATTER (formatter));
-	g_return_if_fail (GTK_IS_STYLE (style));
 
 	formatter_class = E_MAIL_FORMATTER_GET_CLASS (formatter);
-	g_return_if_fail (formatter_class->set_style != NULL);
+	g_return_if_fail (formatter_class->update_style != NULL);
 
-	formatter_class->set_style (formatter, style, state);
+	formatter_class->update_style (formatter, state);
 }
 
 EMailImageLoadingPolicy
@@ -1540,8 +1546,8 @@ e_mail_formatter_add_header_struct (EMailFormatter *formatter,
 
 void
 e_mail_formatter_remove_header (EMailFormatter *formatter,
-                                const gchar *name,
-                                const gchar *value)
+				const gchar *name,
+				const gchar *value)
 {
 	GList *iter = NULL;
 
