@@ -23,7 +23,6 @@
 #include <libemail-engine/e-mail-enums.h>
 
 #include <em-format/e-mail-extension-registry.h>
-#include <em-format/e-mail-formatter-enums.h>
 #include <em-format/e-mail-part-list.h>
 
 /* Standard GObject macros */
@@ -47,6 +46,38 @@
 
 G_BEGIN_DECLS;
 
+typedef enum {
+	E_MAIL_FORMATTER_MODE_INVALID			= -1,
+	E_MAIL_FORMATTER_MODE_NORMAL			= 0,
+	E_MAIL_FORMATTER_MODE_SOURCE,
+	E_MAIL_FORMATTER_MODE_RAW,
+	E_MAIL_FORMATTER_MODE_CID,
+	E_MAIL_FORMATTER_MODE_PRINTING,
+	E_MAIL_FORMATTER_MODE_ALL_HEADERS
+} EMailFormatterMode;
+
+typedef enum {
+	E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSABLE	= 1 << 0,
+	E_MAIL_FORMATTER_HEADER_FLAG_COLLAPSED		= 1 << 1,
+	E_MAIL_FORMATTER_HEADER_FLAG_HTML		= 1 << 2,
+	E_MAIL_FORMATTER_HEADER_FLAG_NOCOLUMNS		= 1 << 3,
+	E_MAIL_FORMATTER_HEADER_FLAG_BOLD		= 1 << 4,
+	E_MAIL_FORMATTER_HEADER_FLAG_NODEC		= 1 << 5,
+	E_MAIL_FORMATTER_HEADER_FLAG_HIDDEN		= 1 << 6,
+	E_MAIL_FORMATTER_HEADER_FLAG_NOLINKS		= 1 << 7,
+	E_MAIL_FORMATTER_HEADER_FLAG_NOELIPSIZE		= 1 << 8
+} EMailFormatterHeaderFlags;
+
+typedef enum {
+	E_MAIL_FORMATTER_COLOR_BODY,		/* header area background */
+	E_MAIL_FORMATTER_COLOR_CITATION,	/* citation font color */
+	E_MAIL_FORMATTER_COLOR_CONTENT,		/* message area background */
+	E_MAIL_FORMATTER_COLOR_FRAME,		/* frame around message area */
+	E_MAIL_FORMATTER_COLOR_HEADER,		/* header font color */
+	E_MAIL_FORMATTER_COLOR_TEXT,		/* message font color */
+	E_MAIL_FORMATTER_NUM_COLOR_TYPES
+} EMailFormatterColorType;
+
 typedef struct _EMailFormatter EMailFormatter;
 typedef struct _EMailFormatterClass EMailFormatterClass;
 typedef struct _EMailFormatterPrivate EMailFormatterPrivate;
@@ -79,7 +110,7 @@ struct _EMailFormatterClass {
 	CamelMimeFilterToHTMLFlags text_html_flags;
 
 	/* Colors should apply globally */
-	GdkColor colors[E_MAIL_FORMATTER_NUM_COLOR_TYPES];
+	GdkRGBA colors[E_MAIL_FORMATTER_NUM_COLOR_TYPES];
 
 	/* sizeof(EMailFormatterContext) or some derivative struct */
 	gsize context_size;
@@ -89,9 +120,8 @@ struct _EMailFormatterClass {
 						 CamelStream *stream,
 						 GCancellable *cancellable);
 
-	void		(*set_style)		(EMailFormatter *formatter,
-						 GtkStyle *style,
-						 GtkStateType state);
+	void		(*update_style)		(EMailFormatter *formatter,
+						 GtkStateFlags state);
 
 	/* Signals */
 	void		(*need_redraw)		(EMailFormatter *formatter);
@@ -144,15 +174,14 @@ CamelMimeFilterToHTMLFlags
 		e_mail_formatter_get_text_format_flags
 						(EMailFormatter *formatter);
 
-const GdkColor *
+const GdkRGBA *
 		e_mail_formatter_get_color	(EMailFormatter *formatter,
-						 EMailFormatterColor type);
+						 EMailFormatterColorType type);
 void		e_mail_formatter_set_color	(EMailFormatter *efh,
-						 EMailFormatterColor type,
-						 const GdkColor *color);
-void		e_mail_formatter_set_style	(EMailFormatter *formatter,
-						 GtkStyle *style,
-						 GtkStateType state);
+						 EMailFormatterColorType type,
+						 const GdkRGBA *color);
+void		e_mail_formatter_update_style	(EMailFormatter *formatter,
+						 GtkStateFlags state);
 
 EMailImageLoadingPolicy
 		e_mail_formatter_get_image_loading_policy
@@ -173,11 +202,11 @@ void		e_mail_formatter_set_show_sender_photo
 						(EMailFormatter *formatter,
 						 gboolean show_sender_photo);
 
-gboolean	e_mail_formatter_get_animate_images
-						(EMailFormatter *formatter);
-void		e_mail_formatter_set_animate_images
-						(EMailFormatter *formatter,
-						 gboolean animate_images);
+gboolean        e_mail_formatter_get_animate_images
+                                                (EMailFormatter *formatter);
+void            e_mail_formatter_set_animate_images
+                                                (EMailFormatter *formatter,
+                                                 gboolean animate_images);
 
 gboolean	e_mail_formatter_get_show_real_date
 						(EMailFormatter *formatter);
