@@ -38,7 +38,7 @@
 typedef struct _AsyncContext AsyncContext;
 
 struct _AsyncContext {
-	CamelFolder *folder;
+	CamelFolder *sent_folder;
 
 	CamelMimeMessage *message;
 	CamelMessageInfo *info;
@@ -48,8 +48,6 @@ struct _AsyncContext {
 
 	CamelFilterDriver *driver;
 
-	CamelService *transport;
-
 	GCancellable *cancellable;
 	gint io_priority;
 
@@ -62,13 +60,15 @@ struct _AsyncContext {
 
 	gchar *folder_uri;
 	gchar *message_uid;
+	gchar *transport_uid;
+	gchar *sent_folder_uri;
 };
 
 static void
 async_context_free (AsyncContext *context)
 {
-	if (context->folder != NULL)
-		g_object_unref (context->folder);
+	if (context->sent_folder != NULL)
+		g_object_unref (context->sent_folder);
 
 	if (context->message != NULL)
 		g_object_unref (context->message);
@@ -85,9 +85,6 @@ async_context_free (AsyncContext *context)
 	if (context->driver != NULL)
 		g_object_unref (context->driver);
 
-	if (context->transport != NULL)
-		g_object_unref (context->transport);
-
 	if (context->cancellable != NULL) {
 		camel_operation_pop_message (context->cancellable);
 		g_object_unref (context->cancellable);
@@ -104,6 +101,8 @@ async_context_free (AsyncContext *context)
 
 	g_free (context->folder_uri);
 	g_free (context->message_uid);
+	g_free (context->transport_uid);
+	g_free (context->sent_folder_uri);
 
 	g_slice_free (AsyncContext, context);
 }
@@ -516,40 +515,85 @@ mail_session_send_to_thread (GSimpleAsyncResult *simple,
                              GCancellable *cancellable)
 {
 	AsyncContext *context;
-	CamelProvider *provider;
-	CamelFolder *folder = NULL;
 	CamelFolder *local_sent_folder;
 	CamelServiceConnectionStatus status;
 	GString *error_messages;
 	gboolean copy_to_sent = TRUE;
-	gboolean did_connect = FALSE;
 	guint ii;
 	GError *error = NULL;
 
 	context = g_simple_async_result_get_op_res_gpointer (simple);
 
-	if (camel_address_length (context->recipients) == 0)
-		goto skip_send;
-
 	/* Send the message to all recipients. */
+	if (camel_address_length (context->recipients) > 0) {
+		CamelProvider *provider;
+		CamelService *service;
+		gboolean did_connect = FALSE;
 
-	/* XXX Leave this untranslated in gnome-3-8.
-	 *     It was added during the string freeze,
-	 *     but should rarely ever be seen by users. */
-	if (context->transport == NULL) {
-		g_simple_async_result_set_error (
-			simple, CAMEL_SERVICE_ERROR,
-			CAMEL_SERVICE_ERROR_UNAVAILABLE,
-			"No mail transport service available");
-		return;
-	}
+		service = camel_session_ref_service (
+			CAMEL_SESSION (session), context->transport_uid);
 
-	status = camel_service_get_connection_status (context->transport);
-	if (status != CAMEL_SERVICE_CONNECTED) {
-		did_connect = TRUE;
+		if (service == NULL) {
+			g_simple_async_result_set_error (
+				simple, CAMEL_SERVICE_ERROR,
+				CAMEL_SERVICE_ERROR_URL_INVALID,
+				_("No mail service found with UID '%s'"),
+				context->transport_uid);
+			return;
+		}
 
-		camel_service_connect_sync (
-			context->transport, cancellable, &error);
+		if (!CAMEL_IS_TRANSPORT (service)) {
+			g_simple_async_result_set_error (
+				simple, CAMEL_SERVICE_ERROR,
+				CAMEL_SERVICE_ERROR_URL_INVALID,
+				_("UID '%s' is not a mail transport"),
+				context->transport_uid);
+			g_object_unref (service);
+			return;
+		}
+
+		provider = camel_service_get_provider (service);
+		if ((provider->flags & CAMEL_PROVIDER_IS_REMOTE) != 0 &&
+		    !camel_session_get_online (CAMEL_SESSION (session))) {
+			/* silently ignore */
+			g_object_unref (service);
+			return;
+		}
+
+		status = camel_service_get_connection_status (service);
+		if (status != CAMEL_SERVICE_CONNECTED) {
+			did_connect = TRUE;
+
+			camel_service_connect_sync (
+				service, cancellable, &error);
+
+			if (error != NULL) {
+				g_simple_async_result_take_error (simple, error);
+				g_object_unref (service);
+				return;
+			}
+		}
+
+		if (provider->flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)
+			copy_to_sent = FALSE;
+
+		camel_transport_send_to_sync (
+			CAMEL_TRANSPORT (service),
+			context->message, context->from,
+			context->recipients, cancellable, &error);
+
+		if (did_connect) {
+			/* if the cancellable is cancelled, then the disconnect will not run,
+			 * thus reset it to ensure the service will be properly disconnected */
+			if (cancellable)
+				g_cancellable_reset (cancellable);
+
+			camel_service_disconnect_sync (
+				service, error == NULL,
+				cancellable, error ? NULL : &error);
+		}
+
+		g_object_unref (service);
 
 		if (error != NULL) {
 			g_simple_async_result_take_error (simple, error);
@@ -557,38 +601,6 @@ mail_session_send_to_thread (GSimpleAsyncResult *simple,
 		}
 	}
 
-	provider = camel_service_get_provider (context->transport);
-
-	if (provider->flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)
-		copy_to_sent = FALSE;
-
-	camel_transport_send_to_sync (
-		CAMEL_TRANSPORT (context->transport),
-		context->message, context->from,
-		context->recipients, cancellable, &error);
-
-	if (did_connect) {
-		/* Disconnect regardless of error or cancellation,
-		 * but be mindful of these conditions when calling
-		 * camel_service_disconnect_sync(). */
-		if (g_cancellable_is_cancelled (cancellable)) {
-			camel_service_disconnect_sync (
-				context->transport, FALSE, NULL, NULL);
-		} else if (error != NULL) {
-			camel_service_disconnect_sync (
-				context->transport, FALSE, cancellable, NULL);
-		} else {
-			camel_service_disconnect_sync (
-				context->transport, TRUE, cancellable, &error);
-		}
-
-		if (error != NULL) {
-			g_simple_async_result_take_error (simple, error);
-			return;
-		}
-	}
-
-skip_send:
 	/* Post the message to requested folders. */
 	for (ii = 0; ii < context->post_to_uris->len; ii++) {
 		CamelFolder *folder;
@@ -656,19 +668,32 @@ skip_send:
 		e_mail_session_get_local_folder (
 		session, E_MAIL_LOCAL_FOLDER_SENT);
 
-	folder = e_mail_session_get_fcc_for_message_sync (
-		session, context->message, cancellable, &error);
+	/* Try to extract a CamelFolder from the Sent folder URI. */
+	if (context->sent_folder_uri != NULL) {
+		context->sent_folder = e_mail_session_uri_to_folder_sync (
+			session, context->sent_folder_uri, 0,
+			cancellable, &error);
+		if (error != NULL) {
+			g_warn_if_fail (context->sent_folder == NULL);
+			if (error_messages->len > 0)
+				g_string_append (error_messages, "\n\n");
+			g_string_append_printf (
+				error_messages,
+				_("Failed to append to %s: %s\n"
+				"Appending to local 'Sent' folder instead."),
+				context->sent_folder_uri, error->message);
+			g_clear_error (&error);
+		}
+	}
 
-	/* Sanity check. */
-	g_return_if_fail (
-		((folder != NULL) && (error == NULL)) ||
-		((folder == NULL) && (error != NULL)));
+	/* Fall back to the local Sent folder. */
+	if (context->sent_folder == NULL)
+		context->sent_folder = g_object_ref (local_sent_folder);
 
 	/* Append the message. */
-	if (folder != NULL)
-		camel_folder_append_message_sync (
-			folder, context->message,
-			context->info, NULL, cancellable, &error);
+	camel_folder_append_message_sync (
+		context->sent_folder, context->message,
+		context->info, NULL, cancellable, &error);
 
 	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
 		goto exit;
@@ -676,10 +701,13 @@ skip_send:
 	if (error == NULL)
 		goto cleanup;
 
-	if (folder != NULL && folder != local_sent_folder) {
+	/* If appending to a remote Sent folder failed,
+	 * try appending to the local Sent folder. */
+	if (context->sent_folder != local_sent_folder) {
 		const gchar *description;
 
-		description = camel_folder_get_description (folder);
+		description = camel_folder_get_description (
+			context->sent_folder);
 
 		if (error_messages->len > 0)
 			g_string_append (error_messages, "\n\n");
@@ -688,12 +716,6 @@ skip_send:
 			_("Failed to append to %s: %s\n"
 			"Appending to local 'Sent' folder instead."),
 			description, error->message);
-	}
-
-	/* If appending to a remote Sent folder failed,
-	 * try appending to the local Sent folder. */
-	if (folder != local_sent_folder) {
-
 		g_clear_error (&error);
 
 		camel_folder_append_message_sync (
@@ -754,11 +776,9 @@ exit:
 	}
 
 	/* Synchronize the Sent folder. */
-	if (folder != NULL) {
+	if (context->sent_folder != NULL)
 		camel_folder_synchronize_sync (
-			folder, FALSE, cancellable, NULL);
-		g_object_unref (folder);
-	}
+			context->sent_folder, FALSE, cancellable, NULL);
 
 	g_string_free (error_messages, TRUE);
 }
@@ -767,16 +787,17 @@ static guint32
 get_message_size (CamelMimeMessage *message,
                   GCancellable *cancellable)
 {
+	guint32 res = 0;
 	CamelStream *null;
-	guint32 size;
+
+	g_return_val_if_fail (message != NULL, 0);
 
 	null = camel_stream_null_new ();
-	camel_data_wrapper_write_to_stream_sync (
-		CAMEL_DATA_WRAPPER (message), null, cancellable, NULL);
-	size = CAMEL_STREAM_NULL (null)->written;
+	camel_data_wrapper_write_to_stream_sync (CAMEL_DATA_WRAPPER (message), null, cancellable, NULL);
+	res = CAMEL_STREAM_NULL (null)->written;
 	g_object_unref (null);
 
-	return size;
+	return res;
 }
 
 void
@@ -795,28 +816,75 @@ e_mail_session_send_to (EMailSession *session,
 	CamelAddress *recipients;
 	CamelMedium *medium;
 	CamelMessageInfo *info;
-	CamelService *transport;
+	ESourceRegistry *registry;
+	ESource *source = NULL;
 	GPtrArray *post_to_uris;
 	struct _camel_header_raw *xev;
 	struct _camel_header_raw *header;
+	const gchar *string;
 	const gchar *resent_from;
+	gchar *transport_uid = NULL;
+	gchar *sent_folder_uri = NULL;
+	gboolean replies_to_origin_folder = FALSE;
 	GError *error = NULL;
 
 	g_return_if_fail (E_IS_MAIL_SESSION (session));
 	g_return_if_fail (CAMEL_IS_MIME_MESSAGE (message));
 
+	registry = e_mail_session_get_registry (session);
+
 	medium = CAMEL_MEDIUM (message);
 
 	camel_medium_set_header (medium, "X-Mailer", X_MAILER);
 
-	/* Do this before removing "X-Evolution" headers. */
-	transport = e_mail_session_ref_transport_for_message (
-		session, message);
-
 	xev = mail_tool_remove_xevolution_headers (message);
 
 	/* Extract directives from X-Evolution headers. */
 
+	string = camel_header_raw_find (&xev, "X-Evolution-Identity", NULL);
+	if (string != NULL) {
+		gchar *uid = g_strstrip (g_strdup (string));
+		source = e_source_registry_ref_source (registry, uid);
+		g_free (uid);
+	}
+
+	if (E_IS_SOURCE (source)) {
+		ESourceMailSubmission *extension;
+		const gchar *extension_name;
+
+		extension_name = E_SOURCE_EXTENSION_MAIL_SUBMISSION;
+		extension = e_source_get_extension (source, extension_name);
+
+		string = e_source_mail_submission_get_sent_folder (extension);
+		sent_folder_uri = g_strdup (string);
+
+		string = e_source_mail_submission_get_transport_uid (extension);
+		transport_uid = g_strdup (string);
+
+		replies_to_origin_folder = e_source_mail_submission_get_replies_to_origin_folder (extension);
+
+		g_object_unref (source);
+	}
+
+	string = camel_header_raw_find (&xev, "X-Evolution-Fcc", NULL);
+	if (sent_folder_uri == NULL && string != NULL)
+		sent_folder_uri = g_strstrip (g_strdup (string));
+
+	string = camel_header_raw_find (&xev, "X-Evolution-Transport", NULL);
+	if (transport_uid == NULL && string != NULL)
+		transport_uid = g_strstrip (g_strdup (string));
+
+	if (replies_to_origin_folder) {
+		string = camel_header_raw_find (&xev, "X-Evolution-Source-Flags", NULL);
+		if (string != NULL && strstr (string, "FORWARDED") == NULL) {
+			string = camel_header_raw_find (&xev, "X-Evolution-Source-Folder", NULL);
+			if (string != NULL && camel_header_raw_find (&xev, "X-Evolution-Source-Message", NULL) != NULL) {
+				g_free (sent_folder_uri);
+				sent_folder_uri = g_strstrip (g_strdup (string));
+			}
+		}
+	}
+
 	post_to_uris = g_ptr_array_new ();
 	for (header = xev; header != NULL; header = header->next) {
 		gchar *folder_uri;
@@ -874,15 +942,10 @@ e_mail_session_send_to (EMailSession *session,
 
 	/* Miscellaneous preparations. */
 
-	info = camel_message_info_new_from_header (
-		NULL, CAMEL_MIME_PART (message)->headers);
-	((CamelMessageInfoBase *) info)->size =
-		get_message_size (message, cancellable);
+	info = camel_message_info_new_from_header (NULL, ((CamelMimePart *) message)->headers);
+	((CamelMessageInfoBase *) info)->size = get_message_size (message, cancellable);
 	camel_message_info_set_flags (info, CAMEL_MESSAGE_SEEN, ~0);
 
-	/* expand, or remove empty, group addresses */
-	em_utils_expand_groups (CAMEL_INTERNET_ADDRESS (recipients));
-
 	/* The rest of the processing happens in a thread. */
 
 	context = g_slice_new0 (AsyncContext);
@@ -893,7 +956,8 @@ e_mail_session_send_to (EMailSession *session,
 	context->info = info;
 	context->xev = xev;
 	context->post_to_uris = post_to_uris;
-	context->transport = transport;
+	context->transport_uid = transport_uid;
+	context->sent_folder_uri = sent_folder_uri;
 
 	if (G_IS_CANCELLABLE (cancellable))
 		context->cancellable = g_object_ref (cancellable);
@@ -950,655 +1014,3 @@ e_mail_session_send_to_finish (EMailSession *session,
 	return !g_simple_async_result_propagate_error (simple, error);
 }
 
-/* Helper for e_mail_session_get_fcc_for_message_sync() */
-static CamelFolder *
-mail_session_try_uri_to_folder (EMailSession *session,
-                                const gchar *folder_uri,
-                                GCancellable *cancellable,
-                                GError **error)
-{
-	CamelFolder *folder;
-	GError *local_error = NULL;
-
-	folder = e_mail_session_uri_to_folder_sync (
-		session, folder_uri, 0, cancellable, &local_error);
-
-	/* Sanity check. */
-	g_return_val_if_fail (
-		((folder != NULL) && (local_error == NULL)) ||
-		((folder == NULL) && (local_error != NULL)), NULL);
-
-	/* Disregard specific errors. */
-
-	/* Invalid URI. */
-	if (g_error_matches (
-		local_error, CAMEL_FOLDER_ERROR,
-		CAMEL_FOLDER_ERROR_INVALID))
-		g_clear_error (&local_error);
-
-	/* Folder not found. */
-	if (g_error_matches (
-		local_error, CAMEL_STORE_ERROR,
-		CAMEL_STORE_ERROR_NO_FOLDER))
-		g_clear_error (&local_error);
-
-	if (local_error != NULL)
-		g_propagate_error (error, local_error);
-
-	return folder;
-}
-
-/* Helper for e_mail_session_get_fcc_for_message_sync() */
-static CamelFolder *
-mail_session_ref_origin_folder (EMailSession *session,
-                                CamelMimeMessage *message,
-                                GCancellable *cancellable,
-                                GError **error)
-{
-	CamelMedium *medium;
-	const gchar *header_name;
-	const gchar *header_value;
-
-	medium = CAMEL_MEDIUM (message);
-
-	/* Check that a "X-Evolution-Source-Flags" header is present
-	 * and its value does not contain the substring "FORWARDED". */
-
-	header_name = "X-Evolution-Source-Flags";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	if (strstr (header_value, "FORWARDED") != NULL)
-		return NULL;
-
-	/* Check that a "X-Evolution-Source-Message" header is present. */
-
-	header_name = "X-Evolution-Source-Message";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	/* Check that a "X-Evolution-Source-Folder" header is present.
-	 * Its value specifies the origin folder as a folder URI. */
-
-	header_name = "X-Evolution-Source-Folder";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	/* This may return NULL without setting a GError. */
-	return mail_session_try_uri_to_folder (
-		session, header_value, cancellable, error);
-}
-
-/* Helper for e_mail_session_get_fcc_for_message_sync() */
-static CamelFolder *
-mail_session_ref_fcc_from_identity (EMailSession *session,
-                                    ESource *source,
-                                    CamelMimeMessage *message,
-                                    GCancellable *cancellable,
-                                    GError **error)
-{
-	ESourceRegistry *registry;
-	ESourceMailSubmission *extension;
-	CamelFolder *folder = NULL;
-	const gchar *extension_name;
-	gchar *folder_uri;
-
-	registry = e_mail_session_get_registry (session);
-	extension_name = E_SOURCE_EXTENSION_MAIL_SUBMISSION;
-
-	if (source == NULL)
-		return NULL;
-
-	if (!e_source_registry_check_enabled (registry, source))
-		return NULL;
-
-	if (!e_source_has_extension (source, extension_name))
-		return NULL;
-
-	extension = e_source_get_extension (source, extension_name);
-
-	if (e_source_mail_submission_get_replies_to_origin_folder (extension)) {
-		GError *local_error = NULL;
-
-		/* This may return NULL without setting a GError. */
-		folder = mail_session_ref_origin_folder (
-			session, message, cancellable, &local_error);
-
-		if (local_error != NULL) {
-			g_warn_if_fail (folder == NULL);
-			g_propagate_error (error, local_error);
-			return NULL;
-		}
-	}
-
-	folder_uri = e_source_mail_submission_dup_sent_folder (extension);
-
-	if (folder_uri != NULL && folder == NULL) {
-		/* This may return NULL without setting a GError. */
-		folder = mail_session_try_uri_to_folder (
-			session, folder_uri, cancellable, error);
-	}
-
-	g_free (folder_uri);
-
-	return folder;
-}
-
-/* Helper for e_mail_session_get_fcc_for_message_sync() */
-static CamelFolder *
-mail_session_ref_fcc_from_x_identity (EMailSession *session,
-                                      CamelMimeMessage *message,
-                                      GCancellable *cancellable,
-                                      GError **error)
-{
-	ESource *source;
-	ESourceRegistry *registry;
-	CamelFolder *folder;
-	CamelMedium *medium;
-	const gchar *header_name;
-	const gchar *header_value;
-	gchar *uid;
-
-	medium = CAMEL_MEDIUM (message);
-	header_name = "X-Evolution-Identity";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	uid = g_strstrip (g_strdup (header_value));
-
-	registry = e_mail_session_get_registry (session);
-	source = e_source_registry_ref_source (registry, uid);
-
-	/* This may return NULL without setting a GError. */
-	folder = mail_session_ref_fcc_from_identity (
-		session, source, message, cancellable, error);
-
-	g_clear_object (&source);
-
-	g_free (uid);
-
-	return folder;
-}
-
-/* Helper for e_mail_session_get_fcc_for_message_sync() */
-static CamelFolder *
-mail_session_ref_fcc_from_x_fcc (EMailSession *session,
-                                 CamelMimeMessage *message,
-                                 GCancellable *cancellable,
-                                 GError **error)
-{
-	CamelMedium *medium;
-	const gchar *header_name;
-	const gchar *header_value;
-
-	medium = CAMEL_MEDIUM (message);
-	header_name = "X-Evolution-Fcc";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	/* This may return NULL without setting a GError. */
-	return mail_session_try_uri_to_folder (
-		session, header_value, cancellable, error);
-}
-
-/* Helper for e_mail_session_get_fcc_for_message_sync() */
-static CamelFolder *
-mail_session_ref_fcc_from_default_identity (EMailSession *session,
-                                            CamelMimeMessage *message,
-                                            GCancellable *cancellable,
-                                            GError **error)
-{
-	ESource *source;
-	ESourceRegistry *registry;
-	CamelFolder *folder;
-
-	registry = e_mail_session_get_registry (session);
-	source = e_source_registry_ref_default_mail_identity (registry);
-
-	/* This may return NULL without setting a GError. */
-	folder = mail_session_ref_fcc_from_identity (
-		session, source, message, cancellable, error);
-
-	g_clear_object (&source);
-
-	return folder;
-}
-
-/**
- * e_mail_session_get_fcc_for_message_sync:
- * @session: an #EMailSession
- * @message: a #CamelMimeMessage
- * @cancellable: optional #GCancellable object, or %NULL
- * @error: return location for a #GError, or %NULL
- *
- * Obtains the preferred "carbon-copy" folder (a.k.a Fcc) for @message
- * by first checking @message for an "X-Evolution-Identity" header, and
- * then an "X-Evolution-Fcc" header.  Failing that, the function checks
- * the default mail identity (if available), and failing even that, the
- * function falls back to the Sent folder from the built-in mail store.
- *
- * Where applicable, the function attempts to honor the
- * #ESourceMailSubmission:replies-to-origin-folder preference.
- *
- * The returned #CamelFolder is referenced for thread-safety and must be
- * unreferenced with g_object_unref() when finished with it.
- *
- * If a non-recoverable error occurs, the function sets @error and returns
- * %NULL.
- *
- * Returns: a #CamelFolder, or %NULL
- **/
-CamelFolder *
-e_mail_session_get_fcc_for_message_sync (EMailSession *session,
-                                         CamelMimeMessage *message,
-                                         GCancellable *cancellable,
-                                         GError **error)
-{
-	CamelFolder *folder = NULL;
-
-	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
-	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
-
-	/* Check for "X-Evolution-Identity" header. */
-	if (folder == NULL) {
-		GError *local_error = NULL;
-
-		/* This may return NULL without setting a GError. */
-		folder = mail_session_ref_fcc_from_x_identity (
-			session, message, cancellable, &local_error);
-
-		if (local_error != NULL) {
-			g_warn_if_fail (folder == NULL);
-			g_propagate_error (error, local_error);
-			return NULL;
-		}
-	}
-
-	/* Check for "X-Evolution-Fcc" header. */
-	if (folder == NULL) {
-		GError *local_error = NULL;
-
-		/* This may return NULL without setting a GError. */
-		folder = mail_session_ref_fcc_from_x_fcc (
-			session, message, cancellable, &local_error);
-
-		if (local_error != NULL) {
-			g_warn_if_fail (folder == NULL);
-			g_propagate_error (error, local_error);
-			return NULL;
-		}
-	}
-
-	/* Check the default mail identity. */
-	if (folder == NULL) {
-		GError *local_error = NULL;
-
-		/* This may return NULL without setting a GError. */
-		folder = mail_session_ref_fcc_from_default_identity (
-			session, message, cancellable, &local_error);
-
-		if (local_error != NULL) {
-			g_warn_if_fail (folder == NULL);
-			g_propagate_error (error, local_error);
-			return NULL;
-		}
-	}
-
-	/* Last resort - local Sent folder. */
-	if (folder == NULL) {
-		folder = e_mail_session_get_local_folder (
-			session, E_MAIL_LOCAL_FOLDER_SENT);
-		g_object_ref (folder);
-	}
-
-	return folder;
-}
-
-/* Helper for e_mail_session_get_fcc_for_message() */
-static void
-mail_session_get_fcc_for_message_thread (GSimpleAsyncResult *simple,
-                                         GObject *source_object,
-                                         GCancellable *cancellable)
-{
-	AsyncContext *async_context;
-	GError *local_error = NULL;
-
-	async_context = g_simple_async_result_get_op_res_gpointer (simple);
-
-	async_context->folder =
-		e_mail_session_get_fcc_for_message_sync (
-			E_MAIL_SESSION (source_object),
-			async_context->message,
-			cancellable, &local_error);
-
-	if (local_error != NULL)
-		g_simple_async_result_take_error (simple, local_error);
-}
-
-/**
- * e_mail_session_get_fcc_for_message:
- * @session: an #EMailSession
- * @message: a #CamelMimeMessage
- * @io_priority: the I/O priority of the request
- * @cancellable: optional #GCancellable object, or %NULL
- * @callback: a #GAsyncReadyCallback to call when the request is satisfied
- * @user_data: data to pass to the callback function
- *
- * Asynchronously obtains the preferred "carbon-copy" folder (a.k.a Fcc) for
- * @message by first checking @message for an "X-Evolution-Identity" header,
- * and then an "X-Evolution-Fcc" header.  Failing that, the function checks
- * the default mail identity (if available), and failing even that, the
- * function falls back to the Sent folder from the built-in mail store.
- *
- * Where applicable, the function attempts to honor the
- * #ESourceMailSubmission:replies-to-origin-folder preference.
- *
- * When the operation is finished, @callback will be called.  You can then
- * call e_mail_session_get_fcc_for_message_finish() to get the result of the
- * operation.
- **/
-void
-e_mail_session_get_fcc_for_message (EMailSession *session,
-                                    CamelMimeMessage *message,
-                                    gint io_priority,
-                                    GCancellable *cancellable,
-                                    GAsyncReadyCallback callback,
-                                    gpointer user_data)
-{
-	GSimpleAsyncResult *simple;
-	AsyncContext *async_context;
-
-	g_return_if_fail (E_IS_MAIL_SESSION (session));
-	g_return_if_fail (CAMEL_IS_MIME_MESSAGE (message));
-
-	async_context = g_slice_new0 (AsyncContext);
-	async_context->message = g_object_ref (message);
-
-	simple = g_simple_async_result_new (
-		G_OBJECT (session), callback, user_data,
-		e_mail_session_get_fcc_for_message);
-
-	g_simple_async_result_set_check_cancellable (simple, cancellable);
-
-	g_simple_async_result_set_op_res_gpointer (
-		simple, async_context, (GDestroyNotify) async_context_free);
-
-	g_simple_async_result_run_in_thread (
-		simple, mail_session_get_fcc_for_message_thread,
-		io_priority, cancellable);
-
-	g_object_unref (simple);
-}
-
-/**
- * e_mail_session_get_fcc_for_message_finish:
- * @session: an #EMailSession
- * @result: a #GAsyncResult
- * @error: return location for a #GError, or %NULL
- *
- * Finishes the operation started with e_mail_session_get_fcc_for_message().
- *
- * The returned #CamelFolder is referenced for thread-safety and must be
- * unreferenced with g_object_unref() when finished with it.
- *
- * If a non-recoverable error occurred, the function sets @error and
- * returns %NULL.
- *
- * Returns: a #CamelFolder, or %NULL
- **/
-CamelFolder *
-e_mail_session_get_fcc_for_message_finish (EMailSession *session,
-                                           GAsyncResult *result,
-                                           GError **error)
-{
-	GSimpleAsyncResult *simple;
-	AsyncContext *async_context;
-
-	g_return_val_if_fail (
-		g_simple_async_result_is_valid (
-		result, G_OBJECT (session),
-		e_mail_session_get_fcc_for_message), NULL);
-
-	simple = G_SIMPLE_ASYNC_RESULT (result);
-	async_context = g_simple_async_result_get_op_res_gpointer (simple);
-
-	if (g_simple_async_result_propagate_error (simple, error))
-		return NULL;
-
-	g_return_val_if_fail (async_context->folder != NULL, NULL);
-
-	return g_object_ref (async_context->folder);
-}
-
-/**
- * e_mail_session_ref_transport:
- * @session: an #EMailSession
- * @transport_uid: the UID of a mail transport
- *
- * Returns the transport #CamelService instance for @transport_uid,
- * verifying first that the @transport_uid is indeed a mail transport and
- * that the corresponding #ESource is enabled.  If these checks fail, the
- * function returns %NULL.
- *
- * The returned #CamelService is referenced for thread-safety and must be
- * unreferenced with g_object_unref() when finished with it.
- *
- * Returns: a #CamelService, or %NULL
- **/
-CamelService *
-e_mail_session_ref_transport (EMailSession *session,
-                              const gchar *transport_uid)
-{
-	ESourceRegistry *registry;
-	ESource *source = NULL;
-	CamelService *transport = NULL;
-	const gchar *extension_name;
-
-	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
-	g_return_val_if_fail (transport_uid != NULL, NULL);
-
-	registry = e_mail_session_get_registry (session);
-	extension_name = E_SOURCE_EXTENSION_MAIL_TRANSPORT;
-
-	source = e_source_registry_ref_source (registry, transport_uid);
-
-	if (source == NULL)
-		goto exit;
-
-	if (!e_source_registry_check_enabled (registry, source))
-		goto exit;
-
-	if (!e_source_has_extension (source, extension_name))
-		goto exit;
-
-	transport = camel_session_ref_service (
-		CAMEL_SESSION (session), transport_uid);
-
-	/* Sanity check. */
-	if (transport != NULL)
-		g_warn_if_fail (CAMEL_IS_TRANSPORT (transport));
-
-exit:
-	g_clear_object (&source);
-
-	return transport;
-}
-
-/* Helper for e_mail_session_ref_default_transport()
- * and mail_session_ref_transport_from_x_identity(). */
-static CamelService *
-mail_session_ref_transport_for_identity (EMailSession *session,
-                                         ESource *source)
-{
-	ESourceRegistry *registry;
-	ESourceMailSubmission *extension;
-	CamelService *transport = NULL;
-	const gchar *extension_name;
-	gchar *uid;
-
-	registry = e_mail_session_get_registry (session);
-	extension_name = E_SOURCE_EXTENSION_MAIL_SUBMISSION;
-
-	if (source == NULL)
-		return NULL;
-
-	if (!e_source_registry_check_enabled (registry, source))
-		return NULL;
-
-	if (!e_source_has_extension (source, extension_name))
-		return NULL;
-
-	extension = e_source_get_extension (source, extension_name);
-	uid = e_source_mail_submission_dup_transport_uid (extension);
-
-	if (uid != NULL) {
-		transport = e_mail_session_ref_transport (session, uid);
-		g_free (uid);
-	}
-
-	return transport;
-}
-
-/**
- * e_mail_session_ref_default_transport:
- * @session: an #EMailSession
- *
- * Returns the default transport #CamelService instance according to
- * #ESourceRegistry's #ESourceRegistry:default-mail-identity setting,
- * verifying first that the #ESourceMailSubmission:transport-uid named by
- * the #ESourceRegistry:default-mail-identity is indeed a mail transport,
- * and that the corresponding #ESource is enabled.  If these checks fail,
- * the function returns %NULL.
- *
- * The returned #CamelService is referenced for thread-safety and must be
- * unreferenced with g_object_unref() when finished with it.
- *
- * Returns: a #CamelService, or %NULL
- **/
-CamelService *
-e_mail_session_ref_default_transport (EMailSession *session)
-{
-	ESource *source;
-	ESourceRegistry *registry;
-	CamelService *transport;
-
-	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
-
-	registry = e_mail_session_get_registry (session);
-	source = e_source_registry_ref_default_mail_identity (registry);
-	transport = mail_session_ref_transport_for_identity (session, source);
-	g_clear_object (&source);
-
-	return transport;
-}
-
-/* Helper for e_mail_session_ref_transport_for_message() */
-static CamelService *
-mail_session_ref_transport_from_x_identity (EMailSession *session,
-                                            CamelMimeMessage *message)
-{
-	ESource *source;
-	ESourceRegistry *registry;
-	CamelMedium *medium;
-	CamelService *transport;
-	const gchar *header_name;
-	const gchar *header_value;
-	gchar *uid;
-
-	medium = CAMEL_MEDIUM (message);
-	header_name = "X-Evolution-Identity";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	uid = g_strstrip (g_strdup (header_value));
-
-	registry = e_mail_session_get_registry (session);
-	source = e_source_registry_ref_source (registry, uid);
-	transport = mail_session_ref_transport_for_identity (session, source);
-	g_clear_object (&source);
-
-	g_free (uid);
-
-	return transport;
-}
-
-/* Helper for e_mail_session_ref_transport_for_message() */
-static CamelService *
-mail_session_ref_transport_from_x_transport (EMailSession *session,
-                                             CamelMimeMessage *message)
-{
-	CamelMedium *medium;
-	CamelService *transport;
-	const gchar *header_name;
-	const gchar *header_value;
-	gchar *uid;
-
-	medium = CAMEL_MEDIUM (message);
-	header_name = "X-Evolution-Transport";
-	header_value = camel_medium_get_header (medium, header_name);
-
-	if (header_value == NULL)
-		return NULL;
-
-	uid = g_strstrip (g_strdup (header_value));
-
-	transport = e_mail_session_ref_transport (session, uid);
-
-	g_free (uid);
-
-	return transport;
-}
-
-/**
- * e_mail_session_ref_transport_for_message:
- * @session: an #EMailSession
- * @message: a #CamelMimeMessage
- *
- * Returns the preferred transport #CamelService instance for @message by
- * first checking @message for an "X-Evolution-Identity" header, and then
- * an "X-Evolution-Transport" header.  Failing that, the function returns
- * the default transport #CamelService instance (if available).
- *
- * The returned #CamelService is referenced for thread-safety and must be
- * unreferenced with g_object_unref() when finished with it.
- *
- * Returns: a #CamelService, or %NULL
- **/
-CamelService *
-e_mail_session_ref_transport_for_message (EMailSession *session,
-                                          CamelMimeMessage *message)
-{
-	CamelService *transport = NULL;
-
-	g_return_val_if_fail (E_IS_MAIL_SESSION (session), NULL);
-	g_return_val_if_fail (CAMEL_IS_MIME_MESSAGE (message), NULL);
-
-	/* Check for "X-Evolution-Identity" header. */
-	if (transport == NULL)
-		transport = mail_session_ref_transport_from_x_identity (
-			session, message);
-
-	/* Check for "X-Evolution-Transport" header. */
-	if (transport == NULL)
-		transport = mail_session_ref_transport_from_x_transport (
-			session, message);
-
-	/* Fall back to the default mail transport. */
-	if (transport == NULL)
-		transport = e_mail_session_ref_default_transport (session);
-
-	return transport;
-}
-
