@@ -485,11 +485,11 @@ mail_account_in_recipients (ESourceRegistry *registry,
 
 ESource *
 em_utils_guess_mail_account_with_recipients_and_sort (ESourceRegistry *registry,
-                                                      CamelMimeMessage *message,
-                                                      CamelFolder *folder,
-                                                      const gchar *message_uid,
-                                                      EMailUtilsSourtSourcesFunc sort_func,
-                                                      gpointer sort_func_data)
+						      CamelMimeMessage *message,
+						      CamelFolder *folder,
+						      const gchar *message_uid,
+						      EMailUtilsSourtSourcesFunc sort_func,
+						      gpointer sort_func_data)
 {
 	ESource *source = NULL;
 	GHashTable *recipients;
@@ -552,7 +552,7 @@ second_preference:
 	}
 
 	extension_name = E_SOURCE_EXTENSION_MAIL_ACCOUNT;
-	list = e_source_registry_list_sources (registry, extension_name);
+	list = e_source_registry_list_enabled (registry, extension_name);
 
 	if (sort_func)
 		sort_func (&list, sort_func_data);
@@ -560,8 +560,7 @@ second_preference:
 	for (iter = list; iter != NULL; iter = g_list_next (iter)) {
 		ESource *temp = E_SOURCE (iter->data);
 
-		if (e_source_registry_check_enabled (registry, temp) &&
-		    mail_account_in_recipients (registry, temp, recipients)) {
+		if (mail_account_in_recipients (registry, temp, recipients)) {
 			source = g_object_ref (temp);
 			break;
 		}
@@ -584,11 +583,11 @@ exit:
 
 ESource *
 em_utils_guess_mail_identity_with_recipients_and_sort (ESourceRegistry *registry,
-                                                       CamelMimeMessage *message,
-                                                       CamelFolder *folder,
-                                                       const gchar *message_uid,
-                                                       EMailUtilsSourtSourcesFunc sort_func,
-                                                       gpointer sort_func_data)
+						       CamelMimeMessage *message,
+						       CamelFolder *folder,
+						       const gchar *message_uid,
+						       EMailUtilsSourtSourcesFunc sort_func,
+						       gpointer sort_func_data)
 {
 	ESource *source;
 	ESourceExtension *extension;
@@ -706,44 +705,3 @@ em_utils_is_local_delivery_mbox_file (CamelURL *url)
 		!g_file_test (url->path, G_FILE_TEST_IS_DIR);
 }
 
-/* Expands groups to individual addresses, or removes empty groups completely.
- * Usual email addresses are left untouched.
-*/
-void
-em_utils_expand_groups (CamelInternetAddress *addresses)
-{
-	gint ii, len;
-	const gchar *addr;
-	CamelAddress *addrs;
-
-	g_return_if_fail (CAMEL_IS_INTERNET_ADDRESS (addresses));
-
-	addrs = CAMEL_ADDRESS (addresses);
-	len = camel_address_length (addrs);
-	for (ii = len - 1; ii >= 0; ii--) {
-		addr = NULL;
-
-		if (!camel_internet_address_get (addresses, ii, NULL, &addr)) {
-			camel_address_remove (addrs, ii);
-		} else if (addr) {
-			gchar *encoded = camel_internet_address_encode_address (NULL, NULL, addr);
-
-			if (encoded) {
-				CamelInternetAddress *iaddr = camel_internet_address_new ();
-				gint decoded;
-
-				/* decode expands respective groups */
-				decoded = camel_address_decode (CAMEL_ADDRESS (iaddr), encoded);
-				if (decoded <= 0 || decoded > 1) {
-					camel_address_remove (addrs, ii);
-
-					if (decoded > 1)
-						camel_address_cat (addrs, CAMEL_ADDRESS (iaddr));
-				}
-
-				g_object_unref (iaddr);
-				g_free (encoded);
-			}
-		}
-	}
-}
