@@ -215,8 +215,11 @@ mail_msg_unref (gpointer msg)
 		g_mutex_unlock (&mail_msg_lock);
 
 		/* Destroy the message from an idle callback
-		 * so we know we're in the main loop thread. */
-		g_idle_add ((GSourceFunc) mail_msg_free, mail_msg);
+		 * so we know we're in the main loop thread.
+		 * Prioritize ahead of GTK+ redraws. */
+		g_idle_add_full (
+			G_PRIORITY_HIGH_IDLE,
+			(GSourceFunc) mail_msg_free, mail_msg, NULL);
 	}
 }
 
@@ -429,8 +432,10 @@ mail_msg_proxy (MailMsg *msg)
 
 	G_LOCK (idle_source_id);
 	if (idle_source_id == 0)
-		idle_source_id = g_idle_add (
-			(GSourceFunc) mail_msg_idle_cb, NULL);
+		/* Prioritize ahead of GTK+ redraws. */
+		idle_source_id = g_idle_add_full (
+			G_PRIORITY_HIGH_IDLE,
+			(GSourceFunc) mail_msg_idle_cb, NULL, NULL);
 	G_UNLOCK (idle_source_id);
 }
 
@@ -484,8 +489,10 @@ mail_msg_main_loop_push (gpointer msg)
 
 	G_LOCK (idle_source_id);
 	if (idle_source_id == 0)
-		idle_source_id = g_idle_add (
-			(GSourceFunc) mail_msg_idle_cb, NULL);
+		/* Prioritize ahead of GTK+ redraws. */
+		idle_source_id = g_idle_add_full (
+			G_PRIORITY_HIGH_IDLE,
+			(GSourceFunc) mail_msg_idle_cb, NULL, NULL);
 	G_UNLOCK (idle_source_id);
 }
 
