@@ -242,6 +242,7 @@ fetch_mail_exec (struct _fetch_mail_msg *m,
 	struct _filter_mail_msg *fm = (struct _filter_mail_msg *) m;
 	GObjectClass *class;
 	CamelFolder *folder = NULL;
+	CamelProvider *provider;
 	CamelService *service;
 	CamelSession *session;
 	CamelSettings *settings;
@@ -258,6 +259,11 @@ fetch_mail_exec (struct _fetch_mail_msg *m,
 
 	service = CAMEL_SERVICE (m->store);
 	session = camel_service_ref_session (service);
+	provider = camel_service_get_provider (service);
+
+	if (provider && (provider->flags & CAMEL_PROVIDER_IS_REMOTE) != 0 &&
+	    !camel_session_get_online (session))
+		goto exit;
 
 	fm->destination = e_mail_session_get_local_folder (
 		E_MAIL_SESSION (session), E_MAIL_LOCAL_FOLDER_LOCAL_INBOX);
@@ -265,9 +271,7 @@ fetch_mail_exec (struct _fetch_mail_msg *m,
 		goto exit;
 	g_object_ref (fm->destination);
 
-	service = CAMEL_SERVICE (m->store);
 	uid = camel_service_get_uid (service);
-
 	settings = camel_service_ref_settings (service);
 
 	/* XXX This is a POP3-specific setting. */
@@ -348,7 +352,7 @@ fetch_mail_exec (struct _fetch_mail_msg *m,
 			g_object_ref (fm->destination);
 		}
 
-		if (!local_error && !g_cancellable_is_cancelled (cancellable)) {
+		if (!local_error) {
 			folder_uids = camel_folder_get_uids (folder);
 			cache_uids = camel_uid_cache_get_new_uids (cache, folder_uids);
 
@@ -373,26 +377,11 @@ fetch_mail_exec (struct _fetch_mail_msg *m,
 					g_cancellable_reset (m->cancellable);
 
 				if (!success) {
-					GPtrArray *uncached_uids;
-					GHashTable *uncached_hash;
-
-					uncached_uids = camel_folder_get_uncached_uids (folder, cache_uids, NULL);
-					uncached_hash = g_hash_table_new (g_str_hash, g_str_equal);
-
-					for (i = 0; uncached_uids && i < uncached_uids->len; i++) {
-						g_hash_table_insert (uncached_hash, uncached_uids->pdata[i], uncached_uids->pdata[i]);
-					}
-
 					/* re-enter known UIDs, thus they are not
 					 * re-fetched next time */
 					for (i = 0; i < cache_uids->len; i++) {
-						/* skip uncached UIDs */
-						if (!g_hash_table_lookup (uncached_hash, cache_uids->pdata[i]))
-							camel_uid_cache_save_uid (cache, cache_uids->pdata[i]);
+						camel_uid_cache_save_uid (cache, cache_uids->pdata[i]);
 					}
-
-					g_hash_table_destroy (uncached_hash);
-					camel_folder_free_uids (folder, uncached_uids);
 				}
 
 				/* save the cache of uids that we've just downloaded */
@@ -448,18 +437,9 @@ exit:
 
 	/* also disconnect if not a local delivery mbox;
 	 * there is no need to keep the connection alive forever */
-	if (!is_local_delivery) {
-		gboolean was_cancelled;
-
-		was_cancelled = g_cancellable_is_cancelled (cancellable);
-
-		/* pity, but otherwise it doesn't disconnect */
-		if (was_cancelled)
-			g_cancellable_reset (cancellable);
-
+	if (!is_local_delivery)
 		camel_service_disconnect_sync (
-			service, !was_cancelled, cancellable, NULL);
-	}
+			service, TRUE, cancellable, NULL);
 
 	g_object_unref (session);
 }
@@ -584,6 +564,49 @@ static void	report_status		(struct _send_queue_msg *m,
 					 const gchar *desc,
 					 ...);
 
+static gboolean
+get_submission_details_from_identity (EMailSession *session,
+                                      const gchar *identity_uid,
+                                      gchar **out_transport_uid,
+                                      gchar **out_sent_folder_uri,
+                                      gboolean *out_replies_to_origin_folder)
+{
+	ESource *source;
+	ESourceRegistry *registry;
+	ESourceExtension *extension;
+	const gchar *extension_name;
+
+	registry = e_mail_session_get_registry (session);
+	extension_name = E_SOURCE_EXTENSION_MAIL_SUBMISSION;
+	source = e_source_registry_ref_source (registry, identity_uid);
+
+	if (source == NULL)
+		return FALSE;
+
+	if (!e_source_has_extension (source, extension_name)) {
+		g_object_unref (source);
+		return FALSE;
+	}
+
+	extension = e_source_get_extension (source, extension_name);
+
+	*out_sent_folder_uri =
+		e_source_mail_submission_dup_sent_folder (
+		E_SOURCE_MAIL_SUBMISSION (extension));
+
+	*out_transport_uid =
+		e_source_mail_submission_dup_transport_uid (
+		E_SOURCE_MAIL_SUBMISSION (extension));
+
+	*out_replies_to_origin_folder =
+		e_source_mail_submission_get_replies_to_origin_folder (
+		E_SOURCE_MAIL_SUBMISSION (extension));
+
+	g_object_unref (source);
+
+	return TRUE;
+}
+
 /* send 1 message to a specific transport */
 static void
 mail_send_message (struct _send_queue_msg *m,
@@ -599,7 +622,10 @@ mail_send_message (struct _send_queue_msg *m,
 	CamelAddress *from, *recipients;
 	CamelMessageInfo *info = NULL;
 	CamelProvider *provider = NULL;
-	const gchar *resent_from;
+	gchar *transport_uid = NULL;
+	gchar *sent_folder_uri = NULL;
+	const gchar *resent_from, *tmp;
+	gboolean replies_to_origin_folder = FALSE;
 	CamelFolder *folder = NULL;
 	GString *err = NULL;
 	struct _camel_header_raw *xev, *header;
@@ -614,15 +640,45 @@ mail_send_message (struct _send_queue_msg *m,
 
 	camel_medium_set_header (CAMEL_MEDIUM (message), "X-Mailer", x_mailer);
 
-	/* Do this before removing "X-Evolution" headers. */
-	service = e_mail_session_ref_transport_for_message (
-		m->session, message);
-	if (service != NULL)
-		provider = camel_service_get_provider (service);
-
 	err = g_string_new ("");
 	xev = mail_tool_remove_xevolution_headers (message);
 
+	tmp = camel_header_raw_find (&xev, "X-Evolution-Identity", NULL);
+	if (tmp != NULL) {
+		gchar *identity_uid;
+
+		identity_uid = g_strstrip (g_strdup (tmp));
+		get_submission_details_from_identity (
+			m->session, identity_uid,
+			&transport_uid, &sent_folder_uri,
+			&replies_to_origin_folder);
+		g_free (identity_uid);
+	}
+
+	tmp = camel_header_raw_find (&xev, "X-Evolution-Transport", NULL);
+	if (transport_uid == NULL && tmp != NULL)
+		transport_uid = g_strstrip (g_strdup (tmp));
+
+	tmp = camel_header_raw_find (&xev, "X-Evolution-Fcc", NULL);
+	if (sent_folder_uri == NULL && tmp != NULL)
+		sent_folder_uri = g_strstrip (g_strdup (tmp));
+
+	if (replies_to_origin_folder) {
+		tmp = camel_header_raw_find (&xev, "X-Evolution-Source-Flags", NULL);
+		if (tmp != NULL && strstr (tmp, "FORWARDED") == NULL) {
+			tmp = camel_header_raw_find (&xev, "X-Evolution-Source-Folder", NULL);
+			if (tmp != NULL && camel_header_raw_find (&xev, "X-Evolution-Source-Message", NULL) != NULL) {
+				g_free (sent_folder_uri);
+				sent_folder_uri = g_strstrip (g_strdup (tmp));
+			}
+		}
+	}
+
+	service = camel_session_ref_service (
+		CAMEL_SESSION (m->session), transport_uid);
+	if (service != NULL)
+		provider = camel_service_get_provider (service);
+
 	if (CAMEL_IS_TRANSPORT (service)) {
 		const gchar *tuid;
 
@@ -633,9 +689,8 @@ mail_send_message (struct _send_queue_msg *m,
 
 	/* Check for email sending */
 	from = (CamelAddress *) camel_internet_address_new ();
-	resent_from = camel_medium_get_header (
-		CAMEL_MEDIUM (message), "Resent-From");
-	if (resent_from != NULL) {
+	resent_from = camel_medium_get_header (CAMEL_MEDIUM (message), "Resent-From");
+	if (resent_from) {
 		camel_address_decode (from, resent_from);
 	} else {
 		iaddr = camel_mime_message_get_from (message);
@@ -646,22 +701,22 @@ mail_send_message (struct _send_queue_msg *m,
 	for (i = 0; i < 3; i++) {
 		const gchar *type;
 
-		if (resent_from != NULL)
-			type = resent_recipients[i];
-		else
-			type = normal_recipients[i];
+		type = resent_from ? resent_recipients[i] : normal_recipients[i];
 		iaddr = camel_mime_message_get_recipients (message, type);
 		camel_address_cat (recipients, CAMEL_ADDRESS (iaddr));
 	}
 
 	if (camel_address_length (recipients) > 0) {
+		if (provider && (provider->flags & CAMEL_PROVIDER_IS_REMOTE) != 0 &&
+		    !camel_session_get_online (CAMEL_SESSION (m->session))) {
+			/* silently ignore */
+			goto exit;
+		}
+
 		if (!camel_service_connect_sync (
 			service, cancellable, error))
 			goto exit;
 
-		/* expand, or remove empty, group addresses */
-		em_utils_expand_groups (CAMEL_INTERNET_ADDRESS (recipients));
-
 		if (!camel_transport_send_to_sync (
 			CAMEL_TRANSPORT (service), message,
 			from, recipients, cancellable, error))
@@ -684,7 +739,7 @@ mail_send_message (struct _send_queue_msg *m,
 		/* FIXME Not passing a GCancellable or GError here. */
 		folder = e_mail_session_uri_to_folder_sync (
 			m->session, uri, 0, NULL, NULL);
-		if (folder != NULL) {
+		if (folder) {
 			/* FIXME Not passing a GCancellable or GError here. */
 			camel_folder_append_message_sync (
 				folder, message, info, NULL, NULL, NULL);
@@ -727,65 +782,71 @@ mail_send_message (struct _send_queue_msg *m,
 
 	if (provider == NULL
 	    || !(provider->flags & CAMEL_PROVIDER_DISABLE_SENT_FOLDER)) {
-		CamelFolder *local_sent_folder;
 		GError *local_error = NULL;
 
-		local_sent_folder = e_mail_session_get_local_folder (
-			m->session, E_MAIL_LOCAL_FOLDER_SENT);
-
-		folder = e_mail_session_get_fcc_for_message_sync (
-			m->session, message, cancellable, &local_error);
-
-		/* Sanity check. */
-		g_return_if_fail (
-			((folder == NULL) && (local_error != NULL)) ||
-			((folder != NULL) && (local_error == NULL)));
-
-		if (local_error == NULL)
-			camel_folder_append_message_sync (
-				folder, message, info, NULL,
+		if (sent_folder_uri) {
+			folder = e_mail_session_uri_to_folder_sync (
+				m->session, sent_folder_uri, 0,
 				cancellable, &local_error);
 
-		if (g_error_matches (
-			local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-			goto exit;
-
-		if (local_error != NULL && folder != local_sent_folder) {
-
-			if (folder != NULL) {
-				const gchar *description;
-
-				description =
-					camel_folder_get_description (folder);
-				if (err->len > 0)
-					g_string_append (err, "\n\n");
-				g_string_append_printf (
-					err,
-					_("Failed to append to %s: %s\n"
-					"Appending to local 'Sent' folder instead."),
-					description,
-					local_error->message);
-
-				g_object_unref (folder);
-			}
-
-			g_clear_error (&local_error);
-			folder = g_object_ref (local_sent_folder);
-
-			camel_folder_append_message_sync (
-				folder, message, info, NULL,
-				cancellable, &local_error);
-
-			if (g_error_matches (
-				local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
-				goto exit;
-
 			if (local_error != NULL) {
-				if (err->len > 0)
+				g_string_append_printf (
+					err, _("Failed to append to %s: %s\n"
+					"Appending to local 'Sent' folder instead."),
+					sent_folder_uri,
+					local_error->message);
+				g_clear_error (&local_error);
+			}
+		}
+
+		if (!folder) {
+			folder = e_mail_session_get_local_folder (
+				m->session, E_MAIL_LOCAL_FOLDER_SENT);
+			g_object_ref (folder);
+		}
+
+		if (!camel_folder_append_message_sync (
+			folder, message, info,
+			NULL, cancellable, &local_error)) {
+
+			CamelFolder *sent_folder;
+
+			if (g_error_matches (local_error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+				goto exit;
+
+			sent_folder = e_mail_session_get_local_folder (
+				m->session, E_MAIL_LOCAL_FOLDER_SENT);
+
+			if (folder != sent_folder) {
+				const gchar *description;
+
+				description = camel_folder_get_description (folder);
+				if (err->len)
 					g_string_append (err, "\n\n");
 				g_string_append_printf (
-					err,
-					_("Failed to append to "
+					err, _("Failed to append to %s: %s\n"
+					"Appending to local 'Sent' folder instead."),
+					description, local_error->message);
+				g_object_ref (sent_folder);
+				g_object_unref (folder);
+				folder = sent_folder;
+
+				g_clear_error (&local_error);
+				camel_folder_append_message_sync (
+					folder, message, info,
+					NULL, cancellable, &local_error);
+			}
+
+			if (local_error != NULL) {
+				if (g_error_matches (
+					local_error, G_IO_ERROR,
+					G_IO_ERROR_CANCELLED))
+					goto exit;
+
+				if (err->len)
+					g_string_append (err, "\n\n");
+				g_string_append_printf (
+					err, _("Failed to append to "
 					"local 'Sent' folder: %s"),
 					local_error->message);
 			}
@@ -826,7 +887,7 @@ mail_send_message (struct _send_queue_msg *m,
 		camel_folder_synchronize_sync (queue, FALSE, NULL, NULL);
 	}
 
-	if (err->len > 0) {
+	if (err->len) {
 		/* set the culmulative exception report */
 		g_set_error (
 			&local_error, CAMEL_ERROR,
@@ -838,12 +899,11 @@ exit:
 		g_propagate_error (error, local_error);
 
 	/* FIXME Not passing a GCancellable or GError here. */
-	if (folder != NULL) {
+	if (folder) {
 		camel_folder_synchronize_sync (folder, FALSE, NULL, NULL);
 		g_object_unref (folder);
 	}
-
-	if (info != NULL)
+	if (info)
 		camel_message_info_free (info);
 
 	if (service != NULL)
@@ -851,6 +911,8 @@ exit:
 
 	g_object_unref (recipients);
 	g_object_unref (from);
+	g_free (sent_folder_uri);
+	g_free (transport_uid);
 	camel_header_raw_clear (&xev);
 	g_string_free (err, TRUE);
 	g_object_unref (message);
