@@ -38,7 +38,6 @@ struct _EMailAccountStorePrivate {
 	CamelService *default_service;
 	GHashTable *service_index;
 	gchar *sort_order_filename;
-	gboolean express_mode;
 	gpointer session;  /* weak pointer */
 	guint busy_count;
 };
@@ -53,7 +52,6 @@ enum {
 	PROP_0,
 	PROP_BUSY,
 	PROP_DEFAULT_SERVICE,
-	PROP_EXPRESS_MODE,
 	PROP_SESSION
 };
 
@@ -140,31 +138,14 @@ mail_account_store_default_compare (CamelService *service_a,
 
 	/* Check for special cases first. */
 
-	if (e_mail_account_store_get_express_mode (store)) {
-		if (g_str_equal (uid_a, E_MAIL_SESSION_LOCAL_UID) &&
-		    g_str_equal (uid_b, E_MAIL_SESSION_VFOLDER_UID))
-			return -1;
-		else if (g_str_equal (uid_b, E_MAIL_SESSION_LOCAL_UID) &&
-			 g_str_equal (uid_a, E_MAIL_SESSION_VFOLDER_UID))
-			return 1;
-		else if (g_str_equal (uid_a, E_MAIL_SESSION_LOCAL_UID))
-			return 1;
-		else if (g_str_equal (uid_b, E_MAIL_SESSION_LOCAL_UID))
-			return -1;
-		else if (g_str_equal (uid_a, E_MAIL_SESSION_VFOLDER_UID))
-			return 1;
-		else if (g_str_equal (uid_a, E_MAIL_SESSION_VFOLDER_UID))
-			return -1;
-	} else {
-		if (g_str_equal (uid_a, E_MAIL_SESSION_LOCAL_UID))
-			return -1;
-		else if (g_str_equal (uid_b, E_MAIL_SESSION_LOCAL_UID))
-			return 1;
-		else if (g_str_equal (uid_a, E_MAIL_SESSION_VFOLDER_UID))
-			return 1;
-		else if (g_str_equal (uid_b, E_MAIL_SESSION_VFOLDER_UID))
-			return -1;
-	}
+	if (g_str_equal (uid_a, E_MAIL_SESSION_LOCAL_UID))
+		return -1;
+	else if (g_str_equal (uid_b, E_MAIL_SESSION_LOCAL_UID))
+		return 1;
+	else if (g_str_equal (uid_a, E_MAIL_SESSION_VFOLDER_UID))
+		return 1;
+	else if (g_str_equal (uid_b, E_MAIL_SESSION_VFOLDER_UID))
+		return -1;
 
 	/* Otherwise sort them alphabetically. */
 
@@ -204,15 +185,51 @@ mail_account_store_update_row (EMailAccountStore *store,
 		-1);
 }
 
+struct ServiceNotifyCbData
+{
+	EMailAccountStore *store;
+	CamelService *service;
+};
+
+static void
+service_notify_cb_data_free (gpointer ptr)
+{
+	struct ServiceNotifyCbData *data = ptr;
+
+	g_clear_object (&data->store);
+	g_clear_object (&data->service);
+	g_slice_free (struct ServiceNotifyCbData, data);
+}
+
+static gboolean
+mail_account_store_service_notify_idle_cb (gpointer user_data)
+{
+	struct ServiceNotifyCbData *data = user_data;
+	GtkTreeIter iter;
+
+	g_return_val_if_fail (data != NULL, FALSE);
+
+	if (mail_account_store_get_iter (data->store, data->service, &iter))
+		mail_account_store_update_row (data->store, data->service, &iter);
+
+	return FALSE;
+}
+
 static void
 mail_account_store_service_notify_cb (CamelService *service,
                                       GParamSpec *pspec,
                                       EMailAccountStore *store)
 {
-	GtkTreeIter iter;
+	struct ServiceNotifyCbData *data;
 
-	if (mail_account_store_get_iter (store, service, &iter))
-		mail_account_store_update_row (store, service, &iter);
+	data = g_slice_new0 (struct ServiceNotifyCbData);
+	data->store = g_object_ref (store);
+	data->service = g_object_ref (service);
+
+	g_idle_add_full (G_PRIORITY_DEFAULT_IDLE,
+		mail_account_store_service_notify_idle_cb,
+		data,
+		service_notify_cb_data_free);
 }
 
 static void
@@ -347,12 +364,6 @@ mail_account_store_set_property (GObject *object,
 				g_value_get_object (value));
 			return;
 
-		case PROP_EXPRESS_MODE:
-			e_mail_account_store_set_express_mode (
-				E_MAIL_ACCOUNT_STORE (object),
-				g_value_get_boolean (value));
-			return;
-
 		case PROP_SESSION:
 			mail_account_store_set_session (
 				E_MAIL_ACCOUNT_STORE (object),
@@ -384,13 +395,6 @@ mail_account_store_get_property (GObject *object,
 				E_MAIL_ACCOUNT_STORE (object)));
 			return;
 
-		case PROP_EXPRESS_MODE:
-			g_value_set_boolean (
-				value,
-				e_mail_account_store_get_express_mode (
-				E_MAIL_ACCOUNT_STORE (object)));
-			return;
-
 		case PROP_SESSION:
 			g_value_set_object (
 				value,
@@ -842,17 +846,6 @@ e_mail_account_store_class_init (EMailAccountStoreClass *class)
 			G_PARAM_READWRITE |
 			G_PARAM_STATIC_STRINGS));
 
-	g_object_class_install_property (
-		object_class,
-		PROP_EXPRESS_MODE,
-		g_param_spec_boolean (
-			"express-mode",
-			"Express Mode",
-			"Whether express mode is enabled",
-			FALSE,
-			G_PARAM_READWRITE |
-			G_PARAM_STATIC_STRINGS));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_SESSION,
@@ -1079,28 +1072,6 @@ e_mail_account_store_set_default_service (EMailAccountStore *store,
 	g_object_notify (G_OBJECT (store), "default-service");
 }
 
-gboolean
-e_mail_account_store_get_express_mode (EMailAccountStore *store)
-{
-	g_return_val_if_fail (E_IS_MAIL_ACCOUNT_STORE (store), FALSE);
-
-	return store->priv->express_mode;
-}
-
-void
-e_mail_account_store_set_express_mode (EMailAccountStore *store,
-                                       gboolean express_mode)
-{
-	g_return_if_fail (E_IS_MAIL_ACCOUNT_STORE (store));
-
-	if (store->priv->express_mode == express_mode)
-		return;
-
-	store->priv->express_mode = express_mode;
-
-	g_object_notify (G_OBJECT (store), "express-mode");
-}
-
 void
 e_mail_account_store_add_service (EMailAccountStore *store,
                                   CamelService *service)
