@@ -138,17 +138,8 @@ mail_backend_prepare_for_offline_cb (EShell *shell,
 	GQueue queue = G_QUEUE_INIT;
 	gboolean synchronize = FALSE;
 
-	if (e_shell_backend_is_started (E_SHELL_BACKEND (backend))) {
-		if (!e_activity_get_cancellable (activity)) {
-			GCancellable *cancellable;
-
-			cancellable = camel_operation_new ();
-			e_activity_set_cancellable (activity, cancellable);
-			g_object_unref (cancellable);
-		}
-
+	if (e_shell_backend_is_started (E_SHELL_BACKEND (backend)))
 		e_shell_backend_add_activity (E_SHELL_BACKEND (backend), activity);
-	}
 
 	window = e_shell_get_active_window (shell);
 	session = e_mail_backend_get_session (backend);
@@ -165,6 +156,17 @@ mail_backend_prepare_for_offline_cb (EShell *shell,
 			CAMEL_SESSION (session), FALSE);
 	}
 
+	/* Set the cancellable only here, because mail_cancel_all() would
+	   cancel the just added CamelOperation as well. */
+	if (e_shell_backend_is_started (E_SHELL_BACKEND (backend)) &&
+	    !e_activity_get_cancellable (activity)) {
+		GCancellable *cancellable;
+
+		cancellable = camel_operation_new ();
+		e_activity_set_cancellable (activity, cancellable);
+		g_object_unref (cancellable);
+	}
+
 	e_mail_account_store_queue_enabled_services (account_store, &queue);
 	while (!g_queue_is_empty (&queue)) {
 		CamelService *service;
@@ -206,7 +208,6 @@ mail_backend_prepare_for_online_cb (EShell *shell,
 	session = e_mail_backend_get_session (backend);
 	account_store = e_mail_ui_session_get_account_store (E_MAIL_UI_SESSION (session));
 
-	camel_session_set_network_available (CAMEL_SESSION (session), TRUE);
 	camel_session_set_online (CAMEL_SESSION (session), TRUE);
 
 	e_mail_account_store_queue_enabled_services (account_store, &queue);
@@ -383,11 +384,6 @@ mail_backend_quit_requested_cb (EShell *shell,
 	if (reason == E_SHELL_QUIT_REMOTE_REQUEST)
 		return;
 
-	/* In express mode, don't raise mail request in non mail window. */
-	if (e_shell_get_express_mode (shell) &&
-		strcmp (e_shell_window_get_active_view ((EShellWindow *) window), "mail") != 0)
-		return;
-
 	if (!e_shell_backend_is_started (mail_shell_backend))
 		return;
 
