@@ -28,16 +28,13 @@
 #include <string.h>
 #include <glib/gi18n.h>
 
-#include <shell/e-shell.h>
-#include <shell/e-shell-utils.h>
-#include <shell/e-shell-settings.h>
+#include "shell/e-shell.h"
+#include "shell/e-shell-utils.h"
 
-#include <em-format/e-mail-formatter-enumtypes.h>
-
-#include "e-mail-reader.h"
-#include "e-mail-reader-utils.h"
-#include "em-folder-tree-model.h"
-#include "message-list.h"
+#include "mail/e-mail-reader.h"
+#include "mail/e-mail-reader-utils.h"
+#include "mail/em-folder-tree-model.h"
+#include "mail/message-list.h"
 
 #define E_MAIL_BROWSER_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
@@ -51,7 +48,7 @@ struct _EMailBrowserPrivate {
 	GtkUIManager *ui_manager;
 	EFocusTracker *focus_tracker;
 
-	EMailFormatterMode display_mode;
+	EMailFormatterMode mode;
 
 	GtkWidget *main_menu;
 	GtkWidget *main_toolbar;
@@ -65,13 +62,13 @@ struct _EMailBrowserPrivate {
 enum {
 	PROP_0,
 	PROP_BACKEND,
-	PROP_DISPLAY_MODE,
 	PROP_FOCUS_TRACKER,
 	PROP_FORWARD_STYLE,
 	PROP_GROUP_BY_THREADS,
-	PROP_REPLY_STYLE,
 	PROP_SHOW_DELETED,
-	PROP_UI_MANAGER
+	PROP_REPLY_STYLE,
+	PROP_UI_MANAGER,
+	PROP_DISPLAY_MODE,
 };
 
 /* This is too trivial to put in a file.
@@ -303,7 +300,7 @@ mail_browser_message_list_built_cb (EMailBrowser *browser,
 	g_return_if_fail (E_IS_MAIL_BROWSER (browser));
 	g_return_if_fail (IS_MESSAGE_LIST (message_list));
 
-	if (message_list_count (message_list) == 0)
+	if (!message_list_count (message_list))
 		/* Prioritize ahead of GTK+ redraws. */
 		g_idle_add_full (
 			G_PRIORITY_HIGH_IDLE,
@@ -367,13 +364,6 @@ mail_browser_set_backend (EMailBrowser *browser,
 	browser->priv->backend = g_object_ref (backend);
 }
 
-static void
-mail_browser_set_display_mode (EMailBrowser *browser,
-                               EMailFormatterMode display_mode)
-{
-	browser->priv->display_mode = display_mode;
-}
-
 static void
 mail_browser_set_property (GObject *object,
                            guint property_id,
@@ -387,12 +377,6 @@ mail_browser_set_property (GObject *object,
 				g_value_get_object (value));
 			return;
 
-		case PROP_DISPLAY_MODE:
-			mail_browser_set_display_mode (
-				E_MAIL_BROWSER (object),
-				g_value_get_enum (value));
-			return;
-
 		case PROP_FORWARD_STYLE:
 			e_mail_reader_set_forward_style (
 				E_MAIL_READER (object),
@@ -416,6 +400,11 @@ mail_browser_set_property (GObject *object,
 				E_MAIL_BROWSER (object),
 				g_value_get_boolean (value));
 			return;
+
+		case PROP_DISPLAY_MODE:
+			E_MAIL_BROWSER (object)->priv->mode =
+				g_value_get_int (value);
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -430,59 +419,50 @@ mail_browser_get_property (GObject *object,
 	switch (property_id) {
 		case PROP_BACKEND:
 			g_value_set_object (
-				value,
-				e_mail_reader_get_backend (
+				value, e_mail_reader_get_backend (
 				E_MAIL_READER (object)));
 			return;
 
-		case PROP_DISPLAY_MODE:
-			g_value_set_enum (
-				value,
-				e_mail_browser_get_display_mode (
-				E_MAIL_BROWSER (object)));
-			return;
-
 		case PROP_FOCUS_TRACKER:
 			g_value_set_object (
-				value,
-				e_mail_browser_get_focus_tracker (
+				value, e_mail_browser_get_focus_tracker (
 				E_MAIL_BROWSER (object)));
 			return;
 
 		case PROP_FORWARD_STYLE:
 			g_value_set_enum (
-				value,
-				e_mail_reader_get_forward_style (
+				value, e_mail_reader_get_forward_style (
 				E_MAIL_READER (object)));
 			return;
 
 		case PROP_GROUP_BY_THREADS:
 			g_value_set_boolean (
-				value,
-				e_mail_reader_get_group_by_threads (
+				value, e_mail_reader_get_group_by_threads (
 				E_MAIL_READER (object)));
 			return;
 
 		case PROP_REPLY_STYLE:
 			g_value_set_enum (
-				value,
-				e_mail_reader_get_reply_style (
+				value, e_mail_reader_get_reply_style (
 				E_MAIL_READER (object)));
 			return;
 
 		case PROP_SHOW_DELETED:
 			g_value_set_boolean (
-				value,
-				e_mail_browser_get_show_deleted (
+				value, e_mail_browser_get_show_deleted (
 				E_MAIL_BROWSER (object)));
 			return;
 
 		case PROP_UI_MANAGER:
 			g_value_set_object (
-				value,
-				e_mail_browser_get_ui_manager (
+				value, e_mail_browser_get_ui_manager (
 				E_MAIL_BROWSER (object)));
 			return;
+
+		case PROP_DISPLAY_MODE:
+			g_value_set_int (
+				value, E_MAIL_BROWSER (object)->priv->mode);
+			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -495,13 +475,30 @@ mail_browser_dispose (GObject *object)
 
 	priv = E_MAIL_BROWSER_GET_PRIVATE (object);
 
-	g_clear_object (&priv->backend);
-	g_clear_object (&priv->ui_manager);
-	g_clear_object (&priv->focus_tracker);
-	g_clear_object (&priv->main_menu);
-	g_clear_object (&priv->main_toolbar);
-	g_clear_object (&priv->preview_pane);
-	g_clear_object (&priv->statusbar);
+	if (priv->backend != NULL) {
+		g_object_unref (priv->backend);
+		priv->backend = NULL;
+	}
+
+	if (priv->ui_manager != NULL) {
+		g_object_unref (priv->ui_manager);
+		priv->ui_manager = NULL;
+	}
+
+	if (priv->focus_tracker != NULL) {
+		g_object_unref (priv->focus_tracker);
+		priv->focus_tracker = NULL;
+	}
+
+	if (priv->main_menu != NULL) {
+		g_object_unref (priv->main_menu);
+		priv->main_menu = NULL;
+	}
+
+	if (priv->main_toolbar != NULL) {
+		g_object_unref (priv->main_toolbar);
+		priv->main_toolbar = NULL;
+	}
 
 	if (priv->message_list != NULL) {
 		/* This will cancel a regen operation. */
@@ -509,6 +506,16 @@ mail_browser_dispose (GObject *object)
 		priv->message_list = NULL;
 	}
 
+	if (priv->preview_pane != NULL) {
+		g_object_unref (priv->preview_pane);
+		priv->preview_pane = NULL;
+	}
+
+	if (priv->statusbar != NULL) {
+		g_object_unref (priv->statusbar);
+		priv->statusbar = NULL;
+	}
+
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (e_mail_browser_parent_class)->dispose (object);
 }
@@ -520,6 +527,7 @@ mail_browser_constructed (GObject *object)
 	EMailReader *reader;
 	EMailBackend *backend;
 	EMailSession *session;
+	EMailDisplay *display;
 	EShellBackend *shell_backend;
 	EShell *shell;
 	EFocusTracker *focus_tracker;
@@ -529,7 +537,6 @@ mail_browser_constructed (GObject *object)
 	GtkAction *action;
 	GtkUIManager *ui_manager;
 	GtkWidget *container;
-	GtkWidget *display;
 	GtkWidget *widget;
 	const gchar *domain;
 	const gchar *id;
@@ -546,8 +553,7 @@ mail_browser_constructed (GObject *object)
 	shell_backend = E_SHELL_BACKEND (backend);
 	shell = e_shell_backend_get_shell (shell_backend);
 
-	ui_manager = e_ui_manager_new ();
-	e_shell_configure_ui_manager (shell, E_UI_MANAGER (ui_manager));
+	ui_manager = gtk_ui_manager_new ();
 
 	browser->priv->ui_manager = ui_manager;
 	domain = GETTEXT_PACKAGE;
@@ -569,11 +575,9 @@ mail_browser_constructed (GObject *object)
 		browser->priv->message_list, "message-list-built",
 		G_CALLBACK (mail_browser_message_list_built_cb), object);
 
-	display = e_mail_display_new ();
-
-	e_mail_display_set_mode (
-		E_MAIL_DISPLAY (display),
-		browser->priv->display_mode);
+	display = g_object_new (
+		E_TYPE_MAIL_DISPLAY,
+		"mode", E_MAIL_BROWSER (object)->priv->mode, NULL);
 
 	g_signal_connect_swapped (
 		display, "popup-event",
@@ -598,6 +602,7 @@ mail_browser_constructed (GObject *object)
 	gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
 
 	/* For easy access.  Takes ownership of the reference. */
+
 	g_object_set_data_full (
 		object, ACTION_GROUP_STANDARD,
 		action_group, (GDestroyNotify) g_object_unref);
@@ -613,12 +618,10 @@ mail_browser_constructed (GObject *object)
 
 	e_mail_reader_init (reader, TRUE, TRUE);
 
-	e_ui_manager_add_ui_from_file (
-		E_UI_MANAGER (ui_manager), E_MAIL_READER_UI_DEFINITION);
-	e_ui_manager_add_ui_from_string (
-		E_UI_MANAGER (ui_manager), ui, NULL);
+	e_load_ui_manager_definition (ui_manager, E_MAIL_READER_UI_DEFINITION);
+	gtk_ui_manager_add_ui_from_string (ui_manager, ui, -1, NULL);
 
-	merge_id = gtk_ui_manager_new_merge_id (GTK_UI_MANAGER (ui_manager));
+	merge_id = gtk_ui_manager_new_merge_id (ui_manager);
 	e_mail_reader_create_charset_menu (reader, ui_manager, merge_id);
 
 	accel_group = gtk_ui_manager_get_accel_group (ui_manager);
@@ -748,23 +751,22 @@ mail_browser_get_hide_deleted (EMailReader *reader)
 static EMailDisplay *
 mail_browser_get_mail_display (EMailReader *reader)
 {
-	EPreviewPane *preview_pane;
-	EWebView *web_view;
+	EMailBrowserPrivate *priv;
 
-	preview_pane = e_mail_reader_get_preview_pane (reader);
-	web_view = e_preview_pane_get_web_view (preview_pane);
+	priv = E_MAIL_BROWSER_GET_PRIVATE (E_MAIL_BROWSER (reader));
 
-	return E_MAIL_DISPLAY (web_view);
+	return E_MAIL_DISPLAY (e_preview_pane_get_web_view (
+					E_PREVIEW_PANE (priv->preview_pane)));
 }
 
 static GtkWidget *
 mail_browser_get_message_list (EMailReader *reader)
 {
-	EMailBrowserPrivate *priv;
+	EMailBrowser *browser;
 
-	priv = E_MAIL_BROWSER_GET_PRIVATE (reader);
+	browser = E_MAIL_BROWSER (reader);
 
-	return priv->message_list;
+	return browser->priv->message_list;
 }
 
 static GtkMenu *
@@ -784,11 +786,11 @@ mail_browser_get_popup_menu (EMailReader *reader)
 static EPreviewPane *
 mail_browser_get_preview_pane (EMailReader *reader)
 {
-	EMailBrowserPrivate *priv;
+	EMailBrowser *browser;
 
-	priv = E_MAIL_BROWSER_GET_PRIVATE (reader);
+	browser = E_MAIL_BROWSER (reader);
 
-	return E_PREVIEW_PANE (priv->preview_pane);
+	return E_PREVIEW_PANE (browser->priv->preview_pane);
 }
 
 static GtkWindow *
@@ -825,70 +827,6 @@ mail_browser_set_message (EMailReader *reader,
 	}
 }
 
-static void
-mail_browser_composer_created (EMailReader *reader,
-                               EMsgComposer *composer,
-                               CamelMimeMessage *message)
-{
-	GSettings *settings;
-	const gchar *key;
-	gchar *value;
-	gboolean close_browser;
-
-	/* Do not prompt if there is no source message.  It means
-	 * the user wants to start a brand new message, presumably
-	 * unrelated to the message shown in the browser window. */
-	if (message == NULL)
-		return;
-
-	settings = g_settings_new ("org.gnome.evolution.mail");
-
-	key = "prompt-on-reply-close-browser";
-	value = g_settings_get_string (settings, key);
-
-	if (g_strcmp0 (value, "always") == 0) {
-		close_browser = TRUE;
-	} else if (g_strcmp0 (value, "never") == 0) {
-		close_browser = FALSE;
-	} else {
-		GtkWidget *dialog;
-		GtkWindow *parent;
-		EShell *shell;
-		EMailBackend *backend;
-		EShellBackend *shell_backend;
-		gint response;
-
-		backend = e_mail_reader_get_backend (reader);
-
-		shell_backend = E_SHELL_BACKEND (backend);
-		shell = e_shell_backend_get_shell (shell_backend);
-
-		parent = e_shell_get_active_window (shell);
-		if (parent == NULL)
-			parent = e_mail_reader_get_window (reader);
-
-		dialog = e_alert_dialog_new_for_args (
-			parent, "mail:ask-reply-close-browser", NULL);
-		response = gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-
-		close_browser =
-			(response == GTK_RESPONSE_YES) ||
-			(response == GTK_RESPONSE_OK);
-
-		if (response == GTK_RESPONSE_OK)
-			g_settings_set_string (settings, key, "always");
-		else if (response == GTK_RESPONSE_CANCEL)
-			g_settings_set_string (settings, key, "never");
-	}
-
-	g_free (value);
-	g_object_unref (settings);
-
-	if (close_browser)
-		e_mail_browser_close (E_MAIL_BROWSER (reader));
-}
-
 static void
 e_mail_browser_class_init (EMailBrowserClass *class)
 {
@@ -915,21 +853,7 @@ e_mail_browser_class_init (EMailBrowserClass *class)
 			"The mail backend",
 			E_TYPE_MAIL_BACKEND,
 			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT_ONLY |
-			G_PARAM_STATIC_STRINGS));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_DISPLAY_MODE,
-		g_param_spec_enum (
-			"display-mode",
-			"Display Mode",
-			NULL,
-			E_TYPE_MAIL_FORMATTER_MODE,
-			E_MAIL_FORMATTER_MODE_NORMAL,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT_ONLY |
-			G_PARAM_STATIC_STRINGS));
+			G_PARAM_CONSTRUCT_ONLY));
 
 	g_object_class_install_property (
 		object_class,
@@ -939,8 +863,7 @@ e_mail_browser_class_init (EMailBrowserClass *class)
 			"Focus Tracker",
 			NULL,
 			E_TYPE_FOCUS_TRACKER,
-			G_PARAM_READABLE |
-			G_PARAM_STATIC_STRINGS));
+			G_PARAM_READABLE));
 
 	/* Inherited from EMailReader */
 	g_object_class_override_property (
@@ -968,19 +891,19 @@ e_mail_browser_class_init (EMailBrowserClass *class)
 			"Show Deleted",
 			"Show deleted messages",
 			FALSE,
-			G_PARAM_READWRITE |
-			G_PARAM_STATIC_STRINGS));
+			G_PARAM_READWRITE));
 
 	g_object_class_install_property (
 		object_class,
-		PROP_UI_MANAGER,
-		g_param_spec_object (
-			"ui-manager",
-			"UI Manager",
+		PROP_DISPLAY_MODE,
+		g_param_spec_int (
+			"display-mode",
+			"Display Mode",
 			NULL,
-			GTK_TYPE_UI_MANAGER,
-			G_PARAM_READABLE |
-			G_PARAM_STATIC_STRINGS));
+			0,
+			G_MAXINT,
+			E_MAIL_FORMATTER_MODE_NORMAL,
+			G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
 }
 
 static void
@@ -995,7 +918,6 @@ e_mail_browser_reader_init (EMailReaderInterface *interface)
 	interface->get_preview_pane = mail_browser_get_preview_pane;
 	interface->get_window = mail_browser_get_window;
 	interface->set_message = mail_browser_set_message;
-	interface->composer_created = mail_browser_composer_created;
 }
 
 static void
@@ -1016,15 +938,19 @@ GtkWidget *
 e_mail_browser_new (EMailBackend *backend,
                     CamelFolder *folder,
                     const gchar *msg_uid,
-                    EMailFormatterMode display_mode)
+                    EMailFormatterMode mode)
 {
+	GtkWidget *widget;
+
 	g_return_val_if_fail (E_IS_MAIL_BACKEND (backend), NULL);
 
-	return g_object_new (
+	widget= g_object_new (
 		E_TYPE_MAIL_BROWSER,
 		"backend", backend,
-		"display-mode", display_mode,
+		"display-mode", mode,
 		NULL);
+
+	return widget;
 }
 
 void
@@ -1035,24 +961,6 @@ e_mail_browser_close (EMailBrowser *browser)
 	gtk_widget_destroy (GTK_WIDGET (browser));
 }
 
-EMailFormatterMode
-e_mail_browser_get_display_mode (EMailBrowser *browser)
-{
-	g_return_val_if_fail (
-		E_IS_MAIL_BROWSER (browser),
-		E_MAIL_FORMATTER_MODE_INVALID);
-
-	return browser->priv->display_mode;
-}
-
-EFocusTracker *
-e_mail_browser_get_focus_tracker (EMailBrowser *browser)
-{
-	g_return_val_if_fail (E_IS_MAIL_BROWSER (browser), NULL);
-
-	return browser->priv->focus_tracker;
-}
-
 gboolean
 e_mail_browser_get_show_deleted (EMailBrowser *browser)
 {
@@ -1075,6 +983,14 @@ e_mail_browser_set_show_deleted (EMailBrowser *browser,
 	g_object_notify (G_OBJECT (browser), "show-deleted");
 }
 
+EFocusTracker *
+e_mail_browser_get_focus_tracker (EMailBrowser *browser)
+{
+	g_return_val_if_fail (E_IS_MAIL_BROWSER (browser), NULL);
+
+	return browser->priv->focus_tracker;
+}
+
 GtkUIManager *
 e_mail_browser_get_ui_manager (EMailBrowser *browser)
 {
