@@ -19,20 +19,22 @@
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "e-mail-display.h"
 
-#include <config.h>
 #include <glib/gi18n.h>
-
 #include <gdk/gdk.h>
+
 #include <camel/camel.h>
 
-#include <em-format/e-mail-extension-registry.h>
-#include <em-format/e-mail-formatter-enumtypes.h>
-#include <em-format/e-mail-formatter-extension.h>
-#include <em-format/e-mail-formatter-print.h>
-#include <em-format/e-mail-part-attachment.h>
-#include <em-format/e-mail-part-utils.h>
+#include "em-format/e-mail-part-utils.h"
+#include "em-format/e-mail-formatter-extension.h"
+#include "em-format/e-mail-extension-registry.h"
+#include "em-format/e-mail-part-attachment.h"
+#include "em-format/e-mail-formatter-print.h"
 
 #include "e-http-request.h"
 #include "e-mail-display-popup-extension.h"
@@ -70,11 +72,11 @@ struct _EMailDisplayPrivate {
 
 enum {
 	PROP_0,
-	PROP_FORMATTER,
+	PROP_MODE,
+	PROP_PART_LIST,
 	PROP_HEADERS_COLLAPSABLE,
 	PROP_HEADERS_COLLAPSED,
-	PROP_MODE,
-	PROP_PART_LIST
+	PROP_FORMATTER
 };
 
 static CamelDataCache *emd_global_http_cache = NULL;
@@ -193,15 +195,11 @@ mail_display_image_exists_in_cache (const gchar *image_uri)
 static void
 mail_display_update_formatter_colors (EMailDisplay *display)
 {
-	GtkStyle *style;
-	GtkStateType state;
-
 	if (display->priv->formatter == NULL)
 		return;
 
-	style = gtk_widget_get_style (GTK_WIDGET (display));
-	state = gtk_widget_get_state (GTK_WIDGET (display));
-	e_mail_formatter_set_style (display->priv->formatter, style, state);
+	e_mail_formatter_update_style (display->priv->formatter,
+		gtk_widget_get_state_flags (GTK_WIDGET (display)));
 }
 
 static void
@@ -489,7 +487,7 @@ mail_display_plugin_widget_resize (GtkWidget *widget,
 	if (!WEBKIT_DOM_IS_ELEMENT (parent_element)) {
 		d (
 			printf ("%s: %s does not have (valid) parent element!\n",
-			G_STRFUNC, (gchar *) g_object_get_data (object, "uri")));
+			G_STRFUNC, (gchar *) g_object_get_data (G_OBJECT (widget), "uri")));
 		return;
 	}
 
@@ -692,9 +690,8 @@ attachment_button_expanded (GObject *object,
 	WebKitDOMDocument *document;
 	WebKitDOMElement *element;
 	WebKitDOMCSSStyleDeclaration *css;
-	const gchar *attachment_part_id;
-	gchar *element_id;
 	gboolean expanded;
+	gchar *id;
 
 	d (
 		printf ("Attachment button %s has been %s!\n",
@@ -706,11 +703,8 @@ attachment_button_expanded (GObject *object,
 		gtk_widget_get_visible (GTK_WIDGET (button));
 
 	document = webkit_web_view_get_dom_document (WEBKIT_WEB_VIEW (display));
-	attachment_part_id = g_object_get_data (object, "attachment_id");
-
-	element_id = g_strconcat (attachment_part_id, ".wrapper", NULL);
-	element = find_element_by_id (document, element_id);
-	g_free (element_id);
+	element = find_element_by_id (
+		document, g_object_get_data (object, "attachment_id"));
 
 	if (!WEBKIT_DOM_IS_ELEMENT (element)) {
 		d (
@@ -725,12 +719,16 @@ attachment_button_expanded (GObject *object,
 	webkit_dom_css_style_declaration_set_property (
 		css, "display", expanded ? "block" : "none", "", NULL);
 
-	element_id = g_strconcat (attachment_part_id, ".iframe", NULL);
-	element = find_element_by_id (document, element_id);
-	g_free (element_id);
+	id = g_strconcat (
+		g_object_get_data (object, "attachment_id"),
+		".iframe", NULL);
+	element = find_element_by_id (document, id);
+	g_free (id);
 
 	if (!WEBKIT_DOM_IS_HTML_IFRAME_ELEMENT (element)) {
-		d (printf ("%s: No <iframe> found\n", attachment_part_id));
+		d (
+			printf ("%s: No <iframe> found\n",
+			(gchar *) g_object_get_data (object, "attachment_id")));
 		return;
 	}
 	bind_iframe_content_visibility (element, display, button);
@@ -913,7 +911,6 @@ mail_display_plugin_widget_requested (WebKitWebView *web_view,
 		WebKitDOMDocument *document;
 		EMailPartAttachment *empa = (EMailPartAttachment *) part;
 		gchar *attachment_part_id;
-		gchar *wrapper_element_id;
 
 		if (empa->attachment_view_part_id)
 			attachment_part_id = empa->attachment_view_part_id;
@@ -924,10 +921,7 @@ mail_display_plugin_widget_requested (WebKitWebView *web_view,
 		 * the content of the attachment (iframe). */
 		document = webkit_web_view_get_dom_document (
 			WEBKIT_WEB_VIEW (display));
-		wrapper_element_id = g_strconcat (
-			attachment_part_id, ".wrapper", NULL);
-		attachment = find_element_by_id (document, wrapper_element_id);
-		g_free (wrapper_element_id);
+		attachment = find_element_by_id (document, attachment_part_id);
 
 		/* None found? Attachment cannot be expanded */
 		if (attachment == NULL) {
@@ -1013,15 +1007,15 @@ toggle_headers_visibility (WebKitDOMElement *button,
 	css_full = webkit_dom_element_get_style (full_headers);
 	css_value = webkit_dom_css_style_declaration_get_property_value (
 		css_full, "display");
-	expanded = (g_strcmp0 (css_value, "table") == 0);
+	expanded = (g_strcmp0 (css_value, "block") == 0);
 	g_free (css_value);
 
 	webkit_dom_css_style_declaration_set_property (
 		css_full, "display",
-		expanded ? "none" : "table", "", NULL);
+		expanded ? "none" : "block", "", NULL);
 	webkit_dom_css_style_declaration_set_property (
 		css_short, "display",
-		expanded ? "table" : "none", "", NULL);
+		expanded ? "block" : "none", "", NULL);
 
 	if (expanded)
 		path = "evo-file://" EVOLUTION_IMAGESDIR "/plus.png";
@@ -1257,29 +1251,26 @@ mail_display_set_property (GObject *object,
                            GParamSpec *pspec)
 {
 	switch (property_id) {
+		case PROP_PART_LIST:
+			e_mail_display_set_parts_list (
+				E_MAIL_DISPLAY (object),
+				g_value_get_pointer (value));
+			return;
+		case PROP_MODE:
+			e_mail_display_set_mode (
+				E_MAIL_DISPLAY (object),
+				g_value_get_int (value));
+			return;
 		case PROP_HEADERS_COLLAPSABLE:
 			e_mail_display_set_headers_collapsable (
 				E_MAIL_DISPLAY (object),
 				g_value_get_boolean (value));
 			return;
-
 		case PROP_HEADERS_COLLAPSED:
 			e_mail_display_set_headers_collapsed (
 				E_MAIL_DISPLAY (object),
 				g_value_get_boolean (value));
 			return;
-
-		case PROP_MODE:
-			e_mail_display_set_mode (
-				E_MAIL_DISPLAY (object),
-				g_value_get_enum (value));
-			return;
-
-		case PROP_PART_LIST:
-			e_mail_display_set_parts_list (
-				E_MAIL_DISPLAY (object),
-				g_value_get_pointer (value));
-			return;
 	}
 
 	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -1294,36 +1285,27 @@ mail_display_get_property (GObject *object,
 	switch (property_id) {
 		case PROP_FORMATTER:
 			g_value_set_object (
-				value,
-				e_mail_display_get_formatter (
+				value, e_mail_display_get_formatter (
 				E_MAIL_DISPLAY (object)));
 			return;
-
-		case PROP_HEADERS_COLLAPSABLE:
-			g_value_set_boolean (
-				value,
-				e_mail_display_get_headers_collapsable (
-				E_MAIL_DISPLAY (object)));
-			return;
-
-		case PROP_HEADERS_COLLAPSED:
-			g_value_set_boolean (
-				value,
-				e_mail_display_get_headers_collapsed (
-				E_MAIL_DISPLAY (object)));
-			return;
-
-		case PROP_MODE:
-			g_value_set_enum (
-				value,
-				e_mail_display_get_mode (
-				E_MAIL_DISPLAY (object)));
-			return;
-
 		case PROP_PART_LIST:
 			g_value_set_pointer (
-				value,
-				e_mail_display_get_parts_list (
+				value, e_mail_display_get_parts_list (
+				E_MAIL_DISPLAY (object)));
+			return;
+		case PROP_MODE:
+			g_value_set_int (
+				value, e_mail_display_get_mode (
+				E_MAIL_DISPLAY (object)));
+			return;
+		case PROP_HEADERS_COLLAPSABLE:
+			g_value_set_boolean (
+				value, e_mail_display_get_headers_collapsable (
+				E_MAIL_DISPLAY (object)));
+			return;
+		case PROP_HEADERS_COLLAPSED:
+			g_value_set_boolean (
+				value, e_mail_display_get_headers_collapsed (
 				E_MAIL_DISPLAY (object)));
 			return;
 	}
@@ -1351,14 +1333,16 @@ mail_display_dispose (GObject *object)
 		priv->widgets = NULL;
 	}
 
-	if (priv->settings != NULL)
+	if (priv->settings != NULL) {
 		g_signal_handlers_disconnect_matched (
 			priv->settings, G_SIGNAL_MATCH_DATA,
 			0, 0, NULL, NULL, object);
+		g_object_unref (priv->settings);
+		priv->settings = NULL;
+	}
 
 	g_clear_object (&priv->part_list);
 	g_clear_object (&priv->formatter);
-	g_clear_object (&priv->settings);
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (e_mail_display_parent_class)->dispose (object);
@@ -1383,16 +1367,15 @@ mail_display_realize (GtkWidget *widget)
 }
 
 static void
-mail_display_style_set (GtkWidget *widget,
-                        GtkStyle *previous_style)
+mail_display_style_updated (GtkWidget *widget)
 {
 	EMailDisplay *display = E_MAIL_DISPLAY (widget);
 
 	mail_display_update_formatter_colors (display);
 
-	/* Chain up to parent's style_set() method. */
+	/* Chain up to parent's style_updated() method. */
 	GTK_WIDGET_CLASS (e_mail_display_parent_class)->
-		style_set (widget, previous_style);
+		style_updated (widget);
 }
 
 static gboolean
@@ -1502,7 +1485,7 @@ e_mail_display_class_init (EMailDisplayClass *class)
 
 	widget_class = GTK_WIDGET_CLASS (class);
 	widget_class->realize = mail_display_realize;
-	widget_class->style_set = mail_display_style_set;
+	widget_class->style_updated = mail_display_style_updated;
 	widget_class->button_press_event = mail_display_button_press_event;
 
 	web_view_class = E_WEB_VIEW_CLASS (class);
@@ -1518,6 +1501,29 @@ e_mail_display_class_init (EMailDisplayClass *class)
 			G_PARAM_READABLE |
 			G_PARAM_STATIC_STRINGS));
 
+	g_object_class_install_property (
+		object_class,
+		PROP_PART_LIST,
+		g_param_spec_pointer (
+			"part-list",
+			"Part List",
+			NULL,
+			G_PARAM_READWRITE |
+			G_PARAM_STATIC_STRINGS));
+
+	g_object_class_install_property (
+		object_class,
+		PROP_MODE,
+		g_param_spec_int (
+			"mode",
+			"Display Mode",
+			NULL,
+			E_MAIL_FORMATTER_MODE_INVALID,
+			G_MAXINT,
+			E_MAIL_FORMATTER_MODE_NORMAL,
+			G_PARAM_READWRITE |
+			G_PARAM_STATIC_STRINGS));
+
 	g_object_class_install_property (
 		object_class,
 		PROP_HEADERS_COLLAPSABLE,
@@ -1539,28 +1545,6 @@ e_mail_display_class_init (EMailDisplayClass *class)
 			FALSE,
 			G_PARAM_READWRITE |
 			G_PARAM_STATIC_STRINGS));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_MODE,
-		g_param_spec_enum (
-			"mode",
-			"Mode",
-			NULL,
-			E_TYPE_MAIL_FORMATTER_MODE,
-			E_MAIL_FORMATTER_MODE_NORMAL,
-			G_PARAM_READWRITE |
-			G_PARAM_STATIC_STRINGS));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_PART_LIST,
-		g_param_spec_pointer (
-			"part-list",
-			"Part List",
-			NULL,
-			G_PARAM_READWRITE |
-			G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -1660,18 +1644,12 @@ e_mail_display_init (EMailDisplay *display)
 	}
 }
 
-GtkWidget *
-e_mail_display_new (void)
-{
-	return g_object_new (E_TYPE_MAIL_DISPLAY, NULL);
-}
-
 EMailFormatterMode
 e_mail_display_get_mode (EMailDisplay *display)
 {
 	g_return_val_if_fail (
 		E_IS_MAIL_DISPLAY (display),
-		E_MAIL_FORMATTER_MODE_INVALID);
+		E_MAIL_FORMATTER_MODE_NORMAL);
 
 	return display->priv->mode;
 }
@@ -1988,11 +1966,11 @@ e_mail_display_set_status (EMailDisplay *display,
 		"  </table>\n"
 		"</body>\n"
 		"</html>\n",
-		e_color_to_value ((GdkColor *)
+		e_rgba_to_value (
 			e_mail_formatter_get_color (
 				display->priv->formatter,
 				E_MAIL_FORMATTER_COLOR_CONTENT)),
-		e_color_to_value ((GdkColor *)
+		e_rgba_to_value (
 			e_mail_formatter_get_color (
 				display->priv->formatter,
 				E_MAIL_FORMATTER_COLOR_TEXT)),
