@@ -46,17 +46,10 @@
 #include <libxml/parser.h>
 #include <libxml/xmlmemory.h>
 
-#include <shell/e-shell.h>
-#include <shell/e-shell-migrate.h>
+#include "shell/e-shell.h"
+#include "shell/e-shell-migrate.h"
 
-#include <e-util/e-util.h>
-#include <libevolution-utils/e-xml-utils.h>
-
-#include <libevolution-utils/e-alert-dialog.h>
-#include <e-util/e-util-private.h>
-#include <e-util/e-plugin.h>
-
-#include <libemail-engine/e-mail-folder-utils.h>
+#include "libemail-engine/e-mail-folder-utils.h"
 
 #include "e-mail-backend.h"
 #include "em-utils.h"
@@ -319,21 +312,9 @@ e_mail_migrate (EShellBackend *shell_backend,
                 gint micro,
                 GError **error)
 {
-	struct stat st;
 	const gchar *data_dir;
 
-	/* make sure ~/.evolution/mail exists */
 	data_dir = e_shell_backend_get_data_dir (shell_backend);
-	if (g_stat (data_dir, &st) == -1) {
-		if (errno != ENOENT || g_mkdir_with_parents (data_dir, 0700) == -1) {
-			g_set_error (
-				error, E_SHELL_MIGRATE_ERROR,
-				E_SHELL_MIGRATE_ERROR_FAILED,
-				_("Unable to create local mail folders at "
-				"'%s': %s"), data_dir, g_strerror (errno));
-			return FALSE;
-		}
-	}
 
 	if (major == 0)
 		return emm_setup_initial (data_dir);
