@@ -63,6 +63,7 @@
 #include "e-mail-printer.h"
 
 /* XXX This is a dirty hack on a dirty hack.  We really need
+#include <em-format/e-mail-print-formatter.h>
  *     to rework or get rid of the functions that use this. */
 extern const gchar *shell_builtin_backend;
 
@@ -70,6 +71,12 @@ extern const gchar *shell_builtin_backend;
 /* Used in em_util_ask_open_many() */
 #define TOO_MANY 10
 
+/* drag and drop resulting file naming possibilities */
+enum {
+	DND_USE_SENT_DATE = 1, /* YYYYMMDDhhmmssms_<title> and use email sent date */
+	DND_USE_DND_DATE  = 2,  /*  YYYYMMDDhhmmssms_<title> and drag'drop date */
+};
+
 #define d(x)
 
 gboolean
@@ -577,17 +584,39 @@ em_utils_write_messages_to_stream (CamelFolder *folder,
 	return res;
 }
 
+static void
+do_print_msg_to_file (GObject *source,
+                      GAsyncResult *result,
+                      gpointer user_data)
+{
+	EMailParser *parser;
+	EMailPartList *parts_list;
+	gchar *filename = user_data;
+	EMailPrinter *printer;
+
+	parser = E_MAIL_PARSER (source);
+	parts_list = e_mail_parser_parse_finish (parser, result, NULL);
+
+	printer = e_mail_printer_new (parts_list);
+	e_mail_printer_set_export_filename (printer, filename);
+	g_signal_connect_swapped (
+		printer, "done",
+		G_CALLBACK (g_object_unref), printer);
+
+	e_mail_printer_print (printer, GTK_PRINT_OPERATION_ACTION_EXPORT, NULL, NULL);
+
+	g_object_unref (parser);
+}
+
 static gboolean
 em_utils_print_messages_to_file (CamelFolder *folder,
                                  const gchar *uid,
                                  const gchar *filename)
 {
 	EMailParser *parser;
-	EMailPartList *parts_list;
 	CamelMimeMessage *message;
 	CamelStore *parent_store;
 	CamelSession *session;
-	gboolean success = FALSE;
 
 	message = camel_folder_get_message_sync (folder, uid, NULL, NULL);
 	if (message == NULL)
@@ -598,43 +627,14 @@ em_utils_print_messages_to_file (CamelFolder *folder,
 
 	parser = e_mail_parser_new (session);
 
-	/* XXX em_utils_selection_set_urilist() is synchronous,
-	 *     so this function has to be synchronous as well.
-	 *     That means potentially blocking for awhile. */
-	parts_list = e_mail_parser_parse_sync (
-		parser, folder, uid, message, NULL);
-	if (parts_list != NULL) {
-		EAsyncClosure *closure;
-		GAsyncResult *result;
-		EMailPrinter *printer;
-		GtkPrintOperationResult print_result;
+	e_mail_parser_parse (
+		parser, folder, uid, message,
+		(GAsyncReadyCallback) do_print_msg_to_file,
+		NULL, g_strdup (filename));
 
-		printer = e_mail_printer_new (parts_list);
-		e_mail_printer_set_export_filename (printer, filename);
-
-		closure = e_async_closure_new ();
-
-		e_mail_printer_print (
-			printer, GTK_PRINT_OPERATION_ACTION_EXPORT,
-			NULL, NULL, e_async_closure_callback, closure);
-
-		result = e_async_closure_wait (closure);
-
-		print_result = e_mail_printer_print_finish (
-			printer, result, NULL);
-
-		e_async_closure_free (closure);
-
-		g_object_unref (printer);
-		g_object_unref (parts_list);
-
-		success = (print_result != GTK_PRINT_OPERATION_RESULT_ERROR);
-	}
-
-	g_object_unref (parser);
 	g_object_unref (session);
 
-	return success;
+	return TRUE;
 }
 
 /* This kind of sucks, because for various reasons most callers need to run
@@ -945,41 +945,57 @@ em_utils_selection_get_uidlist (GtkSelectionData *selection_data,
 }
 
 static gchar *
-em_utils_build_export_basename (CamelFolder *folder,
+em_utils_build_export_filename (CamelFolder *folder,
                                 const gchar *uid,
-                                const gchar *extension)
+                                const gchar *exporttype,
+                                gint exportname,
+                                const gchar *tmpdir)
 {
 	CamelMessageInfo *info;
-	gchar *basename;
-	const gchar *subject = NULL;
-	struct tm *ts;
-	time_t reftime;
+	gchar *file = NULL;
+	gchar *tmpfile = NULL;
+	struct tm  *ts;
 	gchar datetmp[15];
 
-	reftime = time (NULL);
-
-	/* Try to get the drop filename from the message or folder. */
+	/* Try to get the drop filename from the message or folder */
 	info = camel_folder_get_message_info (folder, uid);
-	if (info != NULL) {
-		subject = camel_message_info_subject (info);
-		reftime = camel_message_info_date_sent (info);
+	if (info) {
+		if (camel_message_info_subject (info)) {
+			time_t reftime;
+			reftime = camel_message_info_date_sent (info);
+			if (exportname == DND_USE_DND_DATE) {
+				reftime = time (NULL);
+			}
+
+			ts = localtime (&reftime);
+			strftime (datetmp, 15, "%Y%m%d%H%M%S", ts);
+
+			if (g_ascii_strcasecmp (exporttype, "pdf") == 0)
+				file = g_strdup_printf ("%s_%s.pdf", datetmp, camel_message_info_subject (info));
+			else
+				file = g_strdup_printf ("%s_%s", datetmp, camel_message_info_subject (info));
+
+		}
+		camel_folder_free_message_info (folder, info);
+	} else {
+		time_t reftime;
+		reftime = time (NULL);
+		ts = localtime (&reftime);
+		strftime (datetmp, 15, "%Y%m%d%H%M%S", ts);
+		if (g_ascii_strcasecmp (exporttype, "pdf") == 0)
+			file = g_strdup_printf ("%s_Untitled Message.pdf", datetmp);
+		else
+			file = g_strdup_printf ("%s_Untitled Message", datetmp);
+
 	}
 
-	ts = localtime (&reftime);
-	strftime (datetmp, sizeof (datetmp), "%Y%m%d%H%M%S", ts);
+	if (file != NULL) {
+		e_filename_make_safe (file);
+		tmpfile = g_build_filename (tmpdir, file, NULL);
+		g_free (file);
+	}
 
-	if (subject == NULL || *subject == '\0')
-		subject = "Untitled Message";
-
-	if (extension == NULL)
-		extension = "";
-
-	basename = g_strdup_printf ("%s_%s%s", datetmp, subject, extension);
-
-	if (info != NULL)
-		camel_folder_free_message_info (folder, info);
-
-	return basename;
+	return tmpfile;
 }
 
 /**
@@ -1001,126 +1017,112 @@ em_utils_selection_set_urilist (GtkSelectionData *data,
 	gchar *uri;
 	gint fd;
 	GSettings *settings;
-	gchar *save_file_format;
-	gboolean save_as_mbox;
-
-	g_return_if_fail (uids != NULL);
-
-	/* can be 0 with empty folders */
-	if (!uids->len)
-		return;
+	gchar *exporttype;
+	gint exportname;
 
 	tmpdir = e_mkdtemp ("drag-n-drop-XXXXXX");
 	if (tmpdir == NULL)
 		return;
 
 	settings = g_settings_new ("org.gnome.evolution.mail");
-
-	/* Save format is mbox unless pdf is explicitly requested. */
-	save_file_format = g_settings_get_string (
-		settings, "drag-and-drop-save-file-format");
-	save_as_mbox = (g_strcmp0 (save_file_format, "pdf") != 0);
-	g_free (save_file_format);
-
+	exporttype = g_settings_get_string (settings, "drag-and-drop-save-file-format");
+	if (g_strcmp0 (exporttype, "mbox") != 0 && g_strcmp0 (exporttype, "pdf") != 0) {
+		g_free (exporttype);
+		exporttype = g_strdup ("mbox");
+	}
+	exportname = g_settings_get_int (settings, "drag-and-drop-save-name-format");
 	g_object_unref (settings);
 
-	if (save_as_mbox) {
+	if (g_ascii_strcasecmp (exporttype, "mbox") == 0) {
+		gchar * file = NULL;
 		CamelStream *fstream;
-		gchar *basename;
-		gchar *filename;
 
 		if (uids->len > 1) {
-			basename = g_strdup_printf (
-				_("Messages from %s"),
-				camel_folder_get_display_name (folder));
+			gchar * tmp = g_strdup_printf (_("Messages from %s"), camel_folder_get_display_name (folder));
+			e_filename_make_safe (tmp);
+			file = g_build_filename (tmpdir, tmp, NULL);
+			g_free (tmp);
 		} else {
-			basename = em_utils_build_export_basename (
-				folder, uids->pdata[0], NULL);
+			file = em_utils_build_export_filename (folder, uids->pdata[0], exporttype, exportname, tmpdir);
 		}
-		e_filename_make_safe (basename);
-		filename = g_build_filename (tmpdir, basename, NULL);
-		g_free (basename);
 
-		fd = g_open (
-			filename,
-			O_WRONLY | O_CREAT | O_EXCL | O_BINARY, 0666);
+		fd = g_open (file, O_WRONLY | O_CREAT | O_EXCL | O_BINARY, 0666);
 		if (fd == -1) {
-			g_free (filename);
-			goto exit;
+			g_free (file);
+			g_free (exporttype);
+			g_free (tmpdir);
+			return;
 		}
 
-		uri = g_filename_to_uri (filename, NULL, NULL);
+		uri = g_filename_to_uri (file, NULL, NULL);
 		fstream = camel_stream_fs_new_with_fd (fd);
-		if (fstream != NULL) {
+		if (fstream) {
 			if (em_utils_write_messages_to_stream (folder, uids, fstream) == 0) {
 				GdkAtom type;
-				gchar *uri_crlf;
-
 				/* terminate with \r\n to be compliant with the spec */
-				uri_crlf = g_strconcat (uri, "\r\n", NULL);
+				gchar *uri_crlf = g_strconcat (uri, "\r\n", NULL);
 
 				type = gtk_selection_data_get_target (data);
-				gtk_selection_data_set (
-					data, type, 8,
-					(guchar *) uri_crlf,
-					strlen (uri_crlf));
+				gtk_selection_data_set (data, type, 8, (guchar *) uri_crlf, strlen (uri_crlf));
 				g_free (uri_crlf);
 			}
 			g_object_unref (fstream);
 		} else
 			close (fd);
 
-		g_free (filename);
+		g_free (exporttype);
+		g_free (tmpdir);
+		g_free (file);
 		g_free (uri);
+	} else if (g_ascii_strcasecmp (exporttype, "pdf") == 0) {
+		gchar ** filenames, **uris;
+		gint i, uris_count = 0;
 
-	} else {  /* save as pdf */
-		gchar **uris;
-		guint n_uris = 0;
-		guint ii;
-
-		uris = g_new0 (gchar *, uids->len + 1);
-		for (ii = 0; ii < uids->len; ii++) {
-			gchar *basename;
-			gchar *filename;
-			gboolean success;
-
-			basename = em_utils_build_export_basename (
-				folder, uids->pdata[ii], ".pdf");
-			e_filename_make_safe (basename);
-			filename = g_build_filename (tmpdir, basename, NULL);
-			g_free (basename);
-
+		filenames = g_new (gchar *, uids->len);
+		uris = g_new (gchar *, uids->len + 1);
+		for (i = 0; i < uids->len; i++) {
+			filenames[i] = em_utils_build_export_filename (folder, uids->pdata[i], exporttype, exportname, tmpdir);
 			/* validity test */
-			fd = g_open (
-				filename,
-				O_WRONLY | O_CREAT | O_EXCL | O_BINARY, 0666);
+			fd = g_open (filenames[i], O_WRONLY | O_CREAT | O_EXCL | O_BINARY, 0666);
 			if (fd == -1) {
-				g_strfreev (uris);
-				g_free (filename);
-				goto exit;
+				gint j;
+				for (j = 0; j <= i; j++) {
+					g_free (filenames[j]);
+				}
+				g_free (filenames);
+				g_free (uris);
+				g_free (tmpdir);
+				g_free (exporttype);
+				return;
 			}
 			close (fd);
 
 			/* export */
-			success = em_utils_print_messages_to_file (
-				folder, uids->pdata[ii], filename);
-			if (success) {
+			if (em_utils_print_messages_to_file (folder, uids->pdata[i], filenames[i])) {
 				/* terminate with \r\n to be compliant with the spec */
-				uri = g_filename_to_uri (filename, NULL, NULL);
-				uris[n_uris++] = g_strconcat (uri, "\r\n", NULL);
+				uri = g_filename_to_uri (filenames[i], NULL, NULL);
+				uris[uris_count++] = g_strconcat (uri, "\r\n", NULL);
 				g_free (uri);
 			}
-
-			g_free (filename);
 		}
 
+		uris[uris_count] = NULL;
 		gtk_selection_data_set_uris (data, uris);
 
-		g_strfreev (uris);
+		for (i = 0; i < uids->len; i++) {
+			g_free (filenames[i]);
+		}
+		g_free (filenames);
+		for (i = 0; i < uris_count; i++) {
+			g_free (uris[i]);
+		}
+		g_free (uris);
+		g_free (exporttype);
+		g_free (tmpdir);
+	} else {
+		g_free (exporttype);
+		g_free (tmpdir);
 	}
-
-exit:
-	g_free (tmpdir);
 }
 
 /**
@@ -1282,9 +1284,8 @@ em_utils_message_to_html (CamelSession *session,
 	camel_stream_mem_set_byte_array (CAMEL_STREAM_MEM (mem), buf);
 
 	formatter = e_mail_formatter_quote_new (credits, flags);
-	e_mail_formatter_set_style (formatter,
-		gtk_widget_get_style (GTK_WIDGET (window)),
-		gtk_widget_get_state (GTK_WIDGET (window)));
+	e_mail_formatter_update_style (formatter,
+		gtk_widget_get_state_flags (GTK_WIDGET (window)));
 
 	if (parts_list == NULL) {
 		GSettings *settings;
@@ -1517,7 +1518,7 @@ em_utils_is_re_in_subject (EShell *shell,
                            const gchar *subject,
                            gint *skip_len)
 {
-	EShellSettings *shell_settings;
+	GSettings *settings;
 	gchar *prefixes, **prefixes_strv;
 	gboolean res;
 	gint ii;
@@ -1534,8 +1535,10 @@ em_utils_is_re_in_subject (EShell *shell,
 	if (check_prefix (subject, "Re", skip_len))
 		return TRUE;
 
-	shell_settings = e_shell_get_shell_settings (shell);
-	prefixes = e_shell_settings_get_string (shell_settings, "composer-localized-re");
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	prefixes = g_settings_get_string (settings, "composer-localized-re");
+	g_object_unref (settings);
+
 	if (!prefixes || !*prefixes) {
 		g_free (prefixes);
 		return FALSE;
