@@ -41,7 +41,6 @@ struct _ECalShellSidebarPrivate {
 	GtkWidget *paned;
 	GtkWidget *selector;
 	GtkWidget *date_navigator;
-	GtkWidget *new_calendar_button;
 
 	/* The default client is for ECalModel.  It follows the
 	 * sidebar's primary selection, even if the highlighted
@@ -145,6 +144,46 @@ connect_closure_free (ConnectClosure *closure)
 	g_slice_free (ConnectClosure, closure);
 }
 
+static gboolean
+cal_shell_sidebar_map_uid_to_source (GValue *value,
+                                     GVariant *variant,
+                                     gpointer user_data)
+{
+	ESourceRegistry *registry;
+	ESource *source;
+	const gchar *uid;
+
+	registry = E_SOURCE_REGISTRY (user_data);
+	uid = g_variant_get_string (variant, NULL);
+	if (uid != NULL && *uid != '\0')
+		source = e_source_registry_ref_source (registry, uid);
+	else
+		source = e_source_registry_ref_default_calendar (registry);
+	g_value_take_object (value, source);
+
+	return (source != NULL);
+}
+
+static GVariant *
+cal_shell_sidebar_map_source_to_uid (const GValue *value,
+                                     const GVariantType *expected_type,
+                                     gpointer user_data)
+{
+	GVariant *variant = NULL;
+	ESource *source;
+
+	source = g_value_get_object (value);
+
+	if (source != NULL) {
+		const gchar *uid;
+
+		uid = e_source_get_uid (source);
+		variant = g_variant_new_string (uid);
+	}
+
+	return variant;
+}
+
 static void
 cal_shell_sidebar_emit_client_added (ECalShellSidebar *cal_shell_sidebar,
                                      EClient *client)
@@ -373,8 +412,6 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
                                     EShellSidebar *shell_sidebar)
 {
 	ECalShellSidebarPrivate *priv;
-	EShell *shell;
-	EShellSettings *shell_settings;
 	ESourceRegistry *registry;
 	ESourceSelector *selector;
 	GSettings *settings;
@@ -382,21 +419,10 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 
 	priv = E_CAL_SHELL_SIDEBAR_GET_PRIVATE (shell_sidebar);
 
-	shell = e_shell_window_get_shell (shell_window);
-	shell_settings = e_shell_get_shell_settings (shell);
-
-	g_signal_handlers_disconnect_by_func (
-		shell_window,
-		cal_shell_sidebar_restore_state_cb, shell_sidebar);
-
 	selector = E_SOURCE_SELECTOR (priv->selector);
 	registry = e_source_selector_get_registry (selector);
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (selector));
 
-	g_signal_connect_swapped (
-		registry, "source-removed",
-		G_CALLBACK (e_cal_shell_sidebar_remove_source), shell_sidebar);
-
 	g_signal_connect_swapped (
 		model, "row-changed",
 		G_CALLBACK (cal_shell_sidebar_row_changed_cb),
@@ -407,23 +433,16 @@ cal_shell_sidebar_restore_state_cb (EShellWindow *shell_window,
 		G_CALLBACK (cal_shell_sidebar_primary_selection_changed_cb),
 		shell_sidebar);
 
-	/* This will trigger our "row-changed" signal handler for each
-	 * calendar source, so the appropriate ECalClients get added to
-	 * the ECalModel, which will then create view objects to display
-	 * the calendar content.  This all happens asynchronously. */
-	e_source_selector_update_all_rows (selector);
-
 	/* Bind GObject properties to settings keys. */
 
 	settings = g_settings_new ("org.gnome.evolution.calendar");
 
-	g_object_bind_property_full (
-		shell_settings, "cal-primary-calendar",
+	g_settings_bind_with_mapping (
+		settings, "primary-calendar",
 		selector, "primary-selection",
-		G_BINDING_BIDIRECTIONAL |
-		G_BINDING_SYNC_CREATE,
-		(GBindingTransformFunc) e_binding_transform_uid_to_source,
-		(GBindingTransformFunc) e_binding_transform_source_to_uid,
+		G_SETTINGS_BIND_DEFAULT,
+		cal_shell_sidebar_map_uid_to_source,
+		cal_shell_sidebar_map_source_to_uid,
 		g_object_ref (registry),
 		(GDestroyNotify) g_object_unref);
 
@@ -489,11 +508,6 @@ cal_shell_sidebar_dispose (GObject *object)
 		priv->date_navigator = NULL;
 	}
 
-	if (priv->new_calendar_button != NULL) {
-		g_object_unref (priv->new_calendar_button);
-		priv->new_calendar_button = NULL;
-	}
-
 	if (priv->default_client != NULL) {
 		g_object_unref (priv->default_client);
 		priv->default_client = NULL;
@@ -518,7 +532,6 @@ cal_shell_sidebar_constructed (GObject *object)
 	EShellWindow *shell_window;
 	EShellBackend *shell_backend;
 	EShellSidebar *shell_sidebar;
-	EShellSettings *shell_settings;
 	EClientCache *client_cache;
 	ECalendarItem *calitem;
 	GtkWidget *container;
@@ -534,9 +547,7 @@ cal_shell_sidebar_constructed (GObject *object)
 	shell_view = e_shell_sidebar_get_shell_view (shell_sidebar);
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
-
 	shell = e_shell_backend_get_shell (shell_backend);
-	shell_settings = e_shell_get_shell_settings (shell);
 
 	container = GTK_WIDGET (shell_sidebar);
 
@@ -553,17 +564,6 @@ cal_shell_sidebar_constructed (GObject *object)
 
 	container = widget;
 
-	/* "New Calendar" button is only shown in express mode.
-	 * ECalShellView will bind the button to an appropriate
-	 * GtkAction so we don't have to reimplement it here. */
-	if (e_shell_get_express_mode (shell)) {
-		widget = gtk_button_new ();
-		gtk_box_pack_end (
-			GTK_BOX (container), widget, FALSE, FALSE, 0);
-		priv->new_calendar_button = g_object_ref (widget);
-		gtk_widget_show (widget);
-	}
-
 	widget = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (
 		GTK_SCROLLED_WINDOW (widget),
@@ -594,16 +594,6 @@ cal_shell_sidebar_constructed (GObject *object)
 	priv->date_navigator = g_object_ref (widget);
 	gtk_widget_show (widget);
 
-	g_object_bind_property (
-		shell_settings, "cal-show-week-numbers",
-		calitem, "show-week-numbers",
-		G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (
-		shell_settings, "cal-week-start-day",
-		calitem, "week-start-day",
-		G_BINDING_SYNC_CREATE);
-
 	/* Restore widget state from the last session once
 	 * the shell view is fully initialized and visible. */
 	g_signal_connect (
@@ -813,15 +803,6 @@ e_cal_shell_sidebar_get_default_client (ECalShellSidebar *cal_shell_sidebar)
 	return (ECalClient *) cal_shell_sidebar->priv->default_client;
 }
 
-GtkWidget *
-e_cal_shell_sidebar_get_new_calendar_button (ECalShellSidebar *cal_shell_sidebar)
-{
-	g_return_val_if_fail (
-		E_IS_CAL_SHELL_SIDEBAR (cal_shell_sidebar), NULL);
-
-	return cal_shell_sidebar->priv->new_calendar_button;
-}
-
 ESourceSelector *
 e_cal_shell_sidebar_get_selector (ECalShellSidebar *cal_shell_sidebar)
 {
