@@ -43,8 +43,7 @@ struct _EMailPartItip {
 
 	gchar *uid;
 
-	ESourceRegistry *registry;
-	GHashTable *clients[E_CAL_CLIENT_SOURCE_TYPE_LAST];
+	EClientCache *client_cache;
 
 	ECalClient *current_client;
 	ECalClientSourceType type;
