@@ -35,7 +35,8 @@
 	((obj), E_TYPE_MAIL_ATTACHMENT_HANDLER, EMailAttachmentHandlerPrivate))
 
 struct _EMailAttachmentHandlerPrivate {
-	EMailBackend *backend;
+	EShell *shell;
+	EMailSession *session;
 };
 
 static gpointer parent_class;
@@ -64,13 +65,10 @@ mail_attachment_handler_get_selected_message (EAttachmentHandler *handler)
 	EAttachment *attachment;
 	EAttachmentView *view;
 	CamelMimePart *mime_part;
+	CamelDataWrapper *wrapper;
 	CamelMimeMessage *message = NULL;
-	CamelDataWrapper *outer_wrapper;
-	CamelContentType *outer_content_type;
-	CamelDataWrapper *inner_wrapper;
-	CamelContentType *inner_content_type;
+	CamelContentType *content_type;
 	GList *selected;
-	gboolean inner_and_outer_content_types_match;
 
 	view = e_attachment_handler_get_view (handler);
 
@@ -78,58 +76,42 @@ mail_attachment_handler_get_selected_message (EAttachmentHandler *handler)
 	g_return_val_if_fail (g_list_length (selected) == 1, NULL);
 
 	attachment = E_ATTACHMENT (selected->data);
-	mime_part = e_attachment_ref_mime_part (attachment);
+	mime_part = e_attachment_get_mime_part (attachment);
+	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
 
-	outer_wrapper =
-		camel_medium_get_content (CAMEL_MEDIUM (mime_part));
-	outer_content_type =
-		camel_data_wrapper_get_mime_type_field (outer_wrapper);
+	content_type = camel_data_wrapper_get_mime_type_field (wrapper);
+	if (content_type && camel_content_type_is (content_type, "message", "rfc822")) {
+		CamelDataWrapper *inner;
+		CamelContentType *inner_content_type;
 
-	if (!camel_content_type_is (outer_content_type, "message", "rfc822"))
-		goto exit;
+		inner = camel_medium_get_content (CAMEL_MEDIUM (wrapper));
+		inner_content_type = camel_data_wrapper_get_mime_type_field (inner);
+		if (!camel_content_type_is (inner_content_type, content_type->type, content_type->subtype)) {
+			CamelStream *mem;
 
-	inner_wrapper =
-		camel_medium_get_content (CAMEL_MEDIUM (outer_wrapper));
-	inner_content_type =
-		camel_data_wrapper_get_mime_type_field (inner_wrapper);
+			/* Create a message copy in case the inner content-type doesn't match
+			 * the mime_part's content type, which can happen for multipart/digest,
+			 * where it confuses the formatter on reply, which skips all rfc822 subparts.
+			*/
+			mem = camel_stream_mem_new ();
+			camel_data_wrapper_write_to_stream_sync (CAMEL_DATA_WRAPPER (wrapper), mem, NULL, NULL);
 
-	inner_and_outer_content_types_match =
-		camel_content_type_is (
-			inner_content_type,
-			outer_content_type->type,
-			outer_content_type->subtype);
+			g_seekable_seek (G_SEEKABLE (mem), 0, G_SEEK_SET, NULL, NULL);
+			message = camel_mime_message_new ();
+			if (!camel_data_wrapper_construct_from_stream_sync (CAMEL_DATA_WRAPPER (message), mem, NULL, NULL)) {
+				g_object_unref (message);
+				message = NULL;
+			}
 
-	if (!inner_and_outer_content_types_match) {
-		CamelStream *mem;
-		gboolean success;
-
-		/* Create a message copy in case the inner content
-		 * type doesn't match the mime_part's content type,
-		 * which can happen for multipart/digest, where it
-		 * confuses the formatter on reply, which skips all
-		 * rfc822 subparts. */
-		mem = camel_stream_mem_new ();
-		camel_data_wrapper_write_to_stream_sync (
-			CAMEL_DATA_WRAPPER (outer_wrapper), mem, NULL, NULL);
-
-		g_seekable_seek (
-			G_SEEKABLE (mem), 0, G_SEEK_SET, NULL, NULL);
-		message = camel_mime_message_new ();
-		success = camel_data_wrapper_construct_from_stream_sync (
-			CAMEL_DATA_WRAPPER (message), mem, NULL, NULL);
-		if (!success)
-			g_clear_object (&message);
-
-		g_object_unref (mem);
+			g_object_unref (mem);
+		}
 	}
 
-exit:
-	if (message == NULL)
-		message = g_object_ref (outer_wrapper);
+	if (!message)
+		message = g_object_ref (wrapper);
 
-	g_clear_object (&mime_part);
-
-	g_list_free_full (selected, (GDestroyNotify) g_object_unref);
+	g_list_foreach (selected, (GFunc) g_object_unref, NULL);
+	g_list_free (selected);
 
 	return message;
 }
@@ -139,26 +121,22 @@ mail_attachment_handler_forward (GtkAction *action,
                                  EAttachmentHandler *handler)
 {
 	EMailAttachmentHandlerPrivate *priv;
-	EShellSettings *shell_settings;
+	GSettings *settings;
 	EMailForwardStyle style;
 	CamelMimeMessage *message;
-	EShellBackend *shell_backend;
-	EShell *shell;
-	const gchar *property_name;
 
 	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
 
 	message = mail_attachment_handler_get_selected_message (handler);
 	g_return_if_fail (message != NULL);
 
-	shell_backend = E_SHELL_BACKEND (priv->backend);
-	shell = e_shell_backend_get_shell (shell_backend);
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	style = g_settings_get_enum (settings, "forward-style-name");
+	g_object_unref (settings);
 
-	property_name = "mail-forward-style";
-	shell_settings = e_shell_get_shell_settings (shell);
-	style = e_shell_settings_get_int (shell_settings, property_name);
-
-	em_utils_forward_message (priv->backend, message, style, NULL, NULL);
+	em_utils_forward_message (
+		priv->shell, CAMEL_SESSION (priv->session),
+		message, style, NULL, NULL);
 
 	g_object_unref (message);
 }
@@ -168,27 +146,22 @@ mail_attachment_handler_reply (EAttachmentHandler *handler,
                                EMailReplyType reply_type)
 {
 	EMailAttachmentHandlerPrivate *priv;
-	EShellSettings *shell_settings;
+	GSettings *settings;
 	EMailReplyStyle style;
 	CamelMimeMessage *message;
-	EShellBackend *shell_backend;
-	EShell *shell;
-	const gchar *property_name;
 
 	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (handler);
 
 	message = mail_attachment_handler_get_selected_message (handler);
 	g_return_if_fail (message != NULL);
 
-	shell_backend = E_SHELL_BACKEND (priv->backend);
-	shell = e_shell_backend_get_shell (shell_backend);
-
-	property_name = "mail-reply-style";
-	shell_settings = e_shell_get_shell_settings (shell);
-	style = e_shell_settings_get_int (shell_settings, property_name);
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	style = g_settings_get_enum (settings, "reply-style-name");
+	g_object_unref (settings);
 
 	em_utils_reply_to_message (
-		shell, message, NULL, NULL, reply_type, style, NULL, NULL);
+		priv->shell, message,
+		NULL, NULL, reply_type, style, NULL, NULL);
 
 	g_object_unref (message);
 }
@@ -314,7 +287,6 @@ mail_attachment_handler_x_uid_list (EAttachmentView *view,
 	CamelFolder *folder = NULL;
 	EAttachment *attachment;
 	EAttachmentStore *store;
-	EMailSession *session;
 	GPtrArray *uids;
 	const gchar *data;
 	const gchar *cp, *end;
@@ -363,12 +335,10 @@ mail_attachment_handler_x_uid_list (EAttachmentView *view,
 	if (uids->len == 0)
 		goto exit;
 
-	session = e_mail_backend_get_session (priv->backend);
-
 	/* The first string is the folder URI. */
 	/* FIXME Not passing a GCancellable here. */
 	folder = e_mail_session_uri_to_folder_sync (
-		session, data, 0, NULL, &local_error);
+		priv->session, data, 0, NULL, &local_error);
 	if (folder == NULL)
 		goto exit;
 
@@ -475,6 +445,7 @@ mail_attachment_handler_update_actions (EAttachmentView *view,
 {
 	EAttachment *attachment;
 	CamelMimePart *mime_part;
+	CamelDataWrapper *wrapper;
 	GtkActionGroup *action_group;
 	GList *selected;
 	gboolean visible = FALSE;
@@ -490,18 +461,14 @@ mail_attachment_handler_update_actions (EAttachmentView *view,
 	    e_attachment_get_saving (attachment))
 		goto exit;
 
-	mime_part = e_attachment_ref_mime_part (attachment);
+	mime_part = e_attachment_get_mime_part (attachment);
 
-	if (mime_part != NULL) {
-		CamelMedium *medium;
-		CamelDataWrapper *content;
+	if (!CAMEL_IS_MIME_PART (mime_part))
+		goto exit;
 
-		medium = CAMEL_MEDIUM (mime_part);
-		content = camel_medium_get_content (medium);
-		visible = CAMEL_IS_MIME_MESSAGE (content);
+	wrapper = camel_medium_get_content (CAMEL_MEDIUM (mime_part));
 
-		g_object_unref (mime_part);
-	}
+	visible = CAMEL_IS_MIME_MESSAGE (wrapper);
 
 exit:
 	action_group = e_attachment_view_get_action_group (view, "mail");
@@ -518,7 +485,15 @@ mail_attachment_handler_dispose (GObject *object)
 
 	priv = E_MAIL_ATTACHMENT_HANDLER_GET_PRIVATE (object);
 
-	g_clear_object (&priv->backend);
+	if (priv->shell != NULL) {
+		g_object_unref (priv->shell);
+		priv->shell = NULL;
+	}
+
+	if (priv->session != NULL) {
+		g_object_unref (priv->session);
+		priv->session = NULL;
+	}
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (parent_class)->dispose (object);
@@ -532,6 +507,7 @@ mail_attachment_handler_constructed (GObject *object)
 	EShellBackend *shell_backend;
 	EAttachmentHandler *handler;
 	EAttachmentView *view;
+	EMailSession *session;
 	GtkActionGroup *action_group;
 	GtkUIManager *ui_manager;
 	GError *error = NULL;
@@ -544,7 +520,10 @@ mail_attachment_handler_constructed (GObject *object)
 
 	shell = e_shell_get_default ();
 	shell_backend = e_shell_get_backend_by_name (shell, "mail");
-	priv->backend = g_object_ref (shell_backend);
+	session = e_mail_backend_get_session (E_MAIL_BACKEND (shell_backend));
+
+	priv->shell = g_object_ref (shell);
+	priv->session = g_object_ref (session);
 
 	view = e_attachment_handler_get_view (handler);
 
