@@ -423,18 +423,24 @@ action_mail_folder_mark_all_as_read_cb (GtkAction *action,
 {
 	EShellView *shell_view;
 	EShellWindow *shell_window;
+	EShellBackend *shell_backend;
 	EMailShellContent *mail_shell_content;
 	EMailReader *reader;
 	EMailView *mail_view;
 	CamelFolder *folder;
 	GtkWindow *parent;
+	EMailBackend *backend;
+	EMailSession *session;
+	MailFolderCache *cache;
 	GtkWidget *message_list;
 	GPtrArray *uids;
 	const gchar *key;
+	const gchar *prompt;
 	guint ii;
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	parent = GTK_WINDOW (shell_window);
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
@@ -445,9 +451,17 @@ action_mail_folder_mark_all_as_read_cb (GtkAction *action,
 	folder = e_mail_reader_get_folder (reader);
 	g_return_if_fail (folder != NULL);
 
+	backend = E_MAIL_BACKEND (shell_backend);
+	session = e_mail_backend_get_session (backend);
+	cache = e_mail_session_get_folder_cache (session);
 	key = "prompt-on-mark-all-read";
 
-	if (!em_utils_prompt_user (parent, key, "mail:ask-mark-all-read", NULL))
+	if (mail_folder_cache_get_folder_has_children (cache, folder, NULL))
+		prompt = "mail:ask-mark-all-read-sub";
+	else
+		prompt = "mail:ask-mark-all-read";
+
+	if (!em_utils_prompt_user (parent, key, prompt, NULL))
 		return;
 
 	message_list = e_mail_reader_get_message_list (reader);
@@ -939,10 +953,8 @@ static void
 action_mail_smart_backward_cb (GtkAction *action,
                                EMailShellView *mail_shell_view)
 {
-	EShell *shell;
 	EShellView *shell_view;
 	EShellWindow *shell_window;
-	EShellSettings *shell_settings;
 	EMailShellContent *mail_shell_content;
 	EMailShellSidebar *mail_shell_sidebar;
 	EMFolderTree *folder_tree;
@@ -953,6 +965,7 @@ action_mail_smart_backward_cb (GtkAction *action,
 	GtkWidget *window;
 	GtkAdjustment *adj;
 	EMailDisplay *display;
+	GSettings *settings;
 	gboolean caret_mode;
 	gboolean magic_spacebar;
 	gdouble value;
@@ -961,8 +974,6 @@ action_mail_smart_backward_cb (GtkAction *action,
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
-	shell = e_shell_window_get_shell (shell_window);
-	shell_settings = e_shell_get_shell_settings (shell);
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
 	mail_view = e_mail_shell_content_get_mail_view (mail_shell_content);
@@ -974,8 +985,9 @@ action_mail_smart_backward_cb (GtkAction *action,
 	display = e_mail_reader_get_mail_display (reader);
 	message_list = e_mail_reader_get_message_list (reader);
 
-	magic_spacebar = e_shell_settings_get_boolean (
-		shell_settings, "mail-magic-spacebar");
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	magic_spacebar = g_settings_get_boolean (settings, "magic-spacebar");
+	g_object_unref (settings);
 
 	toggle_action = GTK_TOGGLE_ACTION (ACTION (MAIL_CARET_MODE));
 	caret_mode = gtk_toggle_action_get_active (toggle_action);
@@ -991,7 +1003,7 @@ action_mail_smart_backward_cb (GtkAction *action,
 		if (caret_mode || !magic_spacebar)
 			return;
 
-                /* XXX Are two separate calls really necessary? */
+		/* XXX Are two separate calls really necessary? */
 
 		if (message_list_select (
 		    MESSAGE_LIST (message_list),
@@ -1024,10 +1036,8 @@ static void
 action_mail_smart_forward_cb (GtkAction *action,
                               EMailShellView *mail_shell_view)
 {
-	EShell *shell;
 	EShellView *shell_view;
 	EShellWindow *shell_window;
-	EShellSettings *shell_settings;
 	EMailShellContent *mail_shell_content;
 	EMailShellSidebar *mail_shell_sidebar;
 	EMFolderTree *folder_tree;
@@ -1038,6 +1048,7 @@ action_mail_smart_forward_cb (GtkAction *action,
 	GtkAdjustment *adj;
 	GtkToggleAction *toggle_action;
 	EMailDisplay *display;
+	GSettings *settings;
 	gboolean caret_mode;
 	gboolean magic_spacebar;
 	gdouble value;
@@ -1047,8 +1058,6 @@ action_mail_smart_forward_cb (GtkAction *action,
 
 	shell_view = E_SHELL_VIEW (mail_shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
-	shell = e_shell_window_get_shell (shell_window);
-	shell_settings = e_shell_get_shell_settings (shell);
 
 	mail_shell_content = mail_shell_view->priv->mail_shell_content;
 	mail_view = e_mail_shell_content_get_mail_view (mail_shell_content);
@@ -1060,8 +1069,9 @@ action_mail_smart_forward_cb (GtkAction *action,
 	display = e_mail_reader_get_mail_display (reader);
 	message_list = e_mail_reader_get_message_list (reader);
 
-	magic_spacebar = e_shell_settings_get_boolean (
-		shell_settings, "mail-magic-spacebar");
+	settings = g_settings_new ("org.gnome.evolution.mail");
+	magic_spacebar = g_settings_get_boolean (settings, "magic-spacebar");
+	g_object_unref (settings);
 
 	toggle_action = GTK_TOGGLE_ACTION (ACTION (MAIL_CARET_MODE));
 	caret_mode = gtk_toggle_action_get_active (toggle_action);
@@ -1078,7 +1088,7 @@ action_mail_smart_forward_cb (GtkAction *action,
 		if (caret_mode || !magic_spacebar)
 			return;
 
-                /* XXX Are two separate calls really necessary? */
+		/* XXX Are two separate calls really necessary? */
 
 		if (message_list_select (
 		    MESSAGE_LIST (message_list),
@@ -1941,26 +1951,6 @@ e_mail_shell_view_actions_init (EMailShellView *mail_shell_view)
 		ACTION (MAIL_STOP), "sensitive",
 		G_BINDING_SYNC_CREATE);
 
-	g_object_bind_property (
-		shell, "online",
-		ACTION (MAIL_SEND_RECEIVE), "sensitive",
-		G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (
-		shell, "online",
-		ACTION (MAIL_SEND_RECEIVE_RECEIVE_ALL), "sensitive",
-		G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (
-		shell, "online",
-		ACTION (MAIL_SEND_RECEIVE_SEND_ALL), "sensitive",
-		G_BINDING_SYNC_CREATE);
-
-	g_object_bind_property (
-		shell, "online",
-		ACTION (MAIL_SEND_RECEIVE_SUBMENU), "sensitive",
-		G_BINDING_SYNC_CREATE);
-
 	/* Keep the sensitivity of "Create Search Folder from Search"
 	 * in sync with "Save Search" so that its only selectable when
 	 * showing search results. */
