@@ -67,30 +67,22 @@ struct _EShellSearchbarPrivate {
 	GtkWidget *scope_combo_box;
 
 	/* Child widget containers (referenced) */
-	GSList *child_containers;
+	GQueue child_containers;
 	guint resize_idle_id;
 
 	/* State Key File */
 	gchar *state_group;
 
-	guint express_mode   : 1;
-	guint filter_visible : 1;
-	guint labels_visible : 1;
-	guint search_visible : 1;
-	guint scope_visible  : 1;
-	guint state_dirty    : 1;
+	gboolean scope_visible;
+	gboolean state_dirty;
 };
 
 enum {
 	PROP_0,
-	PROP_EXPRESS_MODE,
 	PROP_FILTER_COMBO_BOX,
-	PROP_FILTER_VISIBLE,
-	PROP_LABELS_VISIBLE,
 	PROP_SEARCH_HINT,
 	PROP_SEARCH_OPTION,
 	PROP_SEARCH_TEXT,
-	PROP_SEARCH_VISIBLE,
 	PROP_SCOPE_COMBO_BOX,
 	PROP_SCOPE_VISIBLE,
 	PROP_SHELL_VIEW,
@@ -256,17 +248,21 @@ shell_searchbar_update_search_widgets (EShellSearchbar *searchbar)
 		gchar *css;
 
 		style = gtk_widget_get_style_context (widget);
-		gtk_style_context_get_background_color (style, GTK_STATE_FLAG_SELECTED, &bg);
-		gtk_style_context_get_color (style, GTK_STATE_FLAG_SELECTED, &fg);
+		gtk_style_context_get_background_color (
+			style, GTK_STATE_FLAG_SELECTED, &bg);
+		gtk_style_context_get_color (
+			style, GTK_STATE_FLAG_SELECTED, &fg);
 
-		css = g_strdup_printf ("GtkEntry#searchbar_searchentry_active { "
-					"   background:none; "
-					"   background-color:#%06x; "
-					"   color:#%06x; "
-					"}",
-					e_rgba_to_value (&bg),
-					e_rgba_to_value (&fg));
-		gtk_css_provider_load_from_data (searchbar->priv->css_provider, css, -1, NULL);
+		css = g_strdup_printf (
+			"GtkEntry#searchbar_searchentry_active { "
+			"   background:none; "
+			"   background-color:#%06x; "
+			"   color:#%06x; "
+			"}",
+			e_rgba_to_value (&bg),
+			e_rgba_to_value (&fg));
+		gtk_css_provider_load_from_data (
+			searchbar->priv->css_provider, css, -1, NULL);
 		g_free (css);
 
 		gtk_widget_set_name (widget, "searchbar_searchentry_active");
@@ -465,9 +461,9 @@ shell_searchbar_option_changed_cb (GtkRadioAction *action,
 	if (current_value != SEARCH_OPTION_ADVANCED) {
 		e_shell_view_set_search_rule (shell_view, NULL);
 		e_shell_searchbar_set_search_text (searchbar, search_text);
-		if (search_text != NULL && *search_text != '\0')
+		if (search_text != NULL && *search_text != '\0') {
 			e_shell_view_execute_search (shell_view);
-		else {
+		} else {
 			shell_searchbar_save_search_option (searchbar);
 			gtk_widget_grab_focus (searchbar->priv->search_entry);
 		}
@@ -481,21 +477,29 @@ shell_searchbar_resize_idle_cb (gpointer user_data)
 {
 	GtkWidget *widget;
 	EShellSearchbar *searchbar;
-	GSList *iter, *widths = NULL, *witer;
-	gint row, column, roww, maxw, child_left, child_top, allocated_width;
+	GQueue *child_containers;
+	GList *head, *link;
+	GArray *widths;
+	gint row = 0;
+	gint column = 0;
+	gint roww = 0;
+	gint maxw = 0;
+	gint child_left;
+	gint child_top;
+	gint allocated_width;
 	gboolean needs_reposition = FALSE;
 
-	widget = user_data;
-	searchbar = E_SHELL_SEARCHBAR (widget);
+	widget = GTK_WIDGET (user_data);
 	allocated_width = gtk_widget_get_allocated_width (widget);
 
-	row = 0;
-	column = 0;
-	roww = 0;
-	maxw = 0;
+	searchbar = E_SHELL_SEARCHBAR (widget);
+	child_containers = &searchbar->priv->child_containers;
+	head = g_queue_peek_head_link (child_containers);
 
-	for (iter = searchbar->priv->child_containers; iter != NULL; iter = iter->next) {
-		GtkWidget *child = iter->data;
+	widths = g_array_new (FALSE, FALSE, sizeof (gint));
+
+	for (link = head; link != NULL; link = g_list_next (link)) {
+		GtkWidget *child = GTK_WIDGET (link->data);
 		gint minw = -1;
 
 		if (!gtk_widget_get_visible (child))
@@ -503,7 +507,7 @@ shell_searchbar_resize_idle_cb (gpointer user_data)
 		else
 			gtk_widget_get_preferred_width (child, &minw, NULL);
 
-		widths = g_slist_append (widths, GINT_TO_POINTER (minw));
+		g_array_append_val (widths, minw);
 
 		if (roww && minw) {
 			roww += COLUMN_SPACING;
@@ -527,26 +531,37 @@ shell_searchbar_resize_idle_cb (gpointer user_data)
 			"top-attach", &child_top,
 			NULL);
 
-		needs_reposition = needs_reposition || child_left != column || child_top != row;
+		needs_reposition |=
+			(child_left != column) ||
+			(child_top != row);
 
 		if (column == 0 && row > 0 && roww < maxw) {
-			/* columns has same width, thus use the wider widget for calculations*/
+			/* Columns have the same width, so use
+			 * the wider widget for calculations. */
 			roww = maxw;
 		}
 	}
 
 	if (needs_reposition) {
+		guint ii = 0;
+
 		row = 0;
 		column = 0;
 		roww = 0;
 
-		for (iter = searchbar->priv->child_containers; iter; iter = iter->next) {
-			gtk_container_remove (GTK_CONTAINER (widget), iter->data);
-		}
+		g_warn_if_fail (child_containers->length == widths->len);
 
-		for (witer = widths, iter = searchbar->priv->child_containers; witer && iter; witer = witer->next, iter = iter->next) {
-			GtkWidget *child = iter->data;
-			gint w = GPOINTER_TO_INT (witer->data);
+		for (link = head; link != NULL; link = g_list_next (link))
+			gtk_container_remove (
+				GTK_CONTAINER (widget),
+				GTK_WIDGET (link->data));
+
+		for (link = head; link != NULL; link = g_list_next (link)) {
+			GtkWidget *child;
+			gint w;
+
+			child = GTK_WIDGET (link->data);
+			w = g_array_index (widths, gint, ii++);
 
 			if (roww && w) {
 				roww += COLUMN_SPACING;
@@ -561,17 +576,17 @@ shell_searchbar_resize_idle_cb (gpointer user_data)
 				column = 0;
 			}
 
-			gtk_grid_attach (GTK_GRID (widget), child, column, row, 1, 1);
+			gtk_grid_attach (
+				GTK_GRID (widget), child, column, row, 1, 1);
 
 			if (column == 0 && row > 0 && roww < maxw)
 				roww = maxw;
 		}
 	}
 
-	g_slist_free (widths);
+	g_array_free (widths, TRUE);
 
 	searchbar->priv->resize_idle_id = 0;
-	g_object_unref (searchbar);
 
 	return FALSE;
 }
@@ -617,24 +632,6 @@ shell_searchbar_set_property (GObject *object,
                               GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_EXPRESS_MODE:
-			e_shell_searchbar_set_express_mode (
-				E_SHELL_SEARCHBAR (object),
-				g_value_get_boolean (value));
-			return;
-
-		case PROP_FILTER_VISIBLE:
-			e_shell_searchbar_set_filter_visible (
-				E_SHELL_SEARCHBAR (object),
-				g_value_get_boolean (value));
-			return;
-
-		case PROP_LABELS_VISIBLE:
-			e_shell_searchbar_set_labels_visible (
-				E_SHELL_SEARCHBAR (object),
-				g_value_get_boolean (value));
-			return;
-
 		case PROP_SEARCH_HINT:
 			e_shell_searchbar_set_search_hint (
 				E_SHELL_SEARCHBAR (object),
@@ -653,12 +650,6 @@ shell_searchbar_set_property (GObject *object,
 				g_value_get_string (value));
 			return;
 
-		case PROP_SEARCH_VISIBLE:
-			e_shell_searchbar_set_search_visible (
-				E_SHELL_SEARCHBAR (object),
-				g_value_get_boolean (value));
-			return;
-
 		case PROP_SCOPE_VISIBLE:
 			e_shell_searchbar_set_scope_visible (
 				E_SHELL_SEARCHBAR (object),
@@ -688,30 +679,12 @@ shell_searchbar_get_property (GObject *object,
                               GParamSpec *pspec)
 {
 	switch (property_id) {
-		case PROP_EXPRESS_MODE:
-			g_value_set_boolean (
-				value, e_shell_searchbar_get_express_mode (
-				E_SHELL_SEARCHBAR (object)));
-			return;
-
 		case PROP_FILTER_COMBO_BOX:
 			g_value_set_object (
 				value, e_shell_searchbar_get_filter_combo_box (
 				E_SHELL_SEARCHBAR (object)));
 			return;
 
-		case PROP_LABELS_VISIBLE:
-			g_value_set_boolean (
-				value, e_shell_searchbar_get_labels_visible (
-				E_SHELL_SEARCHBAR (object)));
-			return;
-
-		case PROP_FILTER_VISIBLE:
-			g_value_set_boolean (
-				value, e_shell_searchbar_get_filter_visible (
-				E_SHELL_SEARCHBAR (object)));
-			return;
-
 		case PROP_SEARCH_HINT:
 			g_value_set_string (
 				value, e_shell_searchbar_get_search_hint (
@@ -730,12 +703,6 @@ shell_searchbar_get_property (GObject *object,
 				E_SHELL_SEARCHBAR (object)));
 			return;
 
-		case PROP_SEARCH_VISIBLE:
-			g_value_set_boolean (
-				value, e_shell_searchbar_get_search_visible (
-				E_SHELL_SEARCHBAR (object)));
-			return;
-
 		case PROP_SCOPE_COMBO_BOX:
 			g_value_set_object (
 				value, e_shell_searchbar_get_scope_combo_box (
@@ -771,16 +738,11 @@ shell_searchbar_dispose (GObject *object)
 
 	priv = E_SHELL_SEARCHBAR_GET_PRIVATE (object);
 
-	if (priv->resize_idle_id) {
+	if (priv->resize_idle_id > 0) {
 		g_source_remove (priv->resize_idle_id);
 		priv->resize_idle_id = 0;
 	}
 
-	if (priv->child_containers) {
-		g_slist_free_full (priv->child_containers, g_object_unref);
-		priv->child_containers = NULL;
-	}
-
 	if (priv->shell_view != NULL) {
 		g_object_remove_weak_pointer (
 			G_OBJECT (priv->shell_view), &priv->shell_view);
@@ -791,36 +753,45 @@ shell_searchbar_dispose (GObject *object)
 		g_signal_handlers_disconnect_matched (
 			priv->search_option, G_SIGNAL_MATCH_DATA,
 			0, 0, NULL, NULL, object);
-		g_object_unref (priv->search_option);
-		priv->search_option = NULL;
+		g_clear_object (&priv->search_option);
 	}
 
-	if (priv->state_group) {
-		g_free (priv->state_group);
-		priv->state_group = NULL;
-	}
+	g_clear_object (&priv->css_provider);
 
-	if (priv->css_provider) {
-		g_object_unref (priv->css_provider);
-		priv->css_provider = NULL;
-	}
+	while (!g_queue_is_empty (&priv->child_containers))
+		g_object_unref (g_queue_pop_head (&priv->child_containers));
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (e_shell_searchbar_parent_class)->dispose (object);
 }
 
+static void
+shell_searchbar_finalize (GObject *object)
+{
+	EShellSearchbarPrivate *priv;
+
+	priv = E_SHELL_SEARCHBAR_GET_PRIVATE (object);
+
+	g_free (priv->state_group);
+
+	/* Chain up to parent's finalize() method. */
+	G_OBJECT_CLASS (e_shell_searchbar_parent_class)->finalize (object);
+}
+
 static void
 shell_searchbar_constructed (GObject *object)
 {
 	EShellView *shell_view;
 	EShellWindow *shell_window;
 	EShellSearchbar *searchbar;
+	GtkSizeGroup *size_group;
 	GtkAction *action;
 	GtkWidget *widget;
 
 	searchbar = E_SHELL_SEARCHBAR (object);
 	shell_view = e_shell_searchbar_get_shell_view (searchbar);
 	shell_window = e_shell_view_get_shell_window (shell_view);
+	size_group = e_shell_view_get_size_group (shell_view);
 
 	g_signal_connect (
 		shell_view, "clear-search",
@@ -886,6 +857,9 @@ shell_searchbar_constructed (GObject *object)
 		widget, "primary-icon-tooltip-text",
 		G_BINDING_SYNC_CREATE);
 
+	widget = GTK_WIDGET (searchbar);
+	gtk_size_group_add_widget (size_group, widget);
+
 	e_extensible_load_extensions (E_EXTENSIBLE (object));
 
 	/* Chain up to parent's constructed() method. */
@@ -908,14 +882,17 @@ static void
 shell_searchbar_size_allocate (GtkWidget *widget,
                                GdkRectangle *allocation)
 {
-	EShellSearchbar *searchbar;
+	EShellSearchbarPrivate *priv;
 
-	GTK_WIDGET_CLASS (e_shell_searchbar_parent_class)->size_allocate (widget, allocation);
+	priv = E_SHELL_SEARCHBAR_GET_PRIVATE (widget);
 
-	searchbar = E_SHELL_SEARCHBAR (widget);
+	/* Chain up to parent's size_allocate() method. */
+	GTK_WIDGET_CLASS (e_shell_searchbar_parent_class)->
+		size_allocate (widget, allocation);
 
-	if (!searchbar->priv->resize_idle_id)
-		searchbar->priv->resize_idle_id = g_idle_add (shell_searchbar_resize_idle_cb, g_object_ref (searchbar));
+	if (priv->resize_idle_id == 0)
+		priv->resize_idle_id = g_idle_add (
+			shell_searchbar_resize_idle_cb, widget);
 }
 
 static void
@@ -958,6 +935,7 @@ e_shell_searchbar_class_init (EShellSearchbarClass *class)
 	object_class->set_property = shell_searchbar_set_property;
 	object_class->get_property = shell_searchbar_get_property;
 	object_class->dispose = shell_searchbar_dispose;
+	object_class->finalize = shell_searchbar_finalize;
 	object_class->constructed = shell_searchbar_constructed;
 
 	widget_class = GTK_WIDGET_CLASS (class);
@@ -965,17 +943,6 @@ e_shell_searchbar_class_init (EShellSearchbarClass *class)
 	widget_class->size_allocate = shell_searchbar_size_allocate;
 	widget_class->get_preferred_width = shell_searchbar_get_preferred_width;
 
-	g_object_class_install_property (
-		object_class,
-		PROP_EXPRESS_MODE,
-		g_param_spec_boolean (
-			"express-mode",
-			NULL,
-			NULL,
-			FALSE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_FILTER_COMBO_BOX,
@@ -986,28 +953,6 @@ e_shell_searchbar_class_init (EShellSearchbarClass *class)
 			E_TYPE_ACTION_COMBO_BOX,
 			G_PARAM_READABLE));
 
-	g_object_class_install_property (
-		object_class,
-		PROP_LABELS_VISIBLE,
-		g_param_spec_boolean (
-			"labels-visible",
-			NULL,
-			NULL,
-			TRUE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
-	g_object_class_install_property (
-		object_class,
-		PROP_FILTER_VISIBLE,
-		g_param_spec_boolean (
-			"filter-visible",
-			NULL,
-			NULL,
-			TRUE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_SEARCH_HINT,
@@ -1038,17 +983,6 @@ e_shell_searchbar_class_init (EShellSearchbarClass *class)
 			NULL,
 			G_PARAM_READWRITE));
 
-	g_object_class_install_property (
-		object_class,
-		PROP_SEARCH_VISIBLE,
-		g_param_spec_boolean (
-			"search-visible",
-			NULL,
-			NULL,
-			TRUE,
-			G_PARAM_READWRITE |
-			G_PARAM_CONSTRUCT));
-
 	g_object_class_install_property (
 		object_class,
 		PROP_SCOPE_COMBO_BOX,
@@ -1109,9 +1043,11 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 	GtkGrid *grid;
 	GtkLabel *label;
 	GtkWidget *widget;
+	GQueue *child_containers;
 
 	searchbar->priv = E_SHELL_SEARCHBAR_GET_PRIVATE (searchbar);
-	searchbar->priv->child_containers = NULL;
+
+	child_containers = &searchbar->priv->child_containers;
 
 	gtk_grid_set_column_spacing (GTK_GRID (searchbar), COLUMN_SPACING);
 	gtk_grid_set_row_spacing (GTK_GRID (searchbar), 4);
@@ -1124,17 +1060,14 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 	g_object_set (
 		G_OBJECT (widget),
 		"orientation", GTK_ORIENTATION_HORIZONTAL,
+		"border-width", 3,
 		"column-spacing", 3,
 		"valign", GTK_ALIGN_CENTER,
 		NULL);
 	gtk_grid_attach (grid, widget, 0, 0, 1, 1);
-	searchbar->priv->child_containers = g_slist_append (
-		searchbar->priv->child_containers, g_object_ref (widget));
+	gtk_widget_show (widget);
 
-	g_object_bind_property (
-		searchbar, "filter-visible",
-		widget, "visible",
-		G_BINDING_SYNC_CREATE);
+	g_queue_push_tail (child_containers, g_object_ref (widget));
 
 	grid = GTK_GRID (widget);
 
@@ -1146,11 +1079,6 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 	gtk_grid_attach (grid, widget, 0, 0, 1, 1);
 	gtk_widget_show (widget);
 
-	g_object_bind_property (
-		searchbar, "labels-visible",
-		widget, "visible",
-		G_BINDING_SYNC_CREATE);
-
 	label = GTK_LABEL (widget);
 
 	widget = e_action_combo_box_new ();
@@ -1173,13 +1101,9 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 		"hexpand", TRUE,
 		NULL);
 	gtk_grid_attach (grid, widget, 1, 0, 1, 1);
-	searchbar->priv->child_containers = g_slist_append (
-		searchbar->priv->child_containers, g_object_ref (widget));
+	gtk_widget_show (widget);
 
-	g_object_bind_property (
-		searchbar, "search-visible",
-		widget, "visible",
-		G_BINDING_SYNC_CREATE);
+	g_queue_push_tail (child_containers, g_object_ref (widget));
 
 	grid = GTK_GRID (widget);
 
@@ -1189,11 +1113,6 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 	gtk_grid_attach (grid, widget, 0, 0, 1, 1);
 	gtk_widget_show (widget);
 
-	g_object_bind_property (
-		searchbar, "labels-visible",
-		widget, "visible",
-		G_BINDING_SYNC_CREATE);
-
 	label = GTK_LABEL (widget);
 
 	widget = gtk_entry_new ();
@@ -1259,8 +1178,8 @@ e_shell_searchbar_init (EShellSearchbar *searchbar)
 		"valign", GTK_ALIGN_CENTER,
 		NULL);
 	gtk_grid_attach (grid, widget, 2, 0, 1, 1);
-	searchbar->priv->child_containers = g_slist_append (
-		searchbar->priv->child_containers, g_object_ref (widget));
+
+	g_queue_push_tail (child_containers, g_object_ref (widget));
 
 	g_object_bind_property (
 		searchbar, "scope-visible",
@@ -1329,34 +1248,6 @@ e_shell_searchbar_get_shell_view (EShellSearchbar *searchbar)
 	return E_SHELL_VIEW (searchbar->priv->shell_view);
 }
 
-gboolean
-e_shell_searchbar_get_express_mode (EShellSearchbar *searchbar)
-{
-	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
-
-	return searchbar->priv->express_mode;
-}
-
-void
-e_shell_searchbar_set_express_mode (EShellSearchbar *searchbar,
-                                    gboolean express_mode)
-{
-	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
-
-	if (searchbar->priv->express_mode == express_mode)
-		return;
-
-	searchbar->priv->express_mode = express_mode;
-
-	/* Emit "notify" on all the properties we override. */
-	g_object_freeze_notify (G_OBJECT (searchbar));
-	g_object_notify (G_OBJECT (searchbar), "express-mode");
-	g_object_notify (G_OBJECT (searchbar), "labels-visible");
-	g_object_notify (G_OBJECT (searchbar), "filter-visible");
-	g_object_notify (G_OBJECT (searchbar), "scope-visible");
-	g_object_thaw_notify (G_OBJECT (searchbar));
-}
-
 EActionComboBox *
 e_shell_searchbar_get_filter_combo_box (EShellSearchbar *searchbar)
 {
@@ -1365,58 +1256,6 @@ e_shell_searchbar_get_filter_combo_box (EShellSearchbar *searchbar)
 	return E_ACTION_COMBO_BOX (searchbar->priv->filter_combo_box);
 }
 
-gboolean
-e_shell_searchbar_get_labels_visible (EShellSearchbar *searchbar)
-{
-	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
-
-	/* Express mode overrides this. */
-	if (e_shell_searchbar_get_express_mode (searchbar))
-		return FALSE;
-
-	return searchbar->priv->labels_visible;
-}
-
-void
-e_shell_searchbar_set_labels_visible (EShellSearchbar *searchbar,
-                                      gboolean labels_visible)
-{
-	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
-
-	if (searchbar->priv->labels_visible == labels_visible)
-		return;
-
-	searchbar->priv->labels_visible = labels_visible;
-
-	g_object_notify (G_OBJECT (searchbar), "labels-visible");
-}
-
-gboolean
-e_shell_searchbar_get_filter_visible (EShellSearchbar *searchbar)
-{
-	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
-
-	/* Express mode overrides this. */
-	if (e_shell_searchbar_get_express_mode (searchbar))
-		return FALSE;
-
-	return searchbar->priv->filter_visible;
-}
-
-void
-e_shell_searchbar_set_filter_visible (EShellSearchbar *searchbar,
-                                      gboolean filter_visible)
-{
-	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
-
-	if (searchbar->priv->filter_visible == filter_visible)
-		return;
-
-	searchbar->priv->filter_visible = filter_visible;
-
-	g_object_notify (G_OBJECT (searchbar), "filter-visible");
-}
-
 const gchar *
 e_shell_searchbar_get_search_hint (EShellSearchbar *searchbar)
 {
@@ -1525,28 +1364,6 @@ e_shell_searchbar_set_search_text (EShellSearchbar *searchbar,
 	g_object_notify (G_OBJECT (searchbar), "search-text");
 }
 
-gboolean
-e_shell_searchbar_get_search_visible (EShellSearchbar *searchbar)
-{
-	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
-
-	return searchbar->priv->search_visible;
-}
-
-void
-e_shell_searchbar_set_search_visible (EShellSearchbar *searchbar,
-                                      gboolean search_visible)
-{
-	g_return_if_fail (E_IS_SHELL_SEARCHBAR (searchbar));
-
-	if (searchbar->priv->search_visible == search_visible)
-		return;
-
-	searchbar->priv->search_visible = search_visible;
-
-	g_object_notify (G_OBJECT (searchbar), "search-visible");
-}
-
 GtkWidget *
 e_shell_searchbar_get_search_box (EShellSearchbar *searchbar)
 {
@@ -1570,10 +1387,6 @@ e_shell_searchbar_get_scope_visible (EShellSearchbar *searchbar)
 {
 	g_return_val_if_fail (E_IS_SHELL_SEARCHBAR (searchbar), FALSE);
 
-	/* Express mode overrides this. */
-	if (e_shell_searchbar_get_express_mode (searchbar))
-		return FALSE;
-
 	return searchbar->priv->scope_visible;
 }
 
@@ -1641,7 +1454,6 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 	GKeyFile *key_file;
 	GtkAction *action;
 	GtkWidget *widget;
-	gboolean express_mode;
 	const gchar *search_text;
 	const gchar *state_group;
 	const gchar *key;
@@ -1657,8 +1469,6 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 	key_file = e_shell_view_get_state_key_file (shell_view);
 	shell_window = e_shell_view_get_shell_window (shell_view);
 
-	express_mode = e_shell_searchbar_get_express_mode (searchbar);
-
 	/* Changing the combo boxes triggers searches, so block
 	 * the search action until the state is fully restored. */
 	action = E_SHELL_WINDOW_ACTION_SEARCH_QUICK (shell_window);
@@ -1670,7 +1480,7 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 
 	key = STATE_KEY_SEARCH_FILTER;
 	string = g_key_file_get_string (key_file, state_group, key, NULL);
-	if (string != NULL && *string != '\0' && !express_mode)
+	if (string != NULL && *string != '\0')
 		action = e_shell_window_get_action (shell_window, string);
 	else
 		action = NULL;
@@ -1716,7 +1526,7 @@ e_shell_searchbar_load_state (EShellSearchbar *searchbar)
 
 	key = STATE_KEY_SEARCH_SCOPE;
 	string = g_key_file_get_string (key_file, state_group, key, NULL);
-	if (string != NULL && *string != '\0' && !express_mode)
+	if (string != NULL && *string != '\0')
 		action = e_shell_window_get_action (shell_window, string);
 	else
 		action = NULL;
