@@ -59,6 +59,7 @@ struct _EShellViewPrivate {
 	guint merge_id;
 
 	GtkAction *action;
+	GtkSizeGroup *size_group;
 	GtkWidget *shell_content;
 	GtkWidget *shell_sidebar;
 	GtkWidget *shell_taskbar;
@@ -613,6 +614,10 @@ shell_view_constructed (GObject *object)
 		shell_view->priv->searchbar = g_object_ref_sink (widget);
 	}
 
+	/* Size group should be safe to unreference now. */
+	g_object_unref (shell_view->priv->size_group);
+	shell_view->priv->size_group = NULL;
+
 	/* Update actions whenever the Preferences window is closed. */
 	widget = e_shell_get_preferences_window (shell);
 	shell_view->priv->preferences_window = g_object_ref (widget);
@@ -629,77 +634,16 @@ shell_view_constructed (GObject *object)
 static GtkWidget *
 shell_view_construct_searchbar (EShellView *shell_view)
 {
-	EShell *shell;
-	EShellWindow *shell_window;
 	EShellContent *shell_content;
-	EShellSearchbar *shell_searchbar;
 	EShellViewClass *shell_view_class;
-	GtkToolItem *item;
-	GtkAction *action;
-	GtkWidget *main_toolbar;
 	GtkWidget *widget;
 
 	shell_content = e_shell_view_get_shell_content (shell_view);
-	shell_window = e_shell_view_get_shell_window (shell_view);
-	shell = e_shell_window_get_shell (shell_window);
 
 	shell_view_class = E_SHELL_VIEW_GET_CLASS (shell_view);
 	widget = shell_view_class->new_shell_searchbar (shell_view);
-
-	/* In normal mode, we hand the searchbar off to EShellContent. */
-	if (!e_shell_get_express_mode (shell)) {
-		e_shell_content_set_searchbar (shell_content, widget);
-		gtk_widget_show (widget);
-		return widget;
-	}
-
-	/* Express mode is more complicated.  We append a heavily simplified
-	 * version of it to the main toolbar, but only show it when this shell
-	 * view is active.  So each view still gets its own searchbar. */
-
-	shell_searchbar = E_SHELL_SEARCHBAR (widget);
-	e_shell_searchbar_set_express_mode (shell_searchbar, TRUE);
-
-	/* XXX Hardcoded sizes are evil, but what should the width be
-	 *     relative to.  Window width?  The other toolbar width? */
-	gtk_widget_set_size_request (widget, SIMPLE_SEARCHBAR_WIDTH, -1);
-
-	main_toolbar = e_shell_window_get_managed_widget (
-		shell_window, "/search-toolbar");
-
-	item = gtk_tool_item_new ();
-	gtk_container_add (GTK_CONTAINER (item), widget);
-	gtk_widget_show (GTK_WIDGET (item));
-
-	action = e_shell_view_get_action (shell_view);
-	g_object_bind_property (
-		action, "active",
-		widget, "visible",
-		G_BINDING_SYNC_CREATE);
-
-	gtk_toolbar_insert (GTK_TOOLBAR (main_toolbar), item, -1);
-
-	if (e_shell_get_small_screen_mode (shell)) {
-		GtkWidget *image;
-		GtkWidget *container;
-		GtkAction *action;
-		GtkToolItem *item;
-
-		action = e_shell_window_get_action (
-			shell_window, "close-window");
-		image = gtk_image_new_from_icon_name (
-			"window-close-hover", GTK_ICON_SIZE_DIALOG);
-		item = gtk_tool_button_new (
-			image, gtk_action_get_label (action));
-		gtk_widget_set_name (GTK_WIDGET (item), "MeeGoCloseButton");
-		gtk_activatable_set_related_action (
-			GTK_ACTIVATABLE (item), action);
-		container = e_shell_window_get_menu_bar_box (shell_window);
-		gtk_box_pack_start (
-			GTK_BOX (container),
-			GTK_WIDGET (item), FALSE, FALSE, 0);
-		gtk_widget_show_all (GTK_WIDGET (item));
-	}
+	e_shell_content_set_searchbar (shell_content, widget);
+	gtk_widget_show (widget);
 
 	return widget;
 }
@@ -741,8 +685,8 @@ shell_view_toggled (EShellView *shell_view)
 	id = shell_view_class->ui_manager_id;
 
 	if (view_is_active && priv->merge_id == 0) {
-		priv->merge_id = e_ui_manager_add_ui_from_file (
-			E_UI_MANAGER (ui_manager), basename);
+		priv->merge_id = e_load_ui_manager_definition (
+			ui_manager, basename);
 		e_plugin_ui_enable_manager (ui_manager, id);
 	} else if (!view_is_active && priv->merge_id != 0) {
 		e_plugin_ui_disable_manager (ui_manager, id);
@@ -1089,6 +1033,8 @@ static void
 e_shell_view_init (EShellView *shell_view,
                    EShellViewClass *class)
 {
+	GtkSizeGroup *size_group;
+
 	/* XXX Our use of GInstanceInitFunc's 'class' parameter
 	 *     prevents us from using G_DEFINE_ABSTRACT_TYPE. */
 
@@ -1098,8 +1044,11 @@ e_shell_view_init (EShellView *shell_view,
 	if (class->view_collection == NULL)
 		shell_view_init_view_collection (class);
 
+	size_group = gtk_size_group_new (GTK_SIZE_GROUP_VERTICAL);
+
 	shell_view->priv = E_SHELL_VIEW_GET_PRIVATE (shell_view);
 	shell_view->priv->state_key_file = g_key_file_new ();
+	shell_view->priv->size_group = size_group;
 }
 
 GType
@@ -1471,6 +1420,26 @@ e_shell_view_get_search_query (EShellView *shell_view)
 	return g_string_free (string, FALSE);
 }
 
+/**
+ * e_shell_view_get_size_group:
+ * @shell_view: an #EShellView
+ *
+ * Returns a #GtkSizeGroup that #EShellContent and #EShellSidebar use
+ * to keep the search bar and sidebar banner vertically aligned.  The
+ * rest of the application should have no need for this.
+ *
+ * Note, this is only available during #EShellView construction.
+ *
+ * Returns: a #GtkSizeGroup for internal use
+ **/
+GtkSizeGroup *
+e_shell_view_get_size_group (EShellView *shell_view)
+{
+	g_return_val_if_fail (E_IS_SHELL_VIEW (shell_view), NULL);
+
+	return shell_view->priv->size_group;
+}
+
 /**
  * e_shell_view_get_shell_backend:
  * @shell_view: an #EShellView
