@@ -372,16 +372,10 @@ action_preferences_cb (GtkAction *action,
 	shell_backend = e_shell_view_get_shell_backend (shell_view);
 	shell_backend_class = E_SHELL_BACKEND_GET_CLASS (shell_backend);
 
-	if (shell_backend_class->preferences_page != NULL) {
-		if (e_shell_get_express_mode (shell))
-			e_preferences_window_filter_page (
-				E_PREFERENCES_WINDOW (preferences_window),
-				shell_backend_class->preferences_page);
-		else
-			e_preferences_window_show_page (
-				E_PREFERENCES_WINDOW (preferences_window),
-				shell_backend_class->preferences_page);
-	}
+	if (shell_backend_class->preferences_page != NULL)
+		e_preferences_window_show_page (
+			E_PREFERENCES_WINDOW (preferences_window),
+			shell_backend_class->preferences_page);
 }
 
 /**
@@ -763,17 +757,17 @@ action_work_offline_cb (GtkAction *action,
                         EShellWindow *shell_window)
 {
 	EShell *shell;
-	EShellSettings *shell_settings;
+	GSettings *settings;
 
 	shell = e_shell_window_get_shell (shell_window);
-	shell_settings = e_shell_get_shell_settings (shell);
 
 	e_shell_set_online (shell, FALSE);
 
-	/* XXX The sense of the setting is reversed.  Would be more
-	 *     intuitive and less error-prone as "start-online". */
-	e_shell_settings_set_boolean (
-		shell_settings, "start-offline", TRUE);
+	/* XXX The boolean sense of the setting is backwards.  Would
+	 *     be more intuitive and less error-prone as "start-online". */
+	settings = g_settings_new ("org.gnome.evolution.shell");
+	g_settings_set_boolean (settings, "start-offline", TRUE);
+	g_object_unref (settings);
 }
 
 /**
@@ -789,17 +783,17 @@ action_work_online_cb (GtkAction *action,
                        EShellWindow *shell_window)
 {
 	EShell *shell;
-	EShellSettings *shell_settings;
+	GSettings *settings;
 
 	shell = e_shell_window_get_shell (shell_window);
-	shell_settings = e_shell_get_shell_settings (shell);
 
 	e_shell_set_online (shell, TRUE);
 
-	/* XXX The sense of the setting is reversed.  Would be more
-	 *     intuitive and less error-prone as "start-online". */
-	e_shell_settings_set_boolean (
-		shell_settings, "start-offline", FALSE);
+	/* XXX The boolean sense of the setting is backwards.  Would
+	 *     be more intuitive and less error-prone as "start-online". */
+	settings = g_settings_new ("org.gnome.evolution.shell");
+	g_settings_set_boolean (settings, "start-offline", FALSE);
+	g_object_unref (settings);
 }
 
 /**
@@ -1283,8 +1277,8 @@ e_shell_window_actions_init (EShellWindow *shell_window)
 	g_return_if_fail (E_IS_SHELL_WINDOW (shell_window));
 
 	ui_manager = e_shell_window_get_ui_manager (shell_window);
-	e_ui_manager_add_ui_from_file (
-		E_UI_MANAGER (ui_manager), "evolution-shell.ui");
+
+	e_load_ui_manager_definition (ui_manager, "evolution-shell.ui");
 
 	/* Shell Actions */
 	action_group = ACTION_GROUP (SHELL);
@@ -1404,30 +1398,9 @@ e_shell_window_actions_init (EShellWindow *shell_window)
 	g_free (path);
 }
 
-static GList *
-express_filter_new_actions (GList *list)
-{
-	GList *l, *filtered = NULL;
-
-	for (l = list; l; l = l->next) {
-		const gchar *backend_name;
-
-		backend_name = g_object_get_data (
-			G_OBJECT (l->data), "backend-name");
-
-		/* only the addressbook pieces in express mode */
-		if (!strcmp (backend_name, "addressbook"))
-			filtered = g_list_prepend (filtered, l->data);
-	}
-	g_list_free (list);
-
-	return g_list_reverse (filtered);
-}
-
 GtkWidget *
 e_shell_window_create_new_menu (EShellWindow *shell_window)
 {
-	EShell *shell;
 	GtkActionGroup *action_group;
 	GList *new_item_actions;
 	GList *new_source_actions;
@@ -1435,8 +1408,6 @@ e_shell_window_create_new_menu (EShellWindow *shell_window)
 	GtkWidget *menu;
 	GtkWidget *separator;
 
-	shell = e_shell_window_get_shell (shell_window);
-
 	/* Get sorted lists of "new item" and "new source" actions. */
 
 	action_group = ACTION_GROUP (NEW_ITEM);
@@ -1464,12 +1435,6 @@ e_shell_window_create_new_menu (EShellWindow *shell_window)
 	for (iter = list; iter != NULL; iter = iter->next)
 		iter->data = gtk_action_create_menu_item (iter->data);
 
-	if (e_shell_get_express_mode (shell)) {
-		new_item_actions = express_filter_new_actions (new_item_actions);
-		g_list_free (new_source_actions);
-		new_source_actions = NULL;
-	}
-
 	for (iter = new_item_actions; iter != NULL; iter = iter->next)
 		iter->data = gtk_action_create_menu_item (iter->data);
 
