@@ -47,7 +47,6 @@ enum {
 };
 
 enum {
-	CLOSE_ALERT,
 	SHELL_VIEW_CREATED,
 	LAST_SIGNAL
 };
@@ -82,40 +81,68 @@ shell_window_menubar_update_new_menu (EShellWindow *shell_window)
 	gtk_widget_show (widget);
 }
 
+static void	shell_window_backend_prefer_item_changed_cb
+						(EShellBackend *backend,
+						 GParamSpec *pspec,
+						 EShellWindow *shell_window);
+
 static void
-shell_window_toolbar_update_new_menu (GtkMenuToolButton *menu_tool_button,
+shell_window_toolbar_update_new_menu (EShellWindow *shell_window,
                                       GParamSpec *pspec,
-                                      EShellWindow *shell_window)
+                                      GtkMenuToolButton *menu_tool_button)
 {
 	GtkWidget *menu;
 
 	/* Update the "New" menu tool button submenu. */
 	menu = e_shell_window_create_new_menu (shell_window);
 	gtk_menu_tool_button_set_menu (menu_tool_button, menu);
+
+	if (pspec && g_strcmp0 (pspec->name, "active-view") == 0) {
+		EShellView *shell_view;
+		EShellBackend *shell_backend;
+
+		shell_view = e_shell_window_peek_shell_view (
+			shell_window,
+			e_shell_window_get_active_view (shell_window));
+		g_return_if_fail (shell_view != NULL);
+
+		shell_backend = e_shell_view_get_shell_backend (shell_view);
+
+		g_signal_handlers_disconnect_by_func (
+			shell_backend,
+			shell_window_backend_prefer_item_changed_cb,
+			shell_window);
+
+		g_signal_connect (
+			shell_backend, "notify::prefer-new-item",
+			G_CALLBACK (shell_window_backend_prefer_item_changed_cb),
+			shell_window);
+
+		shell_window_backend_prefer_item_changed_cb (
+			shell_backend, NULL, shell_window);
+	}
 }
 
-static gboolean
-shell_window_active_view_to_prefer_item (GBinding *binding,
-                                         const GValue *source_value,
-                                         GValue *target_value,
-                                         gpointer user_data)
+static void
+shell_window_backend_prefer_item_changed_cb (EShellBackend *backend,
+                                             GParamSpec *pspec,
+                                             EShellWindow *shell_window)
 {
-	GObject *source_object;
-	EShell *shell;
+	EShellView *shell_view;
 	EShellBackend *shell_backend;
-	const gchar *active_view;
-	const gchar *prefer_item;
 
-	active_view = g_value_get_string (source_value);
+	shell_view = e_shell_window_peek_shell_view (
+		shell_window,
+		e_shell_window_get_active_view (shell_window));
+	g_return_if_fail (shell_view != NULL);
 
-	source_object = g_binding_get_source (binding);
-	shell = e_shell_window_get_shell (E_SHELL_WINDOW (source_object));
-	shell_backend = e_shell_get_backend_by_name (shell, active_view);
-	prefer_item = e_shell_backend_get_prefer_new_item (shell_backend);
+	shell_backend = e_shell_view_get_shell_backend (shell_view);
+	if (shell_backend != backend)
+		return;
 
-	g_value_set_string (target_value, prefer_item);
-
-	return TRUE;
+	e_shell_window_set_toolbar_new_prefer_item (
+		shell_window,
+		e_shell_backend_get_prefer_new_item (shell_backend));
 }
 
 static void
@@ -372,35 +399,10 @@ shell_window_constructed (GObject *object)
 
 	e_extensible_load_extensions (E_EXTENSIBLE (object));
 
-	if (e_shell_get_meego_mode (shell_window->priv->shell) &&
-	    e_shell_get_small_screen_mode (shell_window->priv->shell))
-		gtk_window_set_decorated (GTK_WINDOW (object), FALSE);
-
 	/* Chain up to parent's constructed() method. */
 	G_OBJECT_CLASS (e_shell_window_parent_class)->constructed (object);
 }
 
-static void
-shell_window_close_alert (EShellWindow *shell_window)
-{
-	EShellView *shell_view;
-	EShellContent *shell_content;
-	GtkWidget *alert_bar;
-	const gchar *view_name;
-
-	/* Close view-specific alerts first, followed by global alerts. */
-
-	view_name = e_shell_window_get_active_view (shell_window);
-	shell_view = e_shell_window_get_shell_view (shell_window, view_name);
-	shell_content = e_shell_view_get_shell_content (shell_view);
-	alert_bar = e_shell_content_get_alert_bar (shell_content);
-
-	if (!e_alert_bar_close_alert (E_ALERT_BAR (alert_bar))) {
-		alert_bar = e_shell_window_get_alert_bar (shell_window);
-		e_alert_bar_close_alert (E_ALERT_BAR (alert_bar));
-	}
-}
-
 static GtkWidget *
 shell_window_construct_menubar (EShellWindow *shell_window)
 {
@@ -410,27 +412,6 @@ shell_window_construct_menubar (EShellWindow *shell_window)
 		shell_window, "/main-menu");
 	gtk_widget_show (main_menu);
 
-	if (e_shell_get_small_screen_mode (shell_window->priv->shell)) {
-		GtkWidget *parent, *child;
-
-		parent = gtk_widget_get_parent (main_menu);
-		g_object_ref (parent);
-		gtk_container_remove ((GtkContainer *) parent, main_menu);
-		child = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-		gtk_box_pack_start ((GtkBox *) child, main_menu, TRUE, TRUE, 0);
-		gtk_widget_show (child);
-		gtk_container_add ((GtkContainer *) parent, child);
-		shell_window->priv->menubar_box = child;
-
-		g_object_bind_property (
-			main_menu, "visible",
-			child, "visible",
-			G_BINDING_BIDIRECTIONAL |
-			G_BINDING_SYNC_CREATE);
-
-		main_menu = child;
-	}
-
 	g_signal_connect (
 		shell_window, "notify::active-view",
 		G_CALLBACK (shell_window_menubar_update_new_menu), NULL);
@@ -447,13 +428,11 @@ e_shell_window_get_menu_bar_box (EShellWindow *shell_window)
 static GtkWidget *
 shell_window_construct_toolbar (EShellWindow *shell_window)
 {
-	EShell *shell;
 	GtkUIManager *ui_manager;
 	GtkWidget *toolbar;
 	GtkWidget *box;
 	GtkToolItem *item;
 
-	shell = e_shell_window_get_shell (shell_window);
 	ui_manager = e_shell_window_get_ui_manager (shell_window);
 
 	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
@@ -471,9 +450,6 @@ shell_window_construct_toolbar (EShellWindow *shell_window)
 		gtk_widget_get_style_context (toolbar),
 		GTK_STYLE_CLASS_PRIMARY_TOOLBAR);
 
-	if (e_shell_get_meego_mode (shell))
-		 gtk_widget_set_name (GTK_WIDGET (toolbar), "MeeGoToolbar");
-
 	/* XXX Having this separator in the UI definition doesn't work
 	 *     because GtkUIManager is unaware of the "New" button, so
 	 *     it makes the separator invisible.  One possibility is to
@@ -497,26 +473,12 @@ shell_window_construct_toolbar (EShellWindow *shell_window)
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, 0);
 	gtk_widget_show (GTK_WIDGET (item));
 
-	/* XXX The ECalShellBackend has a hack where it forces the
-	 *     EMenuToolButton to update its button image by forcing
-	 *     a "notify::active-view" signal emission on the window.
-	 *     This will trigger the property binding, which will set
-	 *     EMenuToolButton's "prefer-item" property, which will
-	 *     invoke shell_window_toolbar_update_new_menu(), which
-	 *     will cause EMenuToolButton to update its button image.
-	 *
-	 *     It's a bit of a Rube Goldberg machine and should be
-	 *     reworked, but it's just serving one (now documented)
-	 *     corner case and works for now. */
-	g_object_bind_property_full (
-		shell_window, "active-view",
-		item, "prefer-item",
-		G_BINDING_SYNC_CREATE,
-		shell_window_active_view_to_prefer_item,
-		(GBindingTransformFunc) NULL,
-		NULL, (GDestroyNotify) NULL);
-
 	g_signal_connect (
+		shell_window, "notify::active-view",
+		G_CALLBACK (shell_window_toolbar_update_new_menu),
+		GTK_MENU_TOOL_BUTTON (item));
+
+	g_signal_connect_swapped (
 		item, "notify::prefer-item",
 		G_CALLBACK (shell_window_toolbar_update_new_menu),
 		shell_window);
@@ -526,18 +488,10 @@ shell_window_construct_toolbar (EShellWindow *shell_window)
 	toolbar = e_shell_window_get_managed_widget (
 		shell_window, "/search-toolbar");
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), FALSE);
-	if (e_shell_get_express_mode (shell))
-		gtk_box_pack_start (GTK_BOX (box), toolbar, FALSE, FALSE, 0);
-	if (e_shell_get_meego_mode (shell))
-		gtk_widget_set_name (GTK_WIDGET (toolbar), "MeeGoToolbar");
 
 	toolbar = e_shell_window_get_managed_widget (
 		shell_window, "/close-toolbar");
 	gtk_toolbar_set_show_arrow (GTK_TOOLBAR (toolbar), FALSE);
-	if (e_shell_get_meego_mode (shell))
-		gtk_box_pack_start (GTK_BOX (box), toolbar, FALSE, FALSE, 0);
-	if (e_shell_get_meego_mode (shell))
-		gtk_widget_set_name (GTK_WIDGET (toolbar), "MeeGoToolbar");
 
 	return box;
 }
@@ -758,20 +712,6 @@ shell_window_create_shell_view (EShellWindow *shell_window,
 	return shell_view;
 }
 
-static void
-shell_window_realize (GtkWidget *widget)
-{
-	EShellWindow *shell_window;
-
-	shell_window = E_SHELL_WINDOW (widget);
-	e_shell_adapt_window_size (
-		shell_window->priv->shell,
-		GTK_WINDOW (widget));
-
-	/* Chain up to parent's dispose() method. */
-	GTK_WIDGET_CLASS (e_shell_window_parent_class)->realize (widget);
-}
-
 static void
 shell_window_submit_alert (EAlertSink *alert_sink,
                            EAlert *alert)
@@ -804,8 +744,6 @@ static void
 e_shell_window_class_init (EShellWindowClass *class)
 {
 	GObjectClass *object_class;
-	GtkWidgetClass *widget_class;
-	GtkBindingSet *binding_set;
 
 	g_type_class_add_private (class, sizeof (EShellWindowPrivate));
 
@@ -816,10 +754,6 @@ e_shell_window_class_init (EShellWindowClass *class)
 	object_class->finalize = shell_window_finalize;
 	object_class->constructed = shell_window_constructed;
 
-	widget_class = GTK_WIDGET_CLASS (class);
-	widget_class->realize = shell_window_realize;
-
-	class->close_alert = shell_window_close_alert;
 	class->construct_menubar = shell_window_construct_menubar;
 	class->construct_toolbar = shell_window_construct_toolbar;
 	class->construct_sidebar = shell_window_construct_sidebar;
@@ -996,22 +930,6 @@ e_shell_window_class_init (EShellWindowClass *class)
 			GTK_TYPE_UI_MANAGER,
 			G_PARAM_READABLE));
 
-	/**
-	 * EShellWindow::close-alert
-	 * @shell_window: the #EShellWindow which emitted the signal
-	 *
-	 * Closes either one #EShellView-specific #EAlert or else one
-	 * global #EAlert.  This signal is bound to the Escape key.
-	 **/
-	signals[CLOSE_ALERT] = g_signal_new (
-		"close-alert",
-		G_OBJECT_CLASS_TYPE (object_class),
-		G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
-		G_STRUCT_OFFSET (EShellWindowClass, close_alert),
-		NULL, NULL,
-		g_cclosure_marshal_VOID__VOID,
-		G_TYPE_NONE, 0);
-
 	/**
 	 * EShellWindow::shell-view-created
 	 * @shell_window: the #EShellWindow which emitted the signal
@@ -1031,10 +949,6 @@ e_shell_window_class_init (EShellWindowClass *class)
 		g_cclosure_marshal_VOID__OBJECT,
 		G_TYPE_NONE, 1,
 		E_TYPE_SHELL_VIEW);
-
-	binding_set = gtk_binding_set_by_class (class);
-	gtk_binding_entry_add_signal (
-		binding_set, GDK_KEY_Escape, 0, "close-alert", 0);
 }
 
 static void
@@ -1605,6 +1519,62 @@ e_shell_window_set_toolbar_visible (EShellWindow *shell_window,
 	g_object_notify (G_OBJECT (shell_window), "toolbar-visible");
 }
 
+/**
+ * e_shell_window_get_toolbar_new_prefer_item:
+ * @shell_window: an #EShellWindow
+ *
+ * Returns: name of preferred item on the New button for current view.
+ *
+ * Since: 3.4
+ **/
+const gchar *
+e_shell_window_get_toolbar_new_prefer_item (EShellWindow *shell_window)
+{
+	GtkWidget *toolbar;
+	GtkToolItem *item;
+
+	g_return_val_if_fail (shell_window != NULL, NULL);
+	g_return_val_if_fail (E_IS_SHELL_WINDOW (shell_window), NULL);
+
+	toolbar = e_shell_window_get_managed_widget (shell_window, "/main-toolbar");
+	g_return_val_if_fail (toolbar != NULL, NULL);
+
+	item = gtk_toolbar_get_nth_item (GTK_TOOLBAR (toolbar), 0);
+	g_return_val_if_fail (item != NULL, NULL);
+	g_return_val_if_fail (E_IS_MENU_TOOL_BUTTON (item), NULL);
+
+	return e_menu_tool_button_get_prefer_item (E_MENU_TOOL_BUTTON (item));
+}
+
+/**
+ * e_shell_window_set_toolbar_new_prefer_item:
+ * @shell_window: an #EShellWindow
+ * @prefer_item: prefer-item name to be set
+ *
+ * Sets prefer item on the New button for current view.
+ *
+ * Since: 3.4
+ **/
+void
+e_shell_window_set_toolbar_new_prefer_item (EShellWindow *shell_window,
+                                            const gchar *prefer_item)
+{
+	GtkWidget *toolbar;
+	GtkToolItem *item;
+
+	g_return_if_fail (shell_window != NULL);
+	g_return_if_fail (E_IS_SHELL_WINDOW (shell_window));
+
+	toolbar = e_shell_window_get_managed_widget (shell_window, "/main-toolbar");
+	g_return_if_fail (toolbar != NULL);
+
+	item = gtk_toolbar_get_nth_item (GTK_TOOLBAR (toolbar), 0);
+	g_return_if_fail (item != NULL);
+	g_return_if_fail (E_IS_MENU_TOOL_BUTTON (item));
+
+	e_menu_tool_button_set_prefer_item (E_MENU_TOOL_BUTTON (item), prefer_item);
+}
+
 /**
  * e_shell_window_register_new_item_actions:
  * @shell_window: an #EShellWindow
